import * as i0 from '@angular/core';
import { inject, Renderer2, ElementRef, isDevMode, ɵstringify as _stringify, Input, Directive } from '@angular/core';
import { getKcClsx } from 'keycloakify/account/lib/kcClsx';
import { ComponentReference } from '@keycloakify/angular/account/classes/component-reference';

/* eslint-disable @typescript-eslint/no-explicit-any */
class KcClassDirective {
    constructor() {
        this.initialClasses = [];
        this.stateMap = new Map();
        this.#renderer = inject(Renderer2);
        this.#el = inject(ElementRef);
        this.#host = inject(ComponentReference);
    }
    #renderer;
    #el;
    #host;
    set klass(value) {
        this.initialClasses = value != null ? value.trim().split(/\s+/) : [];
    }
    set ngClass(value) {
        this.rawClass = typeof value === 'string' ? value.trim().split(/\s+/) : value;
    }
    set kcClass(value) {
        this.rawKcClass =
            typeof value === 'string' ? value.trim().split(/\s+/) : value;
    }
    ngDoCheck() {
        for (const klass of this.initialClasses) {
            this._updateState(klass, true);
        }
        // classes from the [ngClass] binding
        const rawClass = this.rawClass;
        if (Array.isArray(rawClass) || rawClass instanceof Set) {
            for (const klass of rawClass) {
                this._updateState(klass, true);
            }
        }
        else if (rawClass != null) {
            for (const klass of Object.keys(rawClass)) {
                this._updateState(klass, Boolean(rawClass[klass]));
            }
        }
        // classes from the [kcClass] binding
        const rawKcClass = this.rawKcClass;
        if (Array.isArray(rawKcClass) || rawKcClass instanceof Set) {
            for (const klass of rawKcClass) {
                this._updateState(klass, true, true);
            }
        }
        else if (rawKcClass != null) {
            for (const klass of Object.keys(rawKcClass)) {
                this._updateState(klass, Boolean(rawKcClass[klass]), true);
            }
        }
        this._applyStateDiff();
    }
    _updateState(klass, nextEnabled, kcClsxCheck = false) {
        const state = this.stateMap.get(klass);
        if (state !== undefined) {
            if (state.enabled !== nextEnabled) {
                state.changed = true;
                state.enabled = nextEnabled;
            }
            state.touched = true;
        }
        else {
            let klassChecked = klass;
            if (kcClsxCheck) {
                const doUseDefaultCss = this.#host.doUseDefaultCss ?? true;
                const classes = {
                    ...(this.#host.classes ?? {}),
                    ...(this.#host.additionalClasses ?? {})
                };
                const kcClsx = getKcClsx({ doUseDefaultCss, classes }).kcClsx;
                klassChecked = kcClsx(klass);
            }
            this.stateMap.set(klassChecked, {
                enabled: nextEnabled,
                changed: true,
                touched: true
            });
        }
    }
    _applyStateDiff() {
        for (const stateEntry of this.stateMap) {
            const klass = stateEntry[0];
            const state = stateEntry[1];
            if (state.changed) {
                this._toggleClass(klass, state.enabled);
                state.changed = false;
            }
            else if (!state.touched) {
                // A class that was previously active got removed from the new collection of classes -
                // remove from the DOM as well.
                if (state.enabled) {
                    this._toggleClass(klass, false);
                }
                this.stateMap.delete(klass);
            }
            state.touched = false;
        }
    }
    _toggleClass(klass, enabled) {
        if (isDevMode()) {
            if (typeof klass !== 'string') {
                throw new Error(`NgClass can only toggle CSS classes expressed as strings, got ${_stringify(klass)}`);
            }
        }
        klass = klass.trim();
        if (klass.length > 0) {
            klass.split(/\s+/).forEach(klass => {
                if (enabled) {
                    this.#renderer.addClass(this.#el.nativeElement, klass);
                }
                else {
                    this.#renderer.removeClass(this.#el.nativeElement, klass);
                }
            });
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: KcClassDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.3", type: KcClassDirective, isStandalone: true, selector: "[kcClass]", inputs: { klass: ["class", "klass"], ngClass: "ngClass", kcClass: "kcClass" }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: KcClassDirective, decorators: [{
            type: Directive,
            args: [{ selector: '[kcClass]' }]
        }], propDecorators: { klass: [{
                type: Input,
                args: ['class']
            }], ngClass: [{
                type: Input,
                args: ['ngClass']
            }], kcClass: [{
                type: Input,
                args: ['kcClass']
            }] } });

/**
 * Generated bundle index. Do not edit.
 */

export { KcClassDirective };
//# sourceMappingURL=keycloakify-angular-account-directives-kc-class.mjs.map
