import { NgClass } from '@angular/common';
import * as i0 from '@angular/core';
import { inject, forwardRef, Component } from '@angular/core';
import { ComponentReference } from '@keycloakify/angular/account/classes/component-reference';
import { KcClassDirective } from '@keycloakify/angular/account/directives/kc-class';
import { ACCOUNT_CLASSES } from '@keycloakify/angular/account/tokens/classes';
import { ACCOUNT_I18N } from '@keycloakify/angular/account/tokens/i18n';
import { KC_ACCOUNT_CONTEXT } from '@keycloakify/angular/account/tokens/kc-context';
import { USE_DEFAULT_CSS } from '@keycloakify/angular/lib/tokens/use-default-css';

class AccountComponent extends ComponentReference {
    constructor() {
        super(...arguments);
        this.i18n = inject(ACCOUNT_I18N);
        this.kcContext = inject(KC_ACCOUNT_CONTEXT);
        this.doUseDefaultCss = inject(USE_DEFAULT_CSS);
        this.classes = inject(ACCOUNT_CLASSES);
        this.additionalClasses = {
            kcBodyClass: `${this.classes?.kcBodyClass} user`
        };
        this.active = 'account';
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: AccountComponent, deps: null, target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "20.0.3", type: AccountComponent, isStandalone: true, selector: "kc-account", providers: [
            {
                provide: ComponentReference,
                useExisting: forwardRef(() => AccountComponent)
            }
        ], usesInheritance: true, ngImport: i0, template: "@let url = kcContext.url;\n@let realm = kcContext.realm;\n@let messagesPerField = kcContext.messagesPerField;\n@let stateChecker = kcContext.stateChecker;\n@let account = kcContext.account;\n@let referrer = kcContext.referrer;\n\n<div class=\"row\">\n    <div class=\"col-md-10\">\n        <h2>{{ i18n.msgStr('editAccountHtmlTitle') }}</h2>\n    </div>\n    <div class=\"col-md-2 subtitle\">\n        <span class=\"subtitle\"> <span class=\"required\">*</span> {{ i18n.msgStr('requiredFields') }} </span>\n    </div>\n</div>\n<form\n    class=\"form-horizontal\"\n    method=\"post\"\n    [action]=\"url.accountUrl\"\n>\n    <input\n        type=\"hidden\"\n        id=\"stateChecker\"\n        name=\"stateChecker\"\n        [value]=\"stateChecker\"\n    />\n    @if (!realm.registrationEmailAsUsername) {\n        <div\n            class=\"form-group\"\n            [ngClass]=\"{ 'has-error': messagesPerField.existsError('username') }\"\n        >\n            <div class=\"col-sm-2 col-md-2\">\n                <label\n                    for=\"username\"\n                    class=\"control-label\"\n                >\n                    {{ i18n.msgStr('username') }}\n                </label>\n                @if (realm.editUsernameAllowed) {\n                    <span class=\"required\">*</span>\n                }\n            </div>\n\n            <div class=\"col-sm-10 col-md-10\">\n                <input\n                    type=\"text\"\n                    class=\"form-control\"\n                    id=\"username\"\n                    name=\"username\"\n                    [disabled]=\"!realm.editUsernameAllowed\"\n                    [defaultValue]=\"account.username ?? ''\"\n                />\n            </div>\n        </div>\n    }\n\n    <div\n        class=\"form-group\"\n        [ngClass]=\"{ 'has-error': messagesPerField.existsError('email') }\"\n    >\n        <div class=\"col-sm-2 col-md-2\">\n            <label\n                for=\"email\"\n                class=\"control-label\"\n            >\n                {{ i18n.msgStr('email') }}\n            </label>\n            <span class=\"required\">*</span>\n        </div>\n\n        <div class=\"col-sm-10 col-md-10\">\n            <input\n                type=\"text\"\n                class=\"form-control\"\n                id=\"email\"\n                name=\"email\"\n                autoFocus\n                [defaultValue]=\"account.email ?? ''\"\n            />\n        </div>\n    </div>\n\n    <div\n        class=\"form-group\"\n        [ngClass]=\"{ 'has-error': messagesPerField.existsError('firstName') }\"\n    >\n        <div class=\"col-sm-2 col-md-2\">\n            <label\n                for=\"firstName\"\n                class=\"control-label\"\n            >\n                {{ i18n.msgStr('firstName') }}\n            </label>\n            <span class=\"required\">*</span>\n        </div>\n\n        <div class=\"col-sm-10 col-md-10\">\n            <input\n                type=\"text\"\n                class=\"form-control\"\n                id=\"firstName\"\n                name=\"firstName\"\n                [defaultValue]=\"account.firstName\"\n            />\n        </div>\n    </div>\n\n    <div\n        class=\"form-group\"\n        [ngClass]=\"{ 'has-error': messagesPerField.existsError('lastName') }\"\n    >\n        <div class=\"col-sm-2 col-md-2\">\n            <label\n                for=\"lastName\"\n                class=\"control-label\"\n            >\n                {{ i18n.msgStr('lastName') }}\n            </label>\n            <span class=\"required\">*</span>\n        </div>\n\n        <div class=\"col-sm-10 col-md-10\">\n            <input\n                type=\"text\"\n                class=\"form-control\"\n                id=\"lastName\"\n                name=\"lastName\"\n                [defaultValue]=\"account.lastName ?? ''\"\n            />\n        </div>\n    </div>\n\n    <div class=\"form-group\">\n        <div\n            id=\"kc-form-buttons\"\n            class=\"col-md-offset-2 col-md-10 submit\"\n        >\n            <div>\n                @if (referrer) {\n                    <a [href]=\"referrer?.url\">{{ i18n.msgStr('backToApplication') }}</a>\n                }\n                <button\n                    type=\"submit\"\n                    name=\"submitAction\"\n                    value=\"Save\"\n                    [kcClass]=\"['kcButtonClass', 'kcButtonPrimaryClass', 'kcButtonLargeClass']\"\n                >\n                    {{ i18n.msgStr('doSave') }}\n                </button>\n                <button\n                    type=\"submit\"\n                    name=\"submitAction\"\n                    value=\"Cancel\"\n                    [kcClass]=\"['kcButtonClass', 'kcButtonPrimaryClass', 'kcButtonLargeClass']\"\n                >\n                    {{ i18n.msgStr('doCancel') }}\n                </button>\n            </div>\n        </div>\n    </div>\n</form>\n", dependencies: [{ kind: "directive", type: KcClassDirective, selector: "[kcClass]", inputs: ["class", "ngClass", "kcClass"] }, { kind: "directive", type: NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: AccountComponent, decorators: [{
            type: Component,
            args: [{ imports: [KcClassDirective, NgClass], selector: 'kc-account', providers: [
                        {
                            provide: ComponentReference,
                            useExisting: forwardRef(() => AccountComponent)
                        }
                    ], template: "@let url = kcContext.url;\n@let realm = kcContext.realm;\n@let messagesPerField = kcContext.messagesPerField;\n@let stateChecker = kcContext.stateChecker;\n@let account = kcContext.account;\n@let referrer = kcContext.referrer;\n\n<div class=\"row\">\n    <div class=\"col-md-10\">\n        <h2>{{ i18n.msgStr('editAccountHtmlTitle') }}</h2>\n    </div>\n    <div class=\"col-md-2 subtitle\">\n        <span class=\"subtitle\"> <span class=\"required\">*</span> {{ i18n.msgStr('requiredFields') }} </span>\n    </div>\n</div>\n<form\n    class=\"form-horizontal\"\n    method=\"post\"\n    [action]=\"url.accountUrl\"\n>\n    <input\n        type=\"hidden\"\n        id=\"stateChecker\"\n        name=\"stateChecker\"\n        [value]=\"stateChecker\"\n    />\n    @if (!realm.registrationEmailAsUsername) {\n        <div\n            class=\"form-group\"\n            [ngClass]=\"{ 'has-error': messagesPerField.existsError('username') }\"\n        >\n            <div class=\"col-sm-2 col-md-2\">\n                <label\n                    for=\"username\"\n                    class=\"control-label\"\n                >\n                    {{ i18n.msgStr('username') }}\n                </label>\n                @if (realm.editUsernameAllowed) {\n                    <span class=\"required\">*</span>\n                }\n            </div>\n\n            <div class=\"col-sm-10 col-md-10\">\n                <input\n                    type=\"text\"\n                    class=\"form-control\"\n                    id=\"username\"\n                    name=\"username\"\n                    [disabled]=\"!realm.editUsernameAllowed\"\n                    [defaultValue]=\"account.username ?? ''\"\n                />\n            </div>\n        </div>\n    }\n\n    <div\n        class=\"form-group\"\n        [ngClass]=\"{ 'has-error': messagesPerField.existsError('email') }\"\n    >\n        <div class=\"col-sm-2 col-md-2\">\n            <label\n                for=\"email\"\n                class=\"control-label\"\n            >\n                {{ i18n.msgStr('email') }}\n            </label>\n            <span class=\"required\">*</span>\n        </div>\n\n        <div class=\"col-sm-10 col-md-10\">\n            <input\n                type=\"text\"\n                class=\"form-control\"\n                id=\"email\"\n                name=\"email\"\n                autoFocus\n                [defaultValue]=\"account.email ?? ''\"\n            />\n        </div>\n    </div>\n\n    <div\n        class=\"form-group\"\n        [ngClass]=\"{ 'has-error': messagesPerField.existsError('firstName') }\"\n    >\n        <div class=\"col-sm-2 col-md-2\">\n            <label\n                for=\"firstName\"\n                class=\"control-label\"\n            >\n                {{ i18n.msgStr('firstName') }}\n            </label>\n            <span class=\"required\">*</span>\n        </div>\n\n        <div class=\"col-sm-10 col-md-10\">\n            <input\n                type=\"text\"\n                class=\"form-control\"\n                id=\"firstName\"\n                name=\"firstName\"\n                [defaultValue]=\"account.firstName\"\n            />\n        </div>\n    </div>\n\n    <div\n        class=\"form-group\"\n        [ngClass]=\"{ 'has-error': messagesPerField.existsError('lastName') }\"\n    >\n        <div class=\"col-sm-2 col-md-2\">\n            <label\n                for=\"lastName\"\n                class=\"control-label\"\n            >\n                {{ i18n.msgStr('lastName') }}\n            </label>\n            <span class=\"required\">*</span>\n        </div>\n\n        <div class=\"col-sm-10 col-md-10\">\n            <input\n                type=\"text\"\n                class=\"form-control\"\n                id=\"lastName\"\n                name=\"lastName\"\n                [defaultValue]=\"account.lastName ?? ''\"\n            />\n        </div>\n    </div>\n\n    <div class=\"form-group\">\n        <div\n            id=\"kc-form-buttons\"\n            class=\"col-md-offset-2 col-md-10 submit\"\n        >\n            <div>\n                @if (referrer) {\n                    <a [href]=\"referrer?.url\">{{ i18n.msgStr('backToApplication') }}</a>\n                }\n                <button\n                    type=\"submit\"\n                    name=\"submitAction\"\n                    value=\"Save\"\n                    [kcClass]=\"['kcButtonClass', 'kcButtonPrimaryClass', 'kcButtonLargeClass']\"\n                >\n                    {{ i18n.msgStr('doSave') }}\n                </button>\n                <button\n                    type=\"submit\"\n                    name=\"submitAction\"\n                    value=\"Cancel\"\n                    [kcClass]=\"['kcButtonClass', 'kcButtonPrimaryClass', 'kcButtonLargeClass']\"\n                >\n                    {{ i18n.msgStr('doCancel') }}\n                </button>\n            </div>\n        </div>\n    </div>\n</form>\n" }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { AccountComponent };
//# sourceMappingURL=keycloakify-angular-account-pages-account.mjs.map
