import { NgClass } from '@angular/common';
import * as i0 from '@angular/core';
import { inject, signal, forwardRef, Component } from '@angular/core';
import { ComponentReference } from '@keycloakify/angular/account/classes/component-reference';
import { KcClassDirective } from '@keycloakify/angular/account/directives/kc-class';
import { ACCOUNT_CLASSES } from '@keycloakify/angular/account/tokens/classes';
import { ACCOUNT_I18N } from '@keycloakify/angular/account/tokens/i18n';
import { KC_ACCOUNT_CONTEXT } from '@keycloakify/angular/account/tokens/kc-context';
import { USE_DEFAULT_CSS } from '@keycloakify/angular/lib/tokens/use-default-css';

class PasswordComponent extends ComponentReference {
    constructor() {
        super();
        this.i18n = inject(ACCOUNT_I18N);
        this.kcContext = inject(KC_ACCOUNT_CONTEXT);
        this.doUseDefaultCss = inject(USE_DEFAULT_CSS);
        this.classes = inject(ACCOUNT_CLASSES);
        this.additionalClasses = {
            kcBodyClass: `${this.classes?.kcBodyClass} password`
        };
        this.active = 'password';
        this.currentPassword = signal('');
        this.newPassword = signal('');
        this.newPasswordConfirm = signal('');
        this.newPasswordError = signal('');
        this.newPasswordConfirmError = signal('');
        this.hasNewPasswordBlurred = signal(false);
        this.hasNewPasswordConfirmBlurred = signal(false);
        // eslint-disable-next-line @typescript-eslint/ban-ts-comment
        // @ts-ignore
        window.kcContext = {
            ...this.kcContext,
            message: (() => {
                if (this.newPasswordError() !== '') {
                    return {
                        type: 'error',
                        summary: this.newPasswordError()
                    };
                }
                if (this.newPasswordConfirmError() !== '') {
                    return {
                        type: 'error',
                        summary: this.newPasswordConfirmError()
                    };
                }
                return this.kcContext.message;
            })()
        };
    }
    checkNewPassword(newPassword) {
        if (!this.kcContext.password.passwordSet)
            return;
        if (newPassword === this.currentPassword()) {
            this.newPasswordError.set('newPasswordSameAsOld');
        }
        else {
            this.newPasswordError.set('');
        }
    }
    checkNewPasswordConfirm(newPasswordConfirm) {
        if (newPasswordConfirm === '')
            return;
        if (newPasswordConfirm !== this.newPassword()) {
            this.newPasswordConfirmError.set('passwordConfirmNotMatch');
        }
        else {
            this.newPasswordConfirmError.set('');
        }
    }
    onNewPasswordChange(value) {
        const newPassword = value;
        this.newPassword.set(newPassword);
        if (this.hasNewPasswordBlurred()) {
            this.checkNewPassword(newPassword);
        }
    }
    onNewPasswordBlur() {
        this.hasNewPasswordBlurred.set(true);
        this.checkNewPassword(this.newPassword());
    }
    onNewPasswordConfirmChange(value) {
        const newPasswordConfirm = value;
        this.newPasswordConfirm.set(newPasswordConfirm);
        if (this.hasNewPasswordConfirmBlurred()) {
            this.checkNewPasswordConfirm(newPasswordConfirm);
        }
    }
    onNewPasswordConfirmBlur() {
        this.hasNewPasswordConfirmBlurred.set(true);
        this.checkNewPasswordConfirm(this.newPasswordConfirm());
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: PasswordComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "20.0.3", type: PasswordComponent, isStandalone: true, selector: "kc-password", providers: [
            {
                provide: ComponentReference,
                useExisting: forwardRef(() => PasswordComponent)
            }
        ], usesInheritance: true, ngImport: i0, template: "@let url = kcContext.url;\n@let password = kcContext.password;\n@let account = kcContext.account;\n@let stateChecker = kcContext.stateChecker;\n\n<div class=\"row\">\n    <div class=\"col-md-10\">\n        <h2>{{ i18n.msgStr('changePasswordHtmlTitle') }}</h2>\n    </div>\n    <div class=\"col-md-2 subtitle\">\n        <span class=\"subtitle\">{{ i18n.msgStr('allFieldsRequired') }}</span>\n    </div>\n</div>\n\n<form\n    class=\"form-horizontal\"\n    method=\"post\"\n    [action]=\"url.passwordUrl\"\n>\n    <input\n        type=\"text\"\n        id=\"username\"\n        name=\"username\"\n        autoComplete=\"username\"\n        readOnly\n        [value]=\"account.username ?? ''\"\n        [style.display]=\"'none'\"\n    />\n\n    @if (password.passwordSet) {\n        <div class=\"form-group\">\n            <div class=\"col-sm-2 col-md-2\">\n                <label\n                    for=\"password\"\n                    class=\"control-label\"\n                >\n                    {{ i18n.msgStr('password') }}\n                </label>\n            </div>\n            <div class=\"col-sm-10 col-md-10\">\n                <input\n                    type=\"password\"\n                    class=\"form-control\"\n                    id=\"password\"\n                    name=\"password\"\n                    autoFocus\n                    autoComplete=\"current-password\"\n                    [value]=\"currentPassword()\"\n                    (change)=\"currentPassword.set($any($event.target).value)\"\n                />\n            </div>\n        </div>\n    }\n\n    <input\n        type=\"hidden\"\n        id=\"stateChecker\"\n        name=\"stateChecker\"\n        [value]=\"stateChecker\"\n    />\n\n    <div class=\"form-group\">\n        <div class=\"col-sm-2 col-md-2\">\n            <label\n                for=\"password-new\"\n                class=\"control-label\"\n            >\n                {{ i18n.msgStr('passwordNew') }}\n            </label>\n        </div>\n        <div class=\"col-sm-10 col-md-10\">\n            <input\n                type=\"password\"\n                class=\"form-control\"\n                id=\"password-new\"\n                name=\"password-new\"\n                autoComplete=\"new-password\"\n                [value]=\"newPassword()\"\n                (change)=\"onNewPasswordChange($any($event.target).value)\"\n                (blur)=\"onNewPasswordBlur()\"\n            />\n        </div>\n    </div>\n\n    <div class=\"form-group\">\n        <div class=\"col-sm-2 col-md-2\">\n            <label\n                for=\"password-confirm\"\n                class=\"control-label two-lines\"\n            >\n                {{ i18n.msgStr('passwordConfirm') }}\n            </label>\n        </div>\n\n        <div class=\"col-sm-10 col-md-10\">\n            <input\n                type=\"password\"\n                class=\"form-control\"\n                id=\"password-confirm\"\n                name=\"password-confirm\"\n                autoComplete=\"new-password\"\n                [value]=\"newPasswordConfirm()\"\n                (change)=\"onNewPasswordConfirmChange($any($event.target).value)\"\n                (blur)=\"onNewPasswordConfirmBlur()\"\n            />\n        </div>\n    </div>\n\n    <div class=\"form-group\">\n        <div\n            id=\"kc-form-buttons\"\n            class=\"col-md-offset-2 col-md-10 submit\"\n        >\n            <div>\n                <button\n                    type=\"submit\"\n                    name=\"submitAction\"\n                    value=\"Save\"\n                    [disabled]=\"newPasswordError() !== '' || newPasswordConfirmError() !== ''\"\n                    [kcClass]=\"['kcButtonClass', 'kcButtonPrimaryClass', 'kcButtonLargeClass']\"\n                >\n                    {{ i18n.msgStr('doSave') }}\n                </button>\n            </div>\n        </div>\n    </div>\n</form>\n", dependencies: [{ kind: "directive", type: KcClassDirective, selector: "[kcClass]", inputs: ["class", "ngClass", "kcClass"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: PasswordComponent, decorators: [{
            type: Component,
            args: [{ imports: [KcClassDirective, NgClass], selector: 'kc-password', providers: [
                        {
                            provide: ComponentReference,
                            useExisting: forwardRef(() => PasswordComponent)
                        }
                    ], template: "@let url = kcContext.url;\n@let password = kcContext.password;\n@let account = kcContext.account;\n@let stateChecker = kcContext.stateChecker;\n\n<div class=\"row\">\n    <div class=\"col-md-10\">\n        <h2>{{ i18n.msgStr('changePasswordHtmlTitle') }}</h2>\n    </div>\n    <div class=\"col-md-2 subtitle\">\n        <span class=\"subtitle\">{{ i18n.msgStr('allFieldsRequired') }}</span>\n    </div>\n</div>\n\n<form\n    class=\"form-horizontal\"\n    method=\"post\"\n    [action]=\"url.passwordUrl\"\n>\n    <input\n        type=\"text\"\n        id=\"username\"\n        name=\"username\"\n        autoComplete=\"username\"\n        readOnly\n        [value]=\"account.username ?? ''\"\n        [style.display]=\"'none'\"\n    />\n\n    @if (password.passwordSet) {\n        <div class=\"form-group\">\n            <div class=\"col-sm-2 col-md-2\">\n                <label\n                    for=\"password\"\n                    class=\"control-label\"\n                >\n                    {{ i18n.msgStr('password') }}\n                </label>\n            </div>\n            <div class=\"col-sm-10 col-md-10\">\n                <input\n                    type=\"password\"\n                    class=\"form-control\"\n                    id=\"password\"\n                    name=\"password\"\n                    autoFocus\n                    autoComplete=\"current-password\"\n                    [value]=\"currentPassword()\"\n                    (change)=\"currentPassword.set($any($event.target).value)\"\n                />\n            </div>\n        </div>\n    }\n\n    <input\n        type=\"hidden\"\n        id=\"stateChecker\"\n        name=\"stateChecker\"\n        [value]=\"stateChecker\"\n    />\n\n    <div class=\"form-group\">\n        <div class=\"col-sm-2 col-md-2\">\n            <label\n                for=\"password-new\"\n                class=\"control-label\"\n            >\n                {{ i18n.msgStr('passwordNew') }}\n            </label>\n        </div>\n        <div class=\"col-sm-10 col-md-10\">\n            <input\n                type=\"password\"\n                class=\"form-control\"\n                id=\"password-new\"\n                name=\"password-new\"\n                autoComplete=\"new-password\"\n                [value]=\"newPassword()\"\n                (change)=\"onNewPasswordChange($any($event.target).value)\"\n                (blur)=\"onNewPasswordBlur()\"\n            />\n        </div>\n    </div>\n\n    <div class=\"form-group\">\n        <div class=\"col-sm-2 col-md-2\">\n            <label\n                for=\"password-confirm\"\n                class=\"control-label two-lines\"\n            >\n                {{ i18n.msgStr('passwordConfirm') }}\n            </label>\n        </div>\n\n        <div class=\"col-sm-10 col-md-10\">\n            <input\n                type=\"password\"\n                class=\"form-control\"\n                id=\"password-confirm\"\n                name=\"password-confirm\"\n                autoComplete=\"new-password\"\n                [value]=\"newPasswordConfirm()\"\n                (change)=\"onNewPasswordConfirmChange($any($event.target).value)\"\n                (blur)=\"onNewPasswordConfirmBlur()\"\n            />\n        </div>\n    </div>\n\n    <div class=\"form-group\">\n        <div\n            id=\"kc-form-buttons\"\n            class=\"col-md-offset-2 col-md-10 submit\"\n        >\n            <div>\n                <button\n                    type=\"submit\"\n                    name=\"submitAction\"\n                    value=\"Save\"\n                    [disabled]=\"newPasswordError() !== '' || newPasswordConfirmError() !== ''\"\n                    [kcClass]=\"['kcButtonClass', 'kcButtonPrimaryClass', 'kcButtonLargeClass']\"\n                >\n                    {{ i18n.msgStr('doSave') }}\n                </button>\n            </div>\n        </div>\n    </div>\n</form>\n" }]
        }], ctorParameters: () => [] });

/**
 * Generated bundle index. Do not edit.
 */

export { PasswordComponent };
//# sourceMappingURL=keycloakify-angular-account-pages-password.mjs.map
