import { makeEnvironmentProviders, DOCUMENT, LOCALE_ID, provideAppInitializer, inject } from '@angular/core';
import { I18nService } from '@keycloakify/angular/account/services/i18n';
import { ACCOUNT_CLASSES } from '@keycloakify/angular/account/tokens/classes';
import { ACCOUNT_I18N } from '@keycloakify/angular/account/tokens/i18n';
import { KC_ACCOUNT_CONTEXT } from '@keycloakify/angular/account/tokens/kc-context';
import { USE_DEFAULT_CSS } from '@keycloakify/angular/lib/tokens/use-default-css';

const provideKeycloakifyAngular = (config) => makeEnvironmentProviders([
    {
        provide: KC_ACCOUNT_CONTEXT,
        useValue: config.kcContext
    },
    {
        provide: LOCALE_ID,
        useFactory: (document) => {
            return document.documentElement.lang ?? 'en';
        },
        deps: [DOCUMENT]
    },
    provideAppInitializer(() => {
        const i18nService = inject(I18nService);
        const kcContext = inject(KC_ACCOUNT_CONTEXT);
        const getI18n = config.getI18n;
        const { i18n, prI18n_currentLanguage } = getI18n({
            kcContext
        });
        let i18nPromise = new Promise(resolve => resolve(i18n));
        if (prI18n_currentLanguage) {
            i18nPromise = prI18n_currentLanguage;
        }
        return i18nPromise.then(i18n => {
            i18nService.i18n = i18n;
            return true;
        });
    }),
    {
        provide: ACCOUNT_I18N,
        useFactory: (i18nService) => i18nService.i18n,
        deps: [I18nService]
    },
    { provide: USE_DEFAULT_CSS, useValue: config?.doUseDefaultCss ?? true },
    { provide: ACCOUNT_CLASSES, useValue: config?.classes ?? {} }
]);

/**
 * Generated bundle index. Do not edit.
 */

export { provideKeycloakifyAngular };
//# sourceMappingURL=keycloakify-angular-account-providers-keycloakify-angular.mjs.map
