import { AsyncPipe, NgClass } from '@angular/common';
import * as i0 from '@angular/core';
import { inject, Renderer2, ChangeDetectorRef, input, viewChild, ViewContainerRef, effect, forwardRef, ChangeDetectionStrategy, Component } from '@angular/core';
import { Meta, Title } from '@angular/platform-browser';
import { ComponentReference } from '@keycloakify/angular/account/classes/component-reference';
import { KcClassDirective } from '@keycloakify/angular/account/directives/kc-class';
import { AccountResourceInjectorService } from '@keycloakify/angular/account/services/account-resource-injector';
import { ACCOUNT_CLASSES } from '@keycloakify/angular/account/tokens/classes';
import { ACCOUNT_I18N } from '@keycloakify/angular/account/tokens/i18n';
import { KC_ACCOUNT_CONTEXT } from '@keycloakify/angular/account/tokens/kc-context';
import { KcSanitizePipe } from '@keycloakify/angular/lib/pipes/kc-sanitize';
import { USE_DEFAULT_CSS } from '@keycloakify/angular/lib/tokens/use-default-css';
import { getKcClsx } from 'keycloakify/account/lib/kcClsx';

class TemplateComponent extends ComponentReference {
    #cdr;
    #effectRef;
    constructor() {
        super();
        this.i18n = inject(ACCOUNT_I18N);
        this.renderer = inject(Renderer2);
        this.#cdr = inject(ChangeDetectorRef);
        this.meta = inject(Meta);
        this.title = inject(Title);
        this.kcContext = inject(KC_ACCOUNT_CONTEXT);
        this.doUseDefaultCss = inject(USE_DEFAULT_CSS);
        this.classes = inject(ACCOUNT_CLASSES);
        this.accountResourceInjectorService = inject(AccountResourceInjectorService);
        this.page = input();
        this.pageRef = viewChild('pageRef', { read: ViewContainerRef });
        this.isReadyToRender$ = this.accountResourceInjectorService.injectResource(this.doUseDefaultCss);
        this.#effectRef = effect(() => {
            const page = this.page();
            const pageRef = this.pageRef();
            if (!page || !pageRef)
                return;
            const compRef = pageRef.createComponent(page);
            this.onComponentCreated(compRef.instance);
        }, { manualCleanup: true });
    }
    applyKcIndexClasses() {
        const kcClsx = getKcClsx({
            doUseDefaultCss: this.doUseDefaultCss,
            classes: this.classes
        }).kcClsx;
        const kcBodyClass = kcClsx('kcBodyClass');
        const kcHtmlClass = kcClsx('kcHtmlClass');
        const kcBodyClasses = kcBodyClass.split(/\s+/);
        const kcHtmlClasses = kcHtmlClass.split(/\s+/);
        kcBodyClasses.push('admin-console', 'user');
        kcBodyClasses.forEach(klass => {
            this.renderer.addClass(document.body, klass);
        });
        kcHtmlClasses.forEach(klass => {
            this.renderer.addClass(document.documentElement, klass);
        });
    }
    onComponentCreated(compRef) {
        if ('active' in compRef && compRef.active) {
            this.active = compRef.active;
        }
        this.title.setTitle(this.i18n.msgStr('accountManagementTitle'));
        this.applyKcIndexClasses();
        this.#cdr.markForCheck();
        this.#effectRef.destroy();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: TemplateComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "20.0.3", type: TemplateComponent, isStandalone: true, selector: "kc-root", inputs: { page: { classPropertyName: "page", publicName: "page", isSignal: true, isRequired: false, transformFunction: null } }, providers: [
            {
                provide: ComponentReference,
                useExisting: forwardRef(() => TemplateComponent)
            }
        ], viewQueries: [{ propertyName: "pageRef", first: true, predicate: ["pageRef"], descendants: true, read: ViewContainerRef, isSignal: true }], usesInheritance: true, ngImport: i0, template: "@let enabledLanguages = i18n.enabledLanguages;\n@let currentLanguage = i18n.currentLanguage;\n@let url = kcContext.url;\n@let features = kcContext.features;\n@let realm = kcContext.realm;\n@let message = kcContext.message;\n@let referrer = kcContext.referrer;\n@let isReadyToRender = isReadyToRender$ | async;\n\n@if (isReadyToRender) {\n    <header class=\"navbar navbar-default navbar-pf navbar-main header\">\n        <nav\n            class=\"navbar\"\n            role=\"navigation\"\n        >\n            <div class=\"navbar-header\">\n                <div class=\"container\">\n                    <h1 class=\"navbar-title\">Keycloak</h1>\n                </div>\n            </div>\n            <div class=\"navbar-collapse navbar-collapse-1\">\n                <div class=\"container\">\n                    <ul class=\"nav navbar-nav navbar-utility\">\n                        @if (enabledLanguages.length > 1) {\n                            <li>\n                                <div\n                                    class=\"kc-dropdown\"\n                                    id=\"kc-locale-dropdown\"\n                                >\n                                    <a\n                                        href=\"#\"\n                                        id=\"kc-current-locale-link\"\n                                    >\n                                        {{ currentLanguage.label }}\n                                    </a>\n                                    <ul>\n                                        @for (enabledLanguage of enabledLanguages; track enabledLanguage.languageTag) {\n                                            @let label = enabledLanguage.label;\n                                            @let href = enabledLanguage.href;\n\n                                            <li class=\"kc-dropdown-item\">\n                                                <a [href]=\"href\">{{ label }}</a>\n                                            </li>\n                                        }\n                                    </ul>\n                                </div>\n                            </li>\n                        }\n                        @if (!!referrer?.url) {\n                            <a\n                                id=\"referrer\"\n                                [href]=\"referrer?.url\"\n                            >\n                                {{ i18n.msgStr('backTo', referrer?.name) }}\n                            </a>\n                        }\n                        <li>\n                            <a [href]=\"url.getLogoutUrl()\">{{ i18n.msgStr('doSignOut') }}</a>\n                        </li>\n                    </ul>\n                </div>\n            </div>\n        </nav>\n    </header>\n\n    <div class=\"container\">\n        <div class=\"bs-sidebar col-sm-3\">\n            <ul>\n                <li [ngClass]=\"{ active: active === 'account' }\">\n                    <a [href]=\"url.accountUrl\">{{ i18n.msgStr('account') }}</a>\n                </li>\n                @if (features.passwordUpdateSupported) {\n                    <li [ngClass]=\"{ active: active === 'password' }\">\n                        <a [href]=\"url.passwordUrl\">{{ i18n.msgStr('password') }}</a>\n                    </li>\n                }\n                <li [ngClass]=\"{ active: active === 'totp' }\">\n                    <a [href]=\"url.totpUrl\">{{ i18n.msgStr('authenticator') }}</a>\n                </li>\n                @if (features.identityFederation) {\n                    <li [ngClass]=\"{ active: active === 'social' }\">\n                        <a [href]=\"url.socialUrl\">{{ i18n.msgStr('federatedIdentity') }}</a>\n                    </li>\n                }\n                <li [ngClass]=\"{ active: active === 'sessions' }\">\n                    <a [href]=\"url.sessionsUrl\">{{ i18n.msgStr('sessions') }}</a>\n                </li>\n                <li [ngClass]=\"{ active: active === 'applications' }\">\n                    <a [href]=\"url.applicationsUrl\">{{ i18n.msgStr('applications') }}</a>\n                </li>\n                @if (features.log) {\n                    <li [ngClass]=\"{ active: active === 'log' }\">\n                        <a [href]=\"url.logUrl\">{{ i18n.msgStr('log') }}</a>\n                    </li>\n                }\n                @if (realm.userManagedAccessAllowed && features.authorization) {\n                    <li [ngClass]=\"{ active: active === 'authorization' }\">\n                        <a [href]=\"url.resourceUrl\">{{ i18n.msgStr('myResources') }}</a>\n                    </li>\n                }\n            </ul>\n        </div>\n\n        <div class=\"col-sm-9 content-area\">\n            @if (message) {\n                <div [ngClass]=\"['alert', 'alert-' + message.type]\">\n                    @switch (message.type) {\n                        @case ('success') {\n                            <span class=\"pficon pficon-ok\"></span>\n                        }\n                        @case ('error') {\n                            <span class=\"pficon pficon-error-circle-o\"></span>\n                        }\n                    }\n                    <span\n                        class=\"kc-feedback-text\"\n                        [innerHTML]=\"message.summary | kcSanitize: 'html'\"\n                    ></span>\n                </div>\n            }\n            <!-- Content -->\n            <ng-template #pageRef></ng-template>\n        </div>\n    </div>\n}\n", dependencies: [{ kind: "pipe", type: AsyncPipe, name: "async" }, { kind: "pipe", type: KcSanitizePipe, name: "kcSanitize" }, { kind: "directive", type: NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: TemplateComponent, decorators: [{
            type: Component,
            args: [{ selector: 'kc-root', imports: [AsyncPipe, KcSanitizePipe, KcClassDirective, NgClass], changeDetection: ChangeDetectionStrategy.OnPush, providers: [
                        {
                            provide: ComponentReference,
                            useExisting: forwardRef(() => TemplateComponent)
                        }
                    ], template: "@let enabledLanguages = i18n.enabledLanguages;\n@let currentLanguage = i18n.currentLanguage;\n@let url = kcContext.url;\n@let features = kcContext.features;\n@let realm = kcContext.realm;\n@let message = kcContext.message;\n@let referrer = kcContext.referrer;\n@let isReadyToRender = isReadyToRender$ | async;\n\n@if (isReadyToRender) {\n    <header class=\"navbar navbar-default navbar-pf navbar-main header\">\n        <nav\n            class=\"navbar\"\n            role=\"navigation\"\n        >\n            <div class=\"navbar-header\">\n                <div class=\"container\">\n                    <h1 class=\"navbar-title\">Keycloak</h1>\n                </div>\n            </div>\n            <div class=\"navbar-collapse navbar-collapse-1\">\n                <div class=\"container\">\n                    <ul class=\"nav navbar-nav navbar-utility\">\n                        @if (enabledLanguages.length > 1) {\n                            <li>\n                                <div\n                                    class=\"kc-dropdown\"\n                                    id=\"kc-locale-dropdown\"\n                                >\n                                    <a\n                                        href=\"#\"\n                                        id=\"kc-current-locale-link\"\n                                    >\n                                        {{ currentLanguage.label }}\n                                    </a>\n                                    <ul>\n                                        @for (enabledLanguage of enabledLanguages; track enabledLanguage.languageTag) {\n                                            @let label = enabledLanguage.label;\n                                            @let href = enabledLanguage.href;\n\n                                            <li class=\"kc-dropdown-item\">\n                                                <a [href]=\"href\">{{ label }}</a>\n                                            </li>\n                                        }\n                                    </ul>\n                                </div>\n                            </li>\n                        }\n                        @if (!!referrer?.url) {\n                            <a\n                                id=\"referrer\"\n                                [href]=\"referrer?.url\"\n                            >\n                                {{ i18n.msgStr('backTo', referrer?.name) }}\n                            </a>\n                        }\n                        <li>\n                            <a [href]=\"url.getLogoutUrl()\">{{ i18n.msgStr('doSignOut') }}</a>\n                        </li>\n                    </ul>\n                </div>\n            </div>\n        </nav>\n    </header>\n\n    <div class=\"container\">\n        <div class=\"bs-sidebar col-sm-3\">\n            <ul>\n                <li [ngClass]=\"{ active: active === 'account' }\">\n                    <a [href]=\"url.accountUrl\">{{ i18n.msgStr('account') }}</a>\n                </li>\n                @if (features.passwordUpdateSupported) {\n                    <li [ngClass]=\"{ active: active === 'password' }\">\n                        <a [href]=\"url.passwordUrl\">{{ i18n.msgStr('password') }}</a>\n                    </li>\n                }\n                <li [ngClass]=\"{ active: active === 'totp' }\">\n                    <a [href]=\"url.totpUrl\">{{ i18n.msgStr('authenticator') }}</a>\n                </li>\n                @if (features.identityFederation) {\n                    <li [ngClass]=\"{ active: active === 'social' }\">\n                        <a [href]=\"url.socialUrl\">{{ i18n.msgStr('federatedIdentity') }}</a>\n                    </li>\n                }\n                <li [ngClass]=\"{ active: active === 'sessions' }\">\n                    <a [href]=\"url.sessionsUrl\">{{ i18n.msgStr('sessions') }}</a>\n                </li>\n                <li [ngClass]=\"{ active: active === 'applications' }\">\n                    <a [href]=\"url.applicationsUrl\">{{ i18n.msgStr('applications') }}</a>\n                </li>\n                @if (features.log) {\n                    <li [ngClass]=\"{ active: active === 'log' }\">\n                        <a [href]=\"url.logUrl\">{{ i18n.msgStr('log') }}</a>\n                    </li>\n                }\n                @if (realm.userManagedAccessAllowed && features.authorization) {\n                    <li [ngClass]=\"{ active: active === 'authorization' }\">\n                        <a [href]=\"url.resourceUrl\">{{ i18n.msgStr('myResources') }}</a>\n                    </li>\n                }\n            </ul>\n        </div>\n\n        <div class=\"col-sm-9 content-area\">\n            @if (message) {\n                <div [ngClass]=\"['alert', 'alert-' + message.type]\">\n                    @switch (message.type) {\n                        @case ('success') {\n                            <span class=\"pficon pficon-ok\"></span>\n                        }\n                        @case ('error') {\n                            <span class=\"pficon pficon-error-circle-o\"></span>\n                        }\n                    }\n                    <span\n                        class=\"kc-feedback-text\"\n                        [innerHTML]=\"message.summary | kcSanitize: 'html'\"\n                    ></span>\n                </div>\n            }\n            <!-- Content -->\n            <ng-template #pageRef></ng-template>\n        </div>\n    </div>\n}\n" }]
        }], ctorParameters: () => [] });

/**
 * Generated bundle index. Do not edit.
 */

export { TemplateComponent };
//# sourceMappingURL=keycloakify-angular-account-template.mjs.map
