import * as i0 from '@angular/core';
import { inject, RendererFactory2, Injectable } from '@angular/core';
import { Observable } from 'rxjs';

class ResourceInjectorService {
    constructor() {
        this.renderer = inject(RendererFactory2).createRenderer(null, null);
    }
    createLink(url) {
        return new Observable(observer => {
            // check if the style is already injected
            if (Array.from(document.styleSheets).some(s => s.href?.includes(url))) {
                observer.next();
                observer.complete();
                console.debug(`stylesheet: ${url} already loaded`);
                return;
            }
            const link = document.createElement('link');
            link.rel = 'stylesheet';
            link.href = url;
            link.onload = () => {
                observer.next();
                observer.complete();
            };
            link.onerror = () => {
                observer.error(new Error(`Failed to load stylesheet: ${url}`));
            };
            const head = document.head;
            head.insertBefore(link, head.firstChild);
        });
    }
    createScript({ type, id, src, textContent }) {
        // check if the script is already injected
        if (Array.from(document.scripts).some(s => s.id?.includes(id))) {
            console.debug(`script: ${src} already injected`);
            return;
        }
        const script = document.createElement('script');
        script.type = type;
        if (src)
            script.src = src;
        if (textContent)
            script.textContent = textContent;
        script.id = id;
        this.renderer.appendChild(document.head, script);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: ResourceInjectorService, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: ResourceInjectorService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: ResourceInjectorService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { ResourceInjectorService };
//# sourceMappingURL=keycloakify-angular-lib-services-resource-injector.mjs.map
