import * as i0 from '@angular/core';
import { input, output, inject, computed, forwardRef, ChangeDetectionStrategy, Component } from '@angular/core';
import { ToArrayPipe } from '@keycloakify/angular/lib/pipes/to-array';
import { USE_DEFAULT_CSS } from '@keycloakify/angular/lib/tokens/use-default-css';
import { ComponentReference } from '@keycloakify/angular/login/classes/component-reference';
import { InputTagComponent } from '@keycloakify/angular/login/components/input-tag';
import { InputTagSelectsComponent } from '@keycloakify/angular/login/components/input-tag-selects';
import { PasswordWrapperComponent } from '@keycloakify/angular/login/components/password-wrapper';
import { SelectTagComponent } from '@keycloakify/angular/login/components/select-tag';
import { TextareaTagComponent } from '@keycloakify/angular/login/components/textarea-tag';
import { LOGIN_CLASSES } from '@keycloakify/angular/login/tokens/classes';

class InputFieldByTypeComponent extends ComponentReference {
    constructor() {
        super(...arguments);
        this.attribute = input();
        this.valueOrValues = input();
        this.displayableErrors = input();
        this.dispatchFormAction = output();
        this.doUseDefaultCss = inject(USE_DEFAULT_CSS);
        this.classes = inject(LOGIN_CLASSES);
        this.attributePassword = computed(() => {
            const attribute = this.attribute() ?? {};
            return {
                ...attribute,
                annotations: { ...(attribute.annotations ?? {}), inputType: 'password' }
            };
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: InputFieldByTypeComponent, deps: null, target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "20.0.3", type: InputFieldByTypeComponent, isStandalone: true, selector: "kc-input-field-by-type", inputs: { attribute: { classPropertyName: "attribute", publicName: "attribute", isSignal: true, isRequired: false, transformFunction: null }, valueOrValues: { classPropertyName: "valueOrValues", publicName: "valueOrValues", isSignal: true, isRequired: false, transformFunction: null }, displayableErrors: { classPropertyName: "displayableErrors", publicName: "displayableErrors", isSignal: true, isRequired: false, transformFunction: null } }, outputs: { dispatchFormAction: "dispatchFormAction" }, providers: [
            {
                provide: ComponentReference,
                useExisting: forwardRef(() => InputFieldByTypeComponent)
            }
        ], usesInheritance: true, ngImport: i0, template: "@let attr = attribute();\n@if (attr) {\n    @let type = attr.annotations.inputType;\n    @switch (type) {\n        @case ('hidden') {\n            <input\n                type=\"hidden\"\n                [name]=\"attr.name\"\n                [value]=\"$any(valueOrValues())\"\n            />\n        }\n        @case ('textarea') {\n            <kc-textarea-tag\n                [attribute]=\"attribute()\"\n                [value]=\"$any(valueOrValues())\"\n                [displayableErrors]=\"displayableErrors()\"\n                (dispatchFormAction)=\"dispatchFormAction.emit($event)\"\n            />\n        }\n        @case (type === 'select' || type === 'multiselect' ? type : '') {\n            <kc-select-tag\n                [attribute]=\"attribute()\"\n                [valueOrValues]=\"valueOrValues()\"\n                [displayableErrors]=\"displayableErrors()\"\n                (dispatchFormAction)=\"dispatchFormAction.emit($event)\"\n            />\n        }\n        @case (type === 'select-radiobuttons' || type === 'multiselect-checkboxes' ? type : '') {\n            <kc-input-tag-selects\n                [attribute]=\"attribute()\"\n                [valueOrValues]=\"valueOrValues()\"\n                [displayableErrors]=\"displayableErrors()\"\n                (dispatchFormAction)=\"dispatchFormAction.emit($event)\"\n            />\n        }\n        @default {\n            @let values = valueOrValues();\n            <!-- if valueOrValues is string skip -->\n            @if (values && (values | toArray: true).length) {\n                @for (value of values; track value; let i = $index) {\n                    <kc-input-tag\n                        [attribute]=\"attribute()\"\n                        [valueOrValues]=\"valueOrValues()\"\n                        [fieldIndex]=\"i\"\n                        [displayableErrors]=\"displayableErrors()\"\n                        (dispatchFormAction)=\"dispatchFormAction.emit($event)\"\n                    />\n                }\n            } @else {\n                @if (attr.name === 'password' || attr.name === 'password-confirm') {\n                    <kc-password-wrapper [passwordInputId]=\"attr.name\">\n                        <kc-input-tag\n                            [attribute]=\"attributePassword()\"\n                            [valueOrValues]=\"valueOrValues()\"\n                            [displayableErrors]=\"displayableErrors()\"\n                            (dispatchFormAction)=\"dispatchFormAction.emit($event)\"\n                        />\n                    </kc-password-wrapper>\n                } @else {\n                    <kc-input-tag\n                        [attribute]=\"attribute()\"\n                        [valueOrValues]=\"valueOrValues()\"\n                        [displayableErrors]=\"displayableErrors()\"\n                        (dispatchFormAction)=\"dispatchFormAction.emit($event)\"\n                    />\n                }\n            }\n        }\n    }\n}\n", styles: [":host{display:contents}\n"], dependencies: [{ kind: "pipe", type: ToArrayPipe, name: "toArray" }, { kind: "component", type: TextareaTagComponent, selector: "kc-textarea-tag", inputs: ["attribute", "value", "displayableErrors"], outputs: ["dispatchFormAction"] }, { kind: "component", type: SelectTagComponent, selector: "kc-select-tag", inputs: ["attribute", "valueOrValues", "displayableErrors"], outputs: ["dispatchFormAction"] }, { kind: "component", type: InputTagSelectsComponent, selector: "kc-input-tag-selects", inputs: ["attribute", "valueOrValues", "displayableErrors"], outputs: ["dispatchFormAction"] }, { kind: "component", type: InputTagComponent, selector: "kc-input-tag", inputs: ["attribute", "valueOrValues", "fieldIndex", "values", "displayableErrors"], outputs: ["dispatchFormAction"] }, { kind: "component", type: PasswordWrapperComponent, selector: "kc-password-wrapper", inputs: ["passwordInputId"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: InputFieldByTypeComponent, decorators: [{
            type: Component,
            args: [{ imports: [ToArrayPipe, TextareaTagComponent, SelectTagComponent, InputTagSelectsComponent, InputTagComponent, PasswordWrapperComponent], selector: 'kc-input-field-by-type', changeDetection: ChangeDetectionStrategy.OnPush, providers: [
                        {
                            provide: ComponentReference,
                            useExisting: forwardRef(() => InputFieldByTypeComponent)
                        }
                    ], template: "@let attr = attribute();\n@if (attr) {\n    @let type = attr.annotations.inputType;\n    @switch (type) {\n        @case ('hidden') {\n            <input\n                type=\"hidden\"\n                [name]=\"attr.name\"\n                [value]=\"$any(valueOrValues())\"\n            />\n        }\n        @case ('textarea') {\n            <kc-textarea-tag\n                [attribute]=\"attribute()\"\n                [value]=\"$any(valueOrValues())\"\n                [displayableErrors]=\"displayableErrors()\"\n                (dispatchFormAction)=\"dispatchFormAction.emit($event)\"\n            />\n        }\n        @case (type === 'select' || type === 'multiselect' ? type : '') {\n            <kc-select-tag\n                [attribute]=\"attribute()\"\n                [valueOrValues]=\"valueOrValues()\"\n                [displayableErrors]=\"displayableErrors()\"\n                (dispatchFormAction)=\"dispatchFormAction.emit($event)\"\n            />\n        }\n        @case (type === 'select-radiobuttons' || type === 'multiselect-checkboxes' ? type : '') {\n            <kc-input-tag-selects\n                [attribute]=\"attribute()\"\n                [valueOrValues]=\"valueOrValues()\"\n                [displayableErrors]=\"displayableErrors()\"\n                (dispatchFormAction)=\"dispatchFormAction.emit($event)\"\n            />\n        }\n        @default {\n            @let values = valueOrValues();\n            <!-- if valueOrValues is string skip -->\n            @if (values && (values | toArray: true).length) {\n                @for (value of values; track value; let i = $index) {\n                    <kc-input-tag\n                        [attribute]=\"attribute()\"\n                        [valueOrValues]=\"valueOrValues()\"\n                        [fieldIndex]=\"i\"\n                        [displayableErrors]=\"displayableErrors()\"\n                        (dispatchFormAction)=\"dispatchFormAction.emit($event)\"\n                    />\n                }\n            } @else {\n                @if (attr.name === 'password' || attr.name === 'password-confirm') {\n                    <kc-password-wrapper [passwordInputId]=\"attr.name\">\n                        <kc-input-tag\n                            [attribute]=\"attributePassword()\"\n                            [valueOrValues]=\"valueOrValues()\"\n                            [displayableErrors]=\"displayableErrors()\"\n                            (dispatchFormAction)=\"dispatchFormAction.emit($event)\"\n                        />\n                    </kc-password-wrapper>\n                } @else {\n                    <kc-input-tag\n                        [attribute]=\"attribute()\"\n                        [valueOrValues]=\"valueOrValues()\"\n                        [displayableErrors]=\"displayableErrors()\"\n                        (dispatchFormAction)=\"dispatchFormAction.emit($event)\"\n                    />\n                }\n            }\n        }\n    }\n}\n", styles: [":host{display:contents}\n"] }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { InputFieldByTypeComponent };
//# sourceMappingURL=keycloakify-angular-login-components-input-field-by-type.mjs.map
