import * as i0 from '@angular/core';
import { inject, input, output, computed, forwardRef, ChangeDetectionStrategy, Component } from '@angular/core';
import { USE_DEFAULT_CSS } from '@keycloakify/angular/lib/tokens/use-default-css';
import { ComponentReference } from '@keycloakify/angular/login/classes/component-reference';
import { KcClassDirective } from '@keycloakify/angular/login/directives/kc-class';
import { LOGIN_CLASSES } from '@keycloakify/angular/login/tokens/classes';
import { LOGIN_I18N } from '@keycloakify/angular/login/tokens/i18n';

class InputTagSelectsComponent extends ComponentReference {
    constructor() {
        super(...arguments);
        this.i18n = inject(LOGIN_I18N);
        this.attribute = input();
        this.valueOrValues = input();
        this.dispatchFormAction = output();
        this.displayableErrors = input();
        this.doUseDefaultCss = inject(USE_DEFAULT_CSS);
        this.classes = inject(LOGIN_CLASSES);
        this.context = computed(() => {
            const attribute = this.attribute();
            if (attribute) {
                const { inputType } = attribute.annotations;
                switch (inputType) {
                    case 'select-radiobuttons':
                        return {
                            inputType: 'radio',
                            classDiv: 'kcInputClassRadio',
                            classInput: 'kcInputClassRadioInput',
                            classLabel: 'kcInputClassRadioLabel'
                        };
                    case 'multiselect-checkboxes':
                        return {
                            inputType: 'checkbox',
                            classDiv: 'kcInputClassCheckbox',
                            classInput: 'kcInputClassCheckboxInput',
                            classLabel: 'kcInputClassCheckboxLabel'
                        };
                }
            }
            return null;
        });
        this.options = computed(() => {
            const attribute = this.attribute();
            if (attribute) {
                return (() => {
                    walk: {
                        const { inputOptionsFromValidation } = attribute.annotations;
                        if (inputOptionsFromValidation === undefined) {
                            break walk;
                        }
                        const validator = attribute.validators[inputOptionsFromValidation];
                        if (validator === undefined) {
                            break walk;
                        }
                        if (validator.options === undefined) {
                            break walk;
                        }
                        return validator.options;
                    }
                    return attribute.validators.options?.options ?? [];
                })();
            }
            return [];
        });
    }
    checked(option) {
        const valueOrValues = this.valueOrValues();
        if (valueOrValues instanceof Array) {
            return valueOrValues.includes(option);
        }
        return valueOrValues === option;
    }
    onChange(event, option) {
        const valueOrValues = this.valueOrValues();
        const isChecked = event.target.checked;
        this.dispatchFormAction.emit({
            action: 'update',
            name: this.attribute()?.name ?? '',
            valueOrValues: (() => {
                if (valueOrValues instanceof Array) {
                    const newValues = [...valueOrValues];
                    if (isChecked) {
                        newValues.push(option);
                    }
                    else {
                        newValues.splice(newValues.indexOf(option), 1);
                    }
                    return newValues;
                }
                return event.target?.checked ? option : '';
            })()
        });
    }
    onBlur() {
        this.dispatchFormAction.emit({
            action: 'focus lost',
            name: this.attribute()?.name ?? '',
            fieldIndex: undefined
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: InputTagSelectsComponent, deps: null, target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "20.0.3", type: InputTagSelectsComponent, isStandalone: true, selector: "kc-input-tag-selects", inputs: { attribute: { classPropertyName: "attribute", publicName: "attribute", isSignal: true, isRequired: false, transformFunction: null }, valueOrValues: { classPropertyName: "valueOrValues", publicName: "valueOrValues", isSignal: true, isRequired: false, transformFunction: null }, displayableErrors: { classPropertyName: "displayableErrors", publicName: "displayableErrors", isSignal: true, isRequired: false, transformFunction: null } }, outputs: { dispatchFormAction: "dispatchFormAction" }, providers: [
            {
                provide: ComponentReference,
                useExisting: forwardRef(() => InputTagSelectsComponent)
            }
        ], usesInheritance: true, ngImport: i0, template: "@let inputType = context()?.inputType;\n@let classInput = context()?.classInput;\n@let classLabel = context()?.classLabel;\n@let classDiv = context()?.classDiv;\n@let attr = attribute();\n@if (attr) {\n    @for (option of options(); track option) {\n        <div [kcClass]=\"classDiv\">\n            <input\n                [type]=\"inputType\"\n                [id]=\"attr.name + '-' + option\"\n                [name]=\"attr.name\"\n                [value]=\"option\"\n                [kcClass]=\"classInput\"\n                [attr.aria-invalid]=\"!!displayableErrors()?.length\"\n                [disabled]=\"attr.readOnly\"\n                [checked]=\"checked(option)\"\n                (change)=\"onChange($event, option)\"\n                (blur)=\"onBlur()\"\n            />\n            <label\n                [for]=\"attr.name + '-' + option\"\n                [kcClass]=\"[classLabel!, attr.readOnly ? 'kcInputClassRadioCheckboxLabelDisabled' : $any('')]\"\n            >\n                {{ i18n.advancedMsgStr(option) }}\n            </label>\n        </div>\n    }\n}\n", styles: [":host{display:contents}\n"], dependencies: [{ kind: "directive", type: KcClassDirective, selector: "[kcClass]", inputs: ["class", "ngClass", "kcClass"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: InputTagSelectsComponent, decorators: [{
            type: Component,
            args: [{ imports: [KcClassDirective], selector: 'kc-input-tag-selects', changeDetection: ChangeDetectionStrategy.OnPush, providers: [
                        {
                            provide: ComponentReference,
                            useExisting: forwardRef(() => InputTagSelectsComponent)
                        }
                    ], template: "@let inputType = context()?.inputType;\n@let classInput = context()?.classInput;\n@let classLabel = context()?.classLabel;\n@let classDiv = context()?.classDiv;\n@let attr = attribute();\n@if (attr) {\n    @for (option of options(); track option) {\n        <div [kcClass]=\"classDiv\">\n            <input\n                [type]=\"inputType\"\n                [id]=\"attr.name + '-' + option\"\n                [name]=\"attr.name\"\n                [value]=\"option\"\n                [kcClass]=\"classInput\"\n                [attr.aria-invalid]=\"!!displayableErrors()?.length\"\n                [disabled]=\"attr.readOnly\"\n                [checked]=\"checked(option)\"\n                (change)=\"onChange($event, option)\"\n                (blur)=\"onBlur()\"\n            />\n            <label\n                [for]=\"attr.name + '-' + option\"\n                [kcClass]=\"[classLabel!, attr.readOnly ? 'kcInputClassRadioCheckboxLabelDisabled' : $any('')]\"\n            >\n                {{ i18n.advancedMsgStr(option) }}\n            </label>\n        </div>\n    }\n}\n", styles: [":host{display:contents}\n"] }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { InputTagSelectsComponent };
//# sourceMappingURL=keycloakify-angular-login-components-input-tag-selects.mjs.map
