import * as i0 from '@angular/core';
import { inject, input, output, computed, forwardRef, ChangeDetectionStrategy, Component } from '@angular/core';
import { AttributesDirective } from '@keycloakify/angular/lib/directives/attributes';
import { InputTypePipe } from '@keycloakify/angular/lib/pipes/input-type';
import { ToArrayPipe } from '@keycloakify/angular/lib/pipes/to-array';
import { ToNumberPipe } from '@keycloakify/angular/lib/pipes/to-number';
import { USE_DEFAULT_CSS } from '@keycloakify/angular/lib/tokens/use-default-css';
import { ComponentReference } from '@keycloakify/angular/login/classes/component-reference';
import { AddRemoveButtonsMultiValuedAttributeComponent } from '@keycloakify/angular/login/components/add-remove-buttons-multi-valued-attribute';
import { FieldErrorsComponent } from '@keycloakify/angular/login/components/field-errors';
import { KcClassDirective } from '@keycloakify/angular/login/directives/kc-class';
import { LOGIN_CLASSES } from '@keycloakify/angular/login/tokens/classes';
import { LOGIN_I18N } from '@keycloakify/angular/login/tokens/i18n';

class InputTagComponent extends ComponentReference {
    constructor() {
        super(...arguments);
        this.i18n = inject(LOGIN_I18N);
        this.attribute = input();
        this.valueOrValues = input();
        this.fieldIndex = input(undefined);
        this.values = input();
        this.displayableErrors = input();
        this.dispatchFormAction = output();
        this.doUseDefaultCss = inject(USE_DEFAULT_CSS);
        this.classes = inject(LOGIN_CLASSES);
        this.value = computed(() => {
            const valueOrValues = this.valueOrValues();
            const index = this.fieldIndex();
            if (valueOrValues instanceof Array) {
                if (index) {
                    return valueOrValues[index] ?? null;
                }
                return null;
            }
            return valueOrValues ?? null;
        });
    }
    onChange(event) {
        const valueOrValues = this.valueOrValues();
        this.dispatchFormAction.emit({
            action: 'update',
            name: this.attribute()?.name ?? '',
            valueOrValues: (() => {
                if (this.fieldIndex !== undefined) {
                    if (valueOrValues instanceof Array) {
                        return valueOrValues.map((value, i) => {
                            if (i === this.fieldIndex()) {
                                return event.target?.value;
                            }
                            return value;
                        });
                    }
                }
                return event.target?.value;
            })()
        });
    }
    onBlur() {
        this.dispatchFormAction.emit({
            action: 'focus lost',
            name: this.attribute()?.name ?? '',
            fieldIndex: this.fieldIndex()
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: InputTagComponent, deps: null, target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "20.0.3", type: InputTagComponent, isStandalone: true, selector: "kc-input-tag", inputs: { attribute: { classPropertyName: "attribute", publicName: "attribute", isSignal: true, isRequired: false, transformFunction: null }, valueOrValues: { classPropertyName: "valueOrValues", publicName: "valueOrValues", isSignal: true, isRequired: false, transformFunction: null }, fieldIndex: { classPropertyName: "fieldIndex", publicName: "fieldIndex", isSignal: true, isRequired: false, transformFunction: null }, values: { classPropertyName: "values", publicName: "values", isSignal: true, isRequired: false, transformFunction: null }, displayableErrors: { classPropertyName: "displayableErrors", publicName: "displayableErrors", isSignal: true, isRequired: false, transformFunction: null } }, outputs: { dispatchFormAction: "dispatchFormAction" }, providers: [
            {
                provide: ComponentReference,
                useExisting: forwardRef(() => InputTagComponent)
            }
        ], usesInheritance: true, ngImport: i0, template: "@let attr = attribute();\n@let index = fieldIndex();\n@if (attr) {\n    <input\n        [type]=\"attr.annotations.inputType | inputType\"\n        [id]=\"attr.name\"\n        [name]=\"attr.name\"\n        [value]=\"value()\"\n        [kcClass]=\"'kcInputClass'\"\n        [attr.aria-invalid]=\"index && displayableErrors()?.[index] !== undefined\"\n        [disabled]=\"attr.readOnly\"\n        [autocomplete]=\"attr.autocomplete\"\n        [placeholder]=\"i18n.advancedMsgStr(attr.annotations.inputTypePlaceholder ?? '')\"\n        [attr.pattern]=\"attr.annotations.inputTypePattern\"\n        [attr.size]=\"\n            !attr.annotations.inputTypeSize\n                ? undefined\n                : (attr.annotations.inputTypeSize | toNumber) === 0\n                  ? undefined\n                  : (attr.annotations.inputTypeSize | toNumber)\n        \"\n        [attr.maxlength]=\"!attr.annotations.inputTypeMaxlength ? undefined : (attr.annotations.inputTypeMaxlength | toNumber)\"\n        [attr.minlength]=\"!attr.annotations.inputTypeMinlength ? undefined : (attr.annotations.inputTypeMinlength | toNumber)\"\n        [attr.max]=\"attr.annotations.inputTypeMax\"\n        [attr.min]=\"attr.annotations.inputTypeMin\"\n        [attr.step]=\"attr.annotations.inputTypeStep\"\n        [kcAttributes]=\"attr.html5DataAnnotations\"\n        (change)=\"onChange($event)\"\n        (blur)=\"onBlur()\"\n    />\n    @if (index !== undefined) {\n        @let values = valueOrValues() ?? [] | toArray;\n        <kc-field-errors\n            [attribute]=\"attr\"\n            [displayableErrors]=\"displayableErrors()\"\n            [fieldIndex]=\"index\"\n        />\n        <kc-add-remove-buttons-multi-valued-attribute\n            [attribute]=\"attr\"\n            [values]=\"values\"\n            [fieldIndex]=\"index\"\n            (dispatchFormAction)=\"dispatchFormAction.emit($event)\"\n        />\n    }\n}\n", styles: [":host{display:contents}\n"], dependencies: [{ kind: "pipe", type: InputTypePipe, name: "inputType" }, { kind: "directive", type: KcClassDirective, selector: "[kcClass]", inputs: ["class", "ngClass", "kcClass"] }, { kind: "pipe", type: ToNumberPipe, name: "toNumber" }, { kind: "directive", type: AttributesDirective, selector: "[kcAttributes]", inputs: ["kcAttributes"] }, { kind: "pipe", type: ToArrayPipe, name: "toArray" }, { kind: "component", type: FieldErrorsComponent, selector: "kc-field-errors", inputs: ["attribute", "displayableErrors", "fieldIndex"] }, { kind: "component", type: AddRemoveButtonsMultiValuedAttributeComponent, selector: "kc-add-remove-buttons-multi-valued-attribute", inputs: ["attribute", "values", "fieldIndex"], outputs: ["dispatchFormAction"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: InputTagComponent, decorators: [{
            type: Component,
            args: [{ imports: [
                        InputTypePipe,
                        KcClassDirective,
                        ToNumberPipe,
                        AttributesDirective,
                        ToArrayPipe,
                        FieldErrorsComponent,
                        AddRemoveButtonsMultiValuedAttributeComponent
                    ], selector: 'kc-input-tag', changeDetection: ChangeDetectionStrategy.OnPush, providers: [
                        {
                            provide: ComponentReference,
                            useExisting: forwardRef(() => InputTagComponent)
                        }
                    ], template: "@let attr = attribute();\n@let index = fieldIndex();\n@if (attr) {\n    <input\n        [type]=\"attr.annotations.inputType | inputType\"\n        [id]=\"attr.name\"\n        [name]=\"attr.name\"\n        [value]=\"value()\"\n        [kcClass]=\"'kcInputClass'\"\n        [attr.aria-invalid]=\"index && displayableErrors()?.[index] !== undefined\"\n        [disabled]=\"attr.readOnly\"\n        [autocomplete]=\"attr.autocomplete\"\n        [placeholder]=\"i18n.advancedMsgStr(attr.annotations.inputTypePlaceholder ?? '')\"\n        [attr.pattern]=\"attr.annotations.inputTypePattern\"\n        [attr.size]=\"\n            !attr.annotations.inputTypeSize\n                ? undefined\n                : (attr.annotations.inputTypeSize | toNumber) === 0\n                  ? undefined\n                  : (attr.annotations.inputTypeSize | toNumber)\n        \"\n        [attr.maxlength]=\"!attr.annotations.inputTypeMaxlength ? undefined : (attr.annotations.inputTypeMaxlength | toNumber)\"\n        [attr.minlength]=\"!attr.annotations.inputTypeMinlength ? undefined : (attr.annotations.inputTypeMinlength | toNumber)\"\n        [attr.max]=\"attr.annotations.inputTypeMax\"\n        [attr.min]=\"attr.annotations.inputTypeMin\"\n        [attr.step]=\"attr.annotations.inputTypeStep\"\n        [kcAttributes]=\"attr.html5DataAnnotations\"\n        (change)=\"onChange($event)\"\n        (blur)=\"onBlur()\"\n    />\n    @if (index !== undefined) {\n        @let values = valueOrValues() ?? [] | toArray;\n        <kc-field-errors\n            [attribute]=\"attr\"\n            [displayableErrors]=\"displayableErrors()\"\n            [fieldIndex]=\"index\"\n        />\n        <kc-add-remove-buttons-multi-valued-attribute\n            [attribute]=\"attr\"\n            [values]=\"values\"\n            [fieldIndex]=\"index\"\n            (dispatchFormAction)=\"dispatchFormAction.emit($event)\"\n        />\n    }\n}\n", styles: [":host{display:contents}\n"] }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { InputTagComponent };
//# sourceMappingURL=keycloakify-angular-login-components-input-tag.mjs.map
