import * as i0 from '@angular/core';
import { inject, input, output, computed, forwardRef, ChangeDetectionStrategy, Component } from '@angular/core';
import { USE_DEFAULT_CSS } from '@keycloakify/angular/lib/tokens/use-default-css';
import { ComponentReference } from '@keycloakify/angular/login/classes/component-reference';
import { KcClassDirective } from '@keycloakify/angular/login/directives/kc-class';
import { ToNumberPipe } from '@keycloakify/angular/lib/pipes/to-number';
import { LOGIN_CLASSES } from '@keycloakify/angular/login/tokens/classes';
import { LOGIN_I18N } from '@keycloakify/angular/login/tokens/i18n';

class SelectTagComponent extends ComponentReference {
    constructor() {
        super(...arguments);
        this.i18n = inject(LOGIN_I18N);
        this.attribute = input();
        this.valueOrValues = input();
        this.displayableErrors = input();
        this.dispatchFormAction = output();
        this.doUseDefaultCss = inject(USE_DEFAULT_CSS);
        this.classes = inject(LOGIN_CLASSES);
        this.isMultiple = computed(() => {
            return this.attribute()?.annotations?.inputType === 'multiselect';
        });
        this.options = computed(() => {
            const attribute = this.attribute();
            if (attribute) {
                return (() => {
                    walk: {
                        const { inputOptionsFromValidation } = attribute.annotations;
                        if (inputOptionsFromValidation === undefined) {
                            break walk;
                        }
                        const validator = attribute.validators[inputOptionsFromValidation];
                        if (validator === undefined) {
                            break walk;
                        }
                        if (validator.options === undefined) {
                            break walk;
                        }
                        return validator.options;
                    }
                    return attribute.validators.options?.options ?? [];
                })();
            }
            return [];
        });
    }
    onChange(event) {
        this.dispatchFormAction.emit({
            action: 'update',
            name: this.attribute()?.name ?? '',
            valueOrValues: (() => {
                if (this.isMultiple()) {
                    return Array.from(event.target.selectedOptions).map(option => option.value);
                }
                return event.target.value;
            })()
        });
    }
    onBlur() {
        this.dispatchFormAction.emit({
            action: 'focus lost',
            name: this.attribute()?.name ?? '',
            fieldIndex: undefined
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: SelectTagComponent, deps: null, target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "20.0.3", type: SelectTagComponent, isStandalone: true, selector: "kc-select-tag", inputs: { attribute: { classPropertyName: "attribute", publicName: "attribute", isSignal: true, isRequired: false, transformFunction: null }, valueOrValues: { classPropertyName: "valueOrValues", publicName: "valueOrValues", isSignal: true, isRequired: false, transformFunction: null }, displayableErrors: { classPropertyName: "displayableErrors", publicName: "displayableErrors", isSignal: true, isRequired: false, transformFunction: null } }, outputs: { dispatchFormAction: "dispatchFormAction" }, providers: [
            {
                provide: ComponentReference,
                useExisting: forwardRef(() => SelectTagComponent)
            }
        ], usesInheritance: true, ngImport: i0, template: "@let attr = attribute();\n@let multiple = isMultiple();\n@if (attr) {\n    <select\n        [id]=\"attr.name\"\n        [name]=\"attr.name\"\n        [value]=\"valueOrValues()\"\n        [kcClass]=\"'kcInputClass'\"\n        [attr.aria-invalid]=\"!!displayableErrors()?.length\"\n        [disabled]=\"attr.readOnly\"\n        [multiple]=\"multiple\"\n        [size]=\"!attr.annotations.inputTypeSize ? undefined : (attr.annotations.inputTypeSize | toNumber)\"\n        (change)=\"onChange($event)\"\n        (blur)=\"onBlur()\"\n    >\n        @if (!multiple) {\n            <option value=\"\"></option>\n        }\n        @for (option of options(); track option) {\n            <option [value]=\"option\">\n                @if (!!attr.annotations.inputOptionLabels) {\n                    {{ i18n.advancedMsgStr(attr.annotations.inputOptionLabels[option] ?? option) }}\n                } @else if (!!attr.annotations.inputOptionLabelsI18nPrefix) {\n                    {{ i18n.advancedMsgStr(attr.annotations.inputOptionLabelsI18nPrefix + '.' + option) }}\n                } @else {\n                    {{ option }}\n                }\n            </option>\n        }\n    </select>\n}\n", styles: [":host{display:contents}\n"], dependencies: [{ kind: "directive", type: KcClassDirective, selector: "[kcClass]", inputs: ["class", "ngClass", "kcClass"] }, { kind: "pipe", type: ToNumberPipe, name: "toNumber" }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: SelectTagComponent, decorators: [{
            type: Component,
            args: [{ imports: [KcClassDirective, ToNumberPipe], selector: 'kc-select-tag', changeDetection: ChangeDetectionStrategy.OnPush, providers: [
                        {
                            provide: ComponentReference,
                            useExisting: forwardRef(() => SelectTagComponent)
                        }
                    ], template: "@let attr = attribute();\n@let multiple = isMultiple();\n@if (attr) {\n    <select\n        [id]=\"attr.name\"\n        [name]=\"attr.name\"\n        [value]=\"valueOrValues()\"\n        [kcClass]=\"'kcInputClass'\"\n        [attr.aria-invalid]=\"!!displayableErrors()?.length\"\n        [disabled]=\"attr.readOnly\"\n        [multiple]=\"multiple\"\n        [size]=\"!attr.annotations.inputTypeSize ? undefined : (attr.annotations.inputTypeSize | toNumber)\"\n        (change)=\"onChange($event)\"\n        (blur)=\"onBlur()\"\n    >\n        @if (!multiple) {\n            <option value=\"\"></option>\n        }\n        @for (option of options(); track option) {\n            <option [value]=\"option\">\n                @if (!!attr.annotations.inputOptionLabels) {\n                    {{ i18n.advancedMsgStr(attr.annotations.inputOptionLabels[option] ?? option) }}\n                } @else if (!!attr.annotations.inputOptionLabelsI18nPrefix) {\n                    {{ i18n.advancedMsgStr(attr.annotations.inputOptionLabelsI18nPrefix + '.' + option) }}\n                } @else {\n                    {{ option }}\n                }\n            </option>\n        }\n    </select>\n}\n", styles: [":host{display:contents}\n"] }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { SelectTagComponent };
//# sourceMappingURL=keycloakify-angular-login-components-select-tag.mjs.map
