import { NgTemplateOutlet, AsyncPipe } from '@angular/common';
import * as i0 from '@angular/core';
import { inject, forwardRef, ContentChild, ChangeDetectionStrategy, Component } from '@angular/core';
import { USE_DEFAULT_CSS } from '@keycloakify/angular/lib/tokens/use-default-css';
import { ComponentReference } from '@keycloakify/angular/login/classes/component-reference';
import { FieldErrorsComponent } from '@keycloakify/angular/login/components/field-errors';
import { GroupLabelComponent } from '@keycloakify/angular/login/components/group-label';
import { InputFieldByTypeComponent } from '@keycloakify/angular/login/components/input-field-by-type';
import { KcClassDirective } from '@keycloakify/angular/login/directives/kc-class';
import { UserProfileFormService } from '@keycloakify/angular/login/services/user-profile-form';
import { LOGIN_CLASSES } from '@keycloakify/angular/login/tokens/classes';
import { LOGIN_I18N } from '@keycloakify/angular/login/tokens/i18n';
import { KC_LOGIN_CONTEXT } from '@keycloakify/angular/login/tokens/kc-context';
import { DO_MAKE_USER_CONFIRM_PASSWORD } from '@keycloakify/angular/login/tokens/make-user-confirm-password';
import { map } from 'rxjs';

class UserProfileFormFieldsComponent extends ComponentReference {
    constructor() {
        super(...arguments);
        this.i18n = inject(LOGIN_I18N);
        this.kcContext = inject(KC_LOGIN_CONTEXT);
        this.#userProfileFormService = inject(UserProfileFormService);
        this.doMakeUserConfirmPassword = inject(DO_MAKE_USER_CONFIRM_PASSWORD);
        this.doUseDefaultCss = inject(USE_DEFAULT_CSS);
        this.classes = inject(LOGIN_CLASSES);
        this.formState$ = this.#userProfileFormService.formState$;
        this.xAttributeLocale$ = this.formState$.pipe(map(s => s.formFieldStates.find(x => x.attribute.name === 'locale')));
    }
    #userProfileFormService;
    onDispatch(formAction) {
        this.#userProfileFormService.dispatchFormAction(formAction);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: UserProfileFormFieldsComponent, deps: null, target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "20.0.3", type: UserProfileFormFieldsComponent, isStandalone: true, selector: "kc-user-profile-form-fields", providers: [
            UserProfileFormService,
            {
                provide: ComponentReference,
                useExisting: forwardRef(() => UserProfileFormFieldsComponent)
            }
        ], queries: [{ propertyName: "beforeField", first: true, predicate: ["beforeField"], descendants: true }, { propertyName: "afterField", first: true, predicate: ["afterField"], descendants: true }], usesInheritance: true, ngImport: i0, template: "@let formState = formState$ | async;\n@let xAttributeLocale = xAttributeLocale$ | async;\n@if (formState) {\n    @let formFieldStates = formState.formFieldStates;\n\n    @for (fieldState of formFieldStates; track fieldState.attribute) {\n        <kc-group-label [attribute]=\"fieldState.attribute\" />\n\n        @if (beforeField) {\n            <ng-container\n                [ngTemplateOutlet]=\"beforeField\"\n                [ngTemplateOutletContext]=\"{\n                    attribute: fieldState.attribute,\n                    valueOrValues: fieldState.valueOrValues,\n                    displayableErrors: fieldState.displayableErrors\n                }\"\n            />\n        }\n\n        <div\n            [kcClass]=\"'kcFormGroupClass'\"\n            [style.display]=\"\n                fieldState.attribute.annotations.inputType === 'hidden' ||\n                (fieldState.attribute.name === 'password-confirm' && !doMakeUserConfirmPassword)\n                    ? 'none'\n                    : 'block'\n            \"\n        >\n            <div [kcClass]=\"'kcLabelWrapperClass'\">\n                <label\n                    [for]=\"fieldState.attribute.name\"\n                    [kcClass]=\"'kcLabelClass'\"\n                >\n                    {{ i18n.advancedMsgStr(fieldState.attribute.displayName ?? '') }}\n                    @if (fieldState.attribute.required) {\n                        *\n                    }\n                </label>\n            </div>\n\n            <div [kcClass]=\"'kcInputWrapperClass'\">\n                @if (fieldState.attribute.annotations.inputHelperTextBefore) {\n                    <div\n                        aria-live=\"polite\"\n                        [kcClass]=\"'kcInputHelperTextBeforeClass'\"\n                        [id]=\"'form-help-text-before-' + fieldState.attribute.name\"\n                    >\n                        {{ i18n.advancedMsgStr(fieldState.attribute.annotations.inputHelperTextBefore) }}\n                    </div>\n                }\n\n                <kc-input-field-by-type\n                    [attribute]=\"fieldState.attribute\"\n                    [valueOrValues]=\"fieldState.valueOrValues\"\n                    [displayableErrors]=\"fieldState.displayableErrors\"\n                    (dispatchFormAction)=\"onDispatch($event)\"\n                />\n\n                <kc-field-errors\n                    [attribute]=\"fieldState.attribute\"\n                    [displayableErrors]=\"fieldState.displayableErrors\"\n                />\n                @if (fieldState.attribute.annotations.inputHelperTextAfter) {\n                    <div\n                        aria-live=\"polite\"\n                        [kcClass]=\"'kcInputHelperTextAfterClass'\"\n                        [id]=\"'form-help-text-after-' + fieldState.attribute.name\"\n                    >\n                        {{ i18n.advancedMsgStr(fieldState.attribute.annotations.inputHelperTextAfter) }}\n                    </div>\n                }\n\n                @if (afterField) {\n                    <ng-container\n                        [ngTemplateOutlet]=\"afterField\"\n                        [ngTemplateOutletContext]=\"{\n                            attribute: fieldState.attribute,\n                            valueOrValues: fieldState.valueOrValues,\n                            displayableErrors: fieldState.displayableErrors\n                        }\"\n                    />\n                }\n                <!-- NOTE: Downloading of html5DataAnnotations scripts is done in the useUserProfileForm hook -->\n            </div>\n        </div>\n    }\n}\n", styles: [":host{display:contents}\n"], dependencies: [{ kind: "directive", type: KcClassDirective, selector: "[kcClass]", inputs: ["class", "ngClass", "kcClass"] }, { kind: "component", type: FieldErrorsComponent, selector: "kc-field-errors", inputs: ["attribute", "displayableErrors", "fieldIndex"] }, { kind: "component", type: InputFieldByTypeComponent, selector: "kc-input-field-by-type", inputs: ["attribute", "valueOrValues", "displayableErrors"], outputs: ["dispatchFormAction"] }, { kind: "component", type: GroupLabelComponent, selector: "kc-group-label", inputs: ["attribute", "groupName"] }, { kind: "directive", type: NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }, { kind: "pipe", type: AsyncPipe, name: "async" }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: UserProfileFormFieldsComponent, decorators: [{
            type: Component,
            args: [{ imports: [KcClassDirective, FieldErrorsComponent, InputFieldByTypeComponent, GroupLabelComponent, NgTemplateOutlet, AsyncPipe], selector: 'kc-user-profile-form-fields', changeDetection: ChangeDetectionStrategy.OnPush, providers: [
                        UserProfileFormService,
                        {
                            provide: ComponentReference,
                            useExisting: forwardRef(() => UserProfileFormFieldsComponent)
                        }
                    ], template: "@let formState = formState$ | async;\n@let xAttributeLocale = xAttributeLocale$ | async;\n@if (formState) {\n    @let formFieldStates = formState.formFieldStates;\n\n    @for (fieldState of formFieldStates; track fieldState.attribute) {\n        <kc-group-label [attribute]=\"fieldState.attribute\" />\n\n        @if (beforeField) {\n            <ng-container\n                [ngTemplateOutlet]=\"beforeField\"\n                [ngTemplateOutletContext]=\"{\n                    attribute: fieldState.attribute,\n                    valueOrValues: fieldState.valueOrValues,\n                    displayableErrors: fieldState.displayableErrors\n                }\"\n            />\n        }\n\n        <div\n            [kcClass]=\"'kcFormGroupClass'\"\n            [style.display]=\"\n                fieldState.attribute.annotations.inputType === 'hidden' ||\n                (fieldState.attribute.name === 'password-confirm' && !doMakeUserConfirmPassword)\n                    ? 'none'\n                    : 'block'\n            \"\n        >\n            <div [kcClass]=\"'kcLabelWrapperClass'\">\n                <label\n                    [for]=\"fieldState.attribute.name\"\n                    [kcClass]=\"'kcLabelClass'\"\n                >\n                    {{ i18n.advancedMsgStr(fieldState.attribute.displayName ?? '') }}\n                    @if (fieldState.attribute.required) {\n                        *\n                    }\n                </label>\n            </div>\n\n            <div [kcClass]=\"'kcInputWrapperClass'\">\n                @if (fieldState.attribute.annotations.inputHelperTextBefore) {\n                    <div\n                        aria-live=\"polite\"\n                        [kcClass]=\"'kcInputHelperTextBeforeClass'\"\n                        [id]=\"'form-help-text-before-' + fieldState.attribute.name\"\n                    >\n                        {{ i18n.advancedMsgStr(fieldState.attribute.annotations.inputHelperTextBefore) }}\n                    </div>\n                }\n\n                <kc-input-field-by-type\n                    [attribute]=\"fieldState.attribute\"\n                    [valueOrValues]=\"fieldState.valueOrValues\"\n                    [displayableErrors]=\"fieldState.displayableErrors\"\n                    (dispatchFormAction)=\"onDispatch($event)\"\n                />\n\n                <kc-field-errors\n                    [attribute]=\"fieldState.attribute\"\n                    [displayableErrors]=\"fieldState.displayableErrors\"\n                />\n                @if (fieldState.attribute.annotations.inputHelperTextAfter) {\n                    <div\n                        aria-live=\"polite\"\n                        [kcClass]=\"'kcInputHelperTextAfterClass'\"\n                        [id]=\"'form-help-text-after-' + fieldState.attribute.name\"\n                    >\n                        {{ i18n.advancedMsgStr(fieldState.attribute.annotations.inputHelperTextAfter) }}\n                    </div>\n                }\n\n                @if (afterField) {\n                    <ng-container\n                        [ngTemplateOutlet]=\"afterField\"\n                        [ngTemplateOutletContext]=\"{\n                            attribute: fieldState.attribute,\n                            valueOrValues: fieldState.valueOrValues,\n                            displayableErrors: fieldState.displayableErrors\n                        }\"\n                    />\n                }\n                <!-- NOTE: Downloading of html5DataAnnotations scripts is done in the useUserProfileForm hook -->\n            </div>\n        </div>\n    }\n}\n", styles: [":host{display:contents}\n"] }]
        }], propDecorators: { beforeField: [{
                type: ContentChild,
                args: ['beforeField']
            }], afterField: [{
                type: ContentChild,
                args: ['afterField']
            }] } });

/**
 * Generated bundle index. Do not edit.
 */

export { UserProfileFormFieldsComponent };
//# sourceMappingURL=keycloakify-angular-login-components-user-profile-form-fields.mjs.map
