import * as i0 from '@angular/core';
import { inject, viewChild, forwardRef, ChangeDetectionStrategy, Component } from '@angular/core';
import { KcSanitizePipe } from '@keycloakify/angular/lib/pipes/kc-sanitize';
import { USE_DEFAULT_CSS } from '@keycloakify/angular/lib/tokens/use-default-css';
import { ComponentReference } from '@keycloakify/angular/login/classes/component-reference';
import { LOGIN_CLASSES } from '@keycloakify/angular/login/tokens/classes';
import { LOGIN_I18N } from '@keycloakify/angular/login/tokens/i18n';
import { KC_LOGIN_CONTEXT } from '@keycloakify/angular/login/tokens/kc-context';

class InfoComponent extends ComponentReference {
    constructor() {
        super(...arguments);
        this.kcContext = inject(KC_LOGIN_CONTEXT);
        this.i18n = inject(LOGIN_I18N);
        this.doUseDefaultCss = inject(USE_DEFAULT_CSS);
        this.classes = inject(LOGIN_CLASSES);
        this.displayRequiredFields = false;
        this.displayInfo = false;
        this.displayMessage = false;
        this.headerNode = viewChild('headerNode');
        this.infoNode = viewChild('infoNode');
        this.socialProvidersNode = viewChild('socialProvidersNode');
    }
    get infoMessage() {
        let html = this.kcContext.message.summary;
        if (this.kcContext.requiredActions) {
            html += '<b>';
            html += this.kcContext.requiredActions.map(requiredAction => this.i18n.advancedMsgStr(`requiredAction.${requiredAction}`)).join(', ');
            html += '</b>';
        }
        return html;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: InfoComponent, deps: null, target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "20.0.3", type: InfoComponent, isStandalone: true, selector: "kc-info", providers: [
            {
                provide: ComponentReference,
                useExisting: forwardRef(() => InfoComponent)
            }
        ], viewQueries: [{ propertyName: "headerNode", first: true, predicate: ["headerNode"], descendants: true, isSignal: true }, { propertyName: "infoNode", first: true, predicate: ["infoNode"], descendants: true, isSignal: true }, { propertyName: "socialProvidersNode", first: true, predicate: ["socialProvidersNode"], descendants: true, isSignal: true }], usesInheritance: true, ngImport: i0, template: "@let skipLink = kcContext.skipLink;\n@let actionUri = kcContext.actionUri;\n@let pageRedirectUri = kcContext.pageRedirectUri;\n@let client = kcContext.client;\n\n<ng-template #headerNode>\n    @let messageHeader = kcContext.messageHeader;\n    @let message = kcContext.message;\n    <span [innerHTML]=\"messageHeader ?? i18n.advancedMsgStr(message.summary) | kcSanitize: 'html'\"> </span>\n</ng-template>\n<div id=\"kc-info-message\">\n    <p\n        class=\"instruction\"\n        [innerHTML]=\"infoMessage | kcSanitize: 'html'\"\n    ></p>\n    @if (!skipLink) {\n        @if (pageRedirectUri) {\n            <p>\n                <a\n                    [href]=\"pageRedirectUri\"\n                    [innerHTML]=\"i18n.msgStr('backToApplication') | kcSanitize: 'html'\"\n                >\n                </a>\n            </p>\n        } @else if (actionUri) {\n            <p>\n                <a\n                    [href]=\"actionUri\"\n                    [innerHTML]=\"i18n.msgStr('proceedWithAction') | kcSanitize: 'html'\"\n                >\n                </a>\n            </p>\n        } @else if (client.baseUrl) {\n            <p>\n                <a\n                    [href]=\"client.baseUrl\"\n                    [innerHTML]=\"i18n.msgStr('backToApplication') | kcSanitize: 'html'\"\n                >\n                </a>\n            </p>\n        }\n    }\n</div>\n", dependencies: [{ kind: "pipe", type: KcSanitizePipe, name: "kcSanitize" }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: InfoComponent, decorators: [{
            type: Component,
            args: [{ imports: [KcSanitizePipe], selector: 'kc-info', changeDetection: ChangeDetectionStrategy.OnPush, providers: [
                        {
                            provide: ComponentReference,
                            useExisting: forwardRef(() => InfoComponent)
                        }
                    ], template: "@let skipLink = kcContext.skipLink;\n@let actionUri = kcContext.actionUri;\n@let pageRedirectUri = kcContext.pageRedirectUri;\n@let client = kcContext.client;\n\n<ng-template #headerNode>\n    @let messageHeader = kcContext.messageHeader;\n    @let message = kcContext.message;\n    <span [innerHTML]=\"messageHeader ?? i18n.advancedMsgStr(message.summary) | kcSanitize: 'html'\"> </span>\n</ng-template>\n<div id=\"kc-info-message\">\n    <p\n        class=\"instruction\"\n        [innerHTML]=\"infoMessage | kcSanitize: 'html'\"\n    ></p>\n    @if (!skipLink) {\n        @if (pageRedirectUri) {\n            <p>\n                <a\n                    [href]=\"pageRedirectUri\"\n                    [innerHTML]=\"i18n.msgStr('backToApplication') | kcSanitize: 'html'\"\n                >\n                </a>\n            </p>\n        } @else if (actionUri) {\n            <p>\n                <a\n                    [href]=\"actionUri\"\n                    [innerHTML]=\"i18n.msgStr('proceedWithAction') | kcSanitize: 'html'\"\n                >\n                </a>\n            </p>\n        } @else if (client.baseUrl) {\n            <p>\n                <a\n                    [href]=\"client.baseUrl\"\n                    [innerHTML]=\"i18n.msgStr('backToApplication') | kcSanitize: 'html'\"\n                >\n                </a>\n            </p>\n        }\n    }\n</div>\n" }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { InfoComponent };
//# sourceMappingURL=keycloakify-angular-login-pages-info.mjs.map
