import * as i0 from '@angular/core';
import { inject, viewChild, forwardRef, ChangeDetectionStrategy, Component } from '@angular/core';
import { KcSanitizePipe } from '@keycloakify/angular/lib/pipes/kc-sanitize';
import { USE_DEFAULT_CSS } from '@keycloakify/angular/lib/tokens/use-default-css';
import { ComponentReference } from '@keycloakify/angular/login/classes/component-reference';
import { KcClassDirective } from '@keycloakify/angular/login/directives/kc-class';
import { LOGIN_CLASSES } from '@keycloakify/angular/login/tokens/classes';
import { LOGIN_I18N } from '@keycloakify/angular/login/tokens/i18n';
import { KC_LOGIN_CONTEXT } from '@keycloakify/angular/login/tokens/kc-context';

class LoginOtpComponent extends ComponentReference {
    constructor() {
        super(...arguments);
        this.kcContext = inject(KC_LOGIN_CONTEXT);
        this.i18n = inject(LOGIN_I18N);
        this.doUseDefaultCss = inject(USE_DEFAULT_CSS);
        this.classes = inject(LOGIN_CLASSES);
        this.displayRequiredFields = false;
        this.displayInfo = false;
        this.displayMessage = this.kcContext.messagesPerField.existsError('totp');
        this.headerNode = viewChild('headerNode');
        this.infoNode = viewChild('infoNode');
        this.socialProvidersNode = viewChild('socialProvidersNode');
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: LoginOtpComponent, deps: null, target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "20.0.3", type: LoginOtpComponent, isStandalone: true, selector: "kc-login-otp", providers: [
            {
                provide: ComponentReference,
                useExisting: forwardRef(() => LoginOtpComponent)
            }
        ], viewQueries: [{ propertyName: "headerNode", first: true, predicate: ["headerNode"], descendants: true, isSignal: true }, { propertyName: "infoNode", first: true, predicate: ["infoNode"], descendants: true, isSignal: true }, { propertyName: "socialProvidersNode", first: true, predicate: ["socialProvidersNode"], descendants: true, isSignal: true }], usesInheritance: true, ngImport: i0, template: "@let url = kcContext.url;\n@let otpLogin = kcContext.otpLogin;\n@let messagesPerField = kcContext.messagesPerField;\n\n<ng-template #headerNode>\n    {{ i18n.msgStr('doLogIn') }}\n</ng-template>\n<form\n    id=\"kc-otp-login-form\"\n    method=\"post\"\n    [kcClass]=\"['kcFormClass']\"\n    [action]=\"url.loginAction\"\n>\n    @if (otpLogin.userOtpCredentials.length > 1) {\n        <div [kcClass]=\"'kcFormGroupClass'\">\n            <div [kcClass]=\"'kcInputWrapperClass'\">\n                @for (otpCredential of otpLogin.userOtpCredentials; track otpCredential; let i = $index) {\n                    <ng-container>\n                        <input\n                            type=\"radio\"\n                            name=\"selectedCredentialId\"\n                            [id]=\"'kc-otp-credential-' + i\"\n                            [kcClass]=\"'kcLoginOTPListClass'\"\n                            [value]=\"otpCredential.id\"\n                            [checked]=\"otpCredential.id === otpLogin.selectedCredentialId\"\n                        />\n                        <label\n                            [for]=\"'kc-otp-credential-' + i\"\n                            [kcClass]=\"'kcLoginOTPListClass'\"\n                            [tabIndex]=\"i\"\n                        >\n                            <span [kcClass]=\"'kcLoginOTPListItemHeaderClass'\">\n                                <span [kcClass]=\"'kcLoginOTPListItemIconBodyClass'\">\n                                    <i\n                                        aria-hidden=\"true\"\n                                        [kcClass]=\"'kcLoginOTPListItemIconClass'\"\n                                    ></i>\n                                </span>\n                                <span [kcClass]=\"'kcLoginOTPListItemTitleClass'\">{{ otpCredential.userLabel }}</span>\n                            </span>\n                        </label>\n                    </ng-container>\n                }\n            </div>\n        </div>\n    }\n    <div [kcClass]=\"'kcFormGroupClass'\">\n        <div [kcClass]=\"'kcLabelWrapperClass'\">\n            <label\n                for=\"otp\"\n                [kcClass]=\"'kcLabelClass'\"\n            >\n                {{ i18n.msgStr('loginOtpOneTime') }}\n            </label>\n        </div>\n        <div [kcClass]=\"'kcInputWrapperClass'\">\n            <input\n                id=\"otp\"\n                name=\"otp\"\n                autoComplete=\"off\"\n                type=\"text\"\n                autoFocus\n                [kcClass]=\"'kcInputClass'\"\n                [attr.aria-invalid]=\"messagesPerField.existsError('totp')\"\n            />\n            @if (messagesPerField.existsError('totp')) {\n                <span\n                    id=\"input-error-otp-code\"\n                    aria-live=\"polite\"\n                    [kcClass]=\"['kcInputErrorMessageClass']\"\n                    [innerHTML]=\"messagesPerField.get('totp') | kcSanitize: 'html'\"\n                ></span>\n            }\n        </div>\n    </div>\n    <div [kcClass]=\"'kcFormGroupClass'\">\n        <div\n            id=\"kc-form-options\"\n            [kcClass]=\"'kcFormOptionsClass'\"\n        ></div>\n        <div\n            id=\"kc-form-buttons\"\n            [kcClass]=\"'kcFormButtonsClass'\"\n        >\n            <input\n                name=\"login\"\n                id=\"kc-login\"\n                type=\"submit\"\n                [kcClass]=\"['kcButtonClass', 'kcButtonPrimaryClass', 'kcButtonBlockClass', 'kcButtonLargeClass']\"\n                [value]=\"i18n.msgStr('doLogIn')\"\n            />\n        </div>\n    </div>\n</form>\n", dependencies: [{ kind: "directive", type: KcClassDirective, selector: "[kcClass]", inputs: ["class", "ngClass", "kcClass"] }, { kind: "pipe", type: KcSanitizePipe, name: "kcSanitize" }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: LoginOtpComponent, decorators: [{
            type: Component,
            args: [{ imports: [KcClassDirective, KcSanitizePipe], selector: 'kc-login-otp', changeDetection: ChangeDetectionStrategy.OnPush, providers: [
                        {
                            provide: ComponentReference,
                            useExisting: forwardRef(() => LoginOtpComponent)
                        }
                    ], template: "@let url = kcContext.url;\n@let otpLogin = kcContext.otpLogin;\n@let messagesPerField = kcContext.messagesPerField;\n\n<ng-template #headerNode>\n    {{ i18n.msgStr('doLogIn') }}\n</ng-template>\n<form\n    id=\"kc-otp-login-form\"\n    method=\"post\"\n    [kcClass]=\"['kcFormClass']\"\n    [action]=\"url.loginAction\"\n>\n    @if (otpLogin.userOtpCredentials.length > 1) {\n        <div [kcClass]=\"'kcFormGroupClass'\">\n            <div [kcClass]=\"'kcInputWrapperClass'\">\n                @for (otpCredential of otpLogin.userOtpCredentials; track otpCredential; let i = $index) {\n                    <ng-container>\n                        <input\n                            type=\"radio\"\n                            name=\"selectedCredentialId\"\n                            [id]=\"'kc-otp-credential-' + i\"\n                            [kcClass]=\"'kcLoginOTPListClass'\"\n                            [value]=\"otpCredential.id\"\n                            [checked]=\"otpCredential.id === otpLogin.selectedCredentialId\"\n                        />\n                        <label\n                            [for]=\"'kc-otp-credential-' + i\"\n                            [kcClass]=\"'kcLoginOTPListClass'\"\n                            [tabIndex]=\"i\"\n                        >\n                            <span [kcClass]=\"'kcLoginOTPListItemHeaderClass'\">\n                                <span [kcClass]=\"'kcLoginOTPListItemIconBodyClass'\">\n                                    <i\n                                        aria-hidden=\"true\"\n                                        [kcClass]=\"'kcLoginOTPListItemIconClass'\"\n                                    ></i>\n                                </span>\n                                <span [kcClass]=\"'kcLoginOTPListItemTitleClass'\">{{ otpCredential.userLabel }}</span>\n                            </span>\n                        </label>\n                    </ng-container>\n                }\n            </div>\n        </div>\n    }\n    <div [kcClass]=\"'kcFormGroupClass'\">\n        <div [kcClass]=\"'kcLabelWrapperClass'\">\n            <label\n                for=\"otp\"\n                [kcClass]=\"'kcLabelClass'\"\n            >\n                {{ i18n.msgStr('loginOtpOneTime') }}\n            </label>\n        </div>\n        <div [kcClass]=\"'kcInputWrapperClass'\">\n            <input\n                id=\"otp\"\n                name=\"otp\"\n                autoComplete=\"off\"\n                type=\"text\"\n                autoFocus\n                [kcClass]=\"'kcInputClass'\"\n                [attr.aria-invalid]=\"messagesPerField.existsError('totp')\"\n            />\n            @if (messagesPerField.existsError('totp')) {\n                <span\n                    id=\"input-error-otp-code\"\n                    aria-live=\"polite\"\n                    [kcClass]=\"['kcInputErrorMessageClass']\"\n                    [innerHTML]=\"messagesPerField.get('totp') | kcSanitize: 'html'\"\n                ></span>\n            }\n        </div>\n    </div>\n    <div [kcClass]=\"'kcFormGroupClass'\">\n        <div\n            id=\"kc-form-options\"\n            [kcClass]=\"'kcFormOptionsClass'\"\n        ></div>\n        <div\n            id=\"kc-form-buttons\"\n            [kcClass]=\"'kcFormButtonsClass'\"\n        >\n            <input\n                name=\"login\"\n                id=\"kc-login\"\n                type=\"submit\"\n                [kcClass]=\"['kcButtonClass', 'kcButtonPrimaryClass', 'kcButtonBlockClass', 'kcButtonLargeClass']\"\n                [value]=\"i18n.msgStr('doLogIn')\"\n            />\n        </div>\n    </div>\n</form>\n" }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { LoginOtpComponent };
//# sourceMappingURL=keycloakify-angular-login-pages-login-otp.mjs.map
