import * as i0 from '@angular/core';
import { inject, viewChild, forwardRef, ChangeDetectionStrategy, Component } from '@angular/core';
import { USE_DEFAULT_CSS } from '@keycloakify/angular/lib/tokens/use-default-css';
import { ComponentReference } from '@keycloakify/angular/login/classes/component-reference';
import { KcClassDirective } from '@keycloakify/angular/login/directives/kc-class';
import { LoginResourceInjectorService } from '@keycloakify/angular/login/services/login-resource-injector';
import { LOGIN_CLASSES } from '@keycloakify/angular/login/tokens/classes';
import { LOGIN_I18N } from '@keycloakify/angular/login/tokens/i18n';
import { KC_LOGIN_CONTEXT } from '@keycloakify/angular/login/tokens/kc-context';
import { getKcClsx } from 'keycloakify/login/lib/kcClsx';

class LoginPasskeysConditionalAuthenticateComponent extends ComponentReference {
    constructor() {
        super();
        this.kcContext = inject(KC_LOGIN_CONTEXT);
        this.loginResourceInjectorService = inject(LoginResourceInjectorService);
        this.i18n = inject(LOGIN_I18N);
        this.doUseDefaultCss = inject(USE_DEFAULT_CSS);
        this.classes = inject(LOGIN_CLASSES);
        this.displayRequiredFields = false;
        this.displayInfo = true;
        this.displayMessage = false;
        this.headerNode = viewChild('headerNode');
        this.infoNode = viewChild('infoNode');
        this.socialProvidersNode = viewChild('socialProvidersNode');
        this.authButtonId = 'authenticateWebAuthnButton';
        const { url, challenge, rpId, userVerification, isUserIdentified, createTimeout } = this.kcContext;
        const scripts = [
            {
                type: 'module',
                id: 'LoginRecoveryAuthnCodeConfig',
                textContent: `
                    import { authenticateByWebAuthn } from "${url.resourcesPath}/js/webauthnAuthenticate.js";
                    import { initAuthenticate } from "${url.resourcesPath}/js/passkeysConditionalAuth.js";

                    const authButton = document.getElementById("${this.authButtonId}");
                    const input = {
                        isUserIdentified : ${isUserIdentified},
                        challenge : ${JSON.stringify(challenge)},
                        userVerification : ${JSON.stringify(userVerification)},
                        rpId : ${JSON.stringify(rpId)},
                        createTimeout : ${createTimeout}
                    };
                    authButton.addEventListener("click", () => {
                        authenticateByWebAuthn({
                            ...input,
                            errmsg : ${JSON.stringify(this.i18n.msgStr('webauthn-unsupported-browser-text'))}
                        });
                    });

                    initAuthenticate({
                        ...input,
                        errmsg : ${JSON.stringify(this.i18n.msgStr('passkey-unsupported-browser-text'))}
                    });
          `
            }
        ];
        this.loginResourceInjectorService.insertAdditionalScripts(scripts);
    }
    selectAuthListItemIconClass(iconClass) {
        const kcClsx = getKcClsx({
            doUseDefaultCss: this.doUseDefaultCss ?? true,
            classes: this.classes
        }).kcClsx;
        // eslint-disable-next-line @typescript-eslint/no-explicit-any
        const className = kcClsx(iconClass);
        if (className === iconClass) {
            return kcClsx('kcWebAuthnDefaultIcon');
        }
        return className;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: LoginPasskeysConditionalAuthenticateComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "20.0.3", type: LoginPasskeysConditionalAuthenticateComponent, isStandalone: true, selector: "kc-login-passkeys-conditional-authenticate", providers: [
            {
                provide: ComponentReference,
                useExisting: forwardRef(() => LoginPasskeysConditionalAuthenticateComponent)
            }
        ], viewQueries: [{ propertyName: "headerNode", first: true, predicate: ["headerNode"], descendants: true, isSignal: true }, { propertyName: "infoNode", first: true, predicate: ["infoNode"], descendants: true, isSignal: true }, { propertyName: "socialProvidersNode", first: true, predicate: ["socialProvidersNode"], descendants: true, isSignal: true }], usesInheritance: true, ngImport: i0, template: "@let authenticators = kcContext.authenticators;\n@let realm = kcContext.realm;\n@let url = kcContext.url;\n@let shouldDisplayAuthenticators = kcContext.shouldDisplayAuthenticators;\n@let login = kcContext.login;\n@let messagesPerField = kcContext.messagesPerField;\n@let usernameHidden = kcContext.usernameHidden;\n@let registrationDisabled = kcContext.registrationDisabled;\n<ng-template #headerNode>\n    {{ i18n.msgStr('passkey-login-title') }}\n</ng-template>\n<ng-template #infoNode>\n    @let realm = kcContext.realm;\n    @let url = kcContext.url;\n    @if (realm.registrationAllowed && !registrationDisabled) {\n        <div id=\"kc-registration\">\n            <span>\n                {{ i18n.msgStr('noAccount') }}\n                <a\n                    tabIndex=\"6\"\n                    [href]=\"url.registrationUrl\"\n                >\n                    {{ i18n.msgStr('doRegister') }}\n                </a>\n            </span>\n        </div>\n    }\n</ng-template>\n\n<form\n    id=\"webauth\"\n    method=\"post\"\n    [action]=\"url.loginAction\"\n>\n    <input\n        type=\"hidden\"\n        id=\"clientDataJSON\"\n        name=\"clientDataJSON\"\n    />\n    <input\n        type=\"hidden\"\n        id=\"authenticatorData\"\n        name=\"authenticatorData\"\n    />\n    <input\n        type=\"hidden\"\n        id=\"signature\"\n        name=\"signature\"\n    />\n    <input\n        type=\"hidden\"\n        id=\"credentialId\"\n        name=\"credentialId\"\n    />\n    <input\n        type=\"hidden\"\n        id=\"userHandle\"\n        name=\"userHandle\"\n    />\n    <input\n        type=\"hidden\"\n        id=\"error\"\n        name=\"error\"\n    />\n</form>\n<div\n    no-bottom-margin=\"true\"\n    style=\"margin-bottom: 0\"\n    [kcClass]=\"'kcFormGroupClass'\"\n>\n    @if (authenticators !== undefined && authenticators.authenticators.length !== 0) {\n        <form\n            id=\"authn_select\"\n            [kcClass]=\"'kcFormClass'\"\n        >\n            @for (authenticator of authenticators.authenticators; track authenticator; let i = $index) {\n                <input\n                    type=\"hidden\"\n                    name=\"authn_use_chk\"\n                    readOnly\n                    [value]=\"authenticator.credentialId\"\n                />\n            }\n        </form>\n\n        @if (shouldDisplayAuthenticators) {\n            @if (authenticators.authenticators.length > 1) {\n                <p [kcClass]=\"'kcSelectAuthListItemTitle'\">\n                    {{ i18n.msgStr('passkey-available-authenticators') }}\n                </p>\n            }\n\n            <div [kcClass]=\"'kcFormClass'\">\n                @for (authenticator of authenticators.authenticators; track authenticator; let i = $index) {\n                    <div\n                        id=\"'kc-webauthn-authenticator-item-' + i\"\n                        [kcClass]=\"'kcSelectAuthListItemClass'\"\n                    >\n                        <i\n                            aria-hidden=\"true\"\n                            [ngClass]=\"selectAuthListItemIconClass(authenticator.transports.iconClass)\"\n                            [kcClass]=\"'kcCommonLogoIdP'\"\n                        ></i>\n                        <div [kcClass]=\"'kcSelectAuthListItemBodyClass'\">\n                            <div\n                                [id]=\"'kc-webauthn-authenticator-label-' + i\"\n                                [kcClass]=\"'kcSelectAuthListItemHeadingClass'\"\n                            >\n                                {{ i18n.advancedMsgStr(authenticator.label) }}\n                            </div>\n                            @if (\n                                authenticator.transports !== undefined &&\n                                authenticator.transports.displayNameProperties !== undefined &&\n                                authenticator.transports.displayNameProperties.length !== 0\n                            ) {\n                                <div\n                                    [id]=\"'kc-webauthn-authenticator-transport-' + i\"\n                                    [kcClass]=\"'kcSelectAuthListItemDescriptionClass'\"\n                                >\n                                    @for (nameProperty of authenticator.transports.displayNameProperties; track nameProperty; let i = $index) {\n                                        <span>\n                                            {{ i18n.advancedMsgStr(nameProperty) }}\n                                        </span>\n                                        @if (i !== authenticator.transports.displayNameProperties.length - 1) {\n                                            <span>, </span>\n                                        }\n                                    }\n                                </div>\n                                <div [kcClass]=\"'kcSelectAuthListItemDescriptionClass'\">\n                                    <span [id]=\"'kc-webauthn-authenticator-createdlabel-' + i\">\n                                        {{ i18n.msgStr('passkey-createdAt-label') }}\n                                    </span>\n                                    <span [id]=\"'kc-webauthn-authenticator-created-' + i\">\n                                        {{ authenticator.createdAt }}\n                                    </span>\n                                </div>\n                                <div [kcClass]=\"'kcSelectAuthListItemFillClass'\"></div>\n                            }\n                        </div>\n                    </div>\n                }\n            </div>\n        }\n    }\n    <div id=\"kc-form-wrapper\">\n        @if (realm.password) {\n            <form\n                id=\"kc-form-passkey\"\n                method=\"post\"\n                style=\"display: none\"\n                [action]=\"url.loginAction\"\n            >\n                @if (!usernameHidden) {\n                    <div [kcClass]=\"'kcFormGroupClass'\">\n                        <label\n                            for=\"username\"\n                            [kcClass]=\"'kcLabelClass'\"\n                        >\n                            {{ i18n.msgStr('passkey-autofill-select') }}\n                        </label>\n                        <input\n                            tabIndex=\"1\"\n                            id=\"username\"\n                            name=\"username\"\n                            type=\"text\"\n                            autoFocus\n                            autoComplete=\"off\"\n                            [attr.aria-invalid]=\"messagesPerField.existsError('username')\"\n                            [kcClass]=\"'kcInputClass'\"\n                            [value]=\"login.username ?? ''\"\n                        />\n                        @if (messagesPerField.existsError('username')) {\n                            <span\n                                id=\"input-error-username\"\n                                aria-live=\"polite\"\n                                [kcClass]=\"'kcInputErrorMessageClass'\"\n                            >\n                                {{ messagesPerField.get('username') }}\n                            </span>\n                        }\n                    </div>\n                }\n            </form>\n            <div\n                id=\"kc-form-passkey-button\"\n                style=\"display: none\"\n                [kcClass]=\"'kcFormButtonsClass'\"\n            >\n                <input\n                    id=\"authButtonId\"\n                    type=\"button\"\n                    autoFocus\n                    [value]=\"i18n.msgStr('passkey-doAuthenticate')\"\n                    [kcClass]=\"['kcButtonClass', 'kcButtonPrimaryClass', 'kcButtonBlockClass', 'kcButtonLargeClass']\"\n                />\n            </div>\n        }\n    </div>\n</div>\n", dependencies: [{ kind: "directive", type: KcClassDirective, selector: "[kcClass]", inputs: ["class", "ngClass", "kcClass"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: LoginPasskeysConditionalAuthenticateComponent, decorators: [{
            type: Component,
            args: [{ imports: [KcClassDirective], selector: 'kc-login-passkeys-conditional-authenticate', changeDetection: ChangeDetectionStrategy.OnPush, providers: [
                        {
                            provide: ComponentReference,
                            useExisting: forwardRef(() => LoginPasskeysConditionalAuthenticateComponent)
                        }
                    ], template: "@let authenticators = kcContext.authenticators;\n@let realm = kcContext.realm;\n@let url = kcContext.url;\n@let shouldDisplayAuthenticators = kcContext.shouldDisplayAuthenticators;\n@let login = kcContext.login;\n@let messagesPerField = kcContext.messagesPerField;\n@let usernameHidden = kcContext.usernameHidden;\n@let registrationDisabled = kcContext.registrationDisabled;\n<ng-template #headerNode>\n    {{ i18n.msgStr('passkey-login-title') }}\n</ng-template>\n<ng-template #infoNode>\n    @let realm = kcContext.realm;\n    @let url = kcContext.url;\n    @if (realm.registrationAllowed && !registrationDisabled) {\n        <div id=\"kc-registration\">\n            <span>\n                {{ i18n.msgStr('noAccount') }}\n                <a\n                    tabIndex=\"6\"\n                    [href]=\"url.registrationUrl\"\n                >\n                    {{ i18n.msgStr('doRegister') }}\n                </a>\n            </span>\n        </div>\n    }\n</ng-template>\n\n<form\n    id=\"webauth\"\n    method=\"post\"\n    [action]=\"url.loginAction\"\n>\n    <input\n        type=\"hidden\"\n        id=\"clientDataJSON\"\n        name=\"clientDataJSON\"\n    />\n    <input\n        type=\"hidden\"\n        id=\"authenticatorData\"\n        name=\"authenticatorData\"\n    />\n    <input\n        type=\"hidden\"\n        id=\"signature\"\n        name=\"signature\"\n    />\n    <input\n        type=\"hidden\"\n        id=\"credentialId\"\n        name=\"credentialId\"\n    />\n    <input\n        type=\"hidden\"\n        id=\"userHandle\"\n        name=\"userHandle\"\n    />\n    <input\n        type=\"hidden\"\n        id=\"error\"\n        name=\"error\"\n    />\n</form>\n<div\n    no-bottom-margin=\"true\"\n    style=\"margin-bottom: 0\"\n    [kcClass]=\"'kcFormGroupClass'\"\n>\n    @if (authenticators !== undefined && authenticators.authenticators.length !== 0) {\n        <form\n            id=\"authn_select\"\n            [kcClass]=\"'kcFormClass'\"\n        >\n            @for (authenticator of authenticators.authenticators; track authenticator; let i = $index) {\n                <input\n                    type=\"hidden\"\n                    name=\"authn_use_chk\"\n                    readOnly\n                    [value]=\"authenticator.credentialId\"\n                />\n            }\n        </form>\n\n        @if (shouldDisplayAuthenticators) {\n            @if (authenticators.authenticators.length > 1) {\n                <p [kcClass]=\"'kcSelectAuthListItemTitle'\">\n                    {{ i18n.msgStr('passkey-available-authenticators') }}\n                </p>\n            }\n\n            <div [kcClass]=\"'kcFormClass'\">\n                @for (authenticator of authenticators.authenticators; track authenticator; let i = $index) {\n                    <div\n                        id=\"'kc-webauthn-authenticator-item-' + i\"\n                        [kcClass]=\"'kcSelectAuthListItemClass'\"\n                    >\n                        <i\n                            aria-hidden=\"true\"\n                            [ngClass]=\"selectAuthListItemIconClass(authenticator.transports.iconClass)\"\n                            [kcClass]=\"'kcCommonLogoIdP'\"\n                        ></i>\n                        <div [kcClass]=\"'kcSelectAuthListItemBodyClass'\">\n                            <div\n                                [id]=\"'kc-webauthn-authenticator-label-' + i\"\n                                [kcClass]=\"'kcSelectAuthListItemHeadingClass'\"\n                            >\n                                {{ i18n.advancedMsgStr(authenticator.label) }}\n                            </div>\n                            @if (\n                                authenticator.transports !== undefined &&\n                                authenticator.transports.displayNameProperties !== undefined &&\n                                authenticator.transports.displayNameProperties.length !== 0\n                            ) {\n                                <div\n                                    [id]=\"'kc-webauthn-authenticator-transport-' + i\"\n                                    [kcClass]=\"'kcSelectAuthListItemDescriptionClass'\"\n                                >\n                                    @for (nameProperty of authenticator.transports.displayNameProperties; track nameProperty; let i = $index) {\n                                        <span>\n                                            {{ i18n.advancedMsgStr(nameProperty) }}\n                                        </span>\n                                        @if (i !== authenticator.transports.displayNameProperties.length - 1) {\n                                            <span>, </span>\n                                        }\n                                    }\n                                </div>\n                                <div [kcClass]=\"'kcSelectAuthListItemDescriptionClass'\">\n                                    <span [id]=\"'kc-webauthn-authenticator-createdlabel-' + i\">\n                                        {{ i18n.msgStr('passkey-createdAt-label') }}\n                                    </span>\n                                    <span [id]=\"'kc-webauthn-authenticator-created-' + i\">\n                                        {{ authenticator.createdAt }}\n                                    </span>\n                                </div>\n                                <div [kcClass]=\"'kcSelectAuthListItemFillClass'\"></div>\n                            }\n                        </div>\n                    </div>\n                }\n            </div>\n        }\n    }\n    <div id=\"kc-form-wrapper\">\n        @if (realm.password) {\n            <form\n                id=\"kc-form-passkey\"\n                method=\"post\"\n                style=\"display: none\"\n                [action]=\"url.loginAction\"\n            >\n                @if (!usernameHidden) {\n                    <div [kcClass]=\"'kcFormGroupClass'\">\n                        <label\n                            for=\"username\"\n                            [kcClass]=\"'kcLabelClass'\"\n                        >\n                            {{ i18n.msgStr('passkey-autofill-select') }}\n                        </label>\n                        <input\n                            tabIndex=\"1\"\n                            id=\"username\"\n                            name=\"username\"\n                            type=\"text\"\n                            autoFocus\n                            autoComplete=\"off\"\n                            [attr.aria-invalid]=\"messagesPerField.existsError('username')\"\n                            [kcClass]=\"'kcInputClass'\"\n                            [value]=\"login.username ?? ''\"\n                        />\n                        @if (messagesPerField.existsError('username')) {\n                            <span\n                                id=\"input-error-username\"\n                                aria-live=\"polite\"\n                                [kcClass]=\"'kcInputErrorMessageClass'\"\n                            >\n                                {{ messagesPerField.get('username') }}\n                            </span>\n                        }\n                    </div>\n                }\n            </form>\n            <div\n                id=\"kc-form-passkey-button\"\n                style=\"display: none\"\n                [kcClass]=\"'kcFormButtonsClass'\"\n            >\n                <input\n                    id=\"authButtonId\"\n                    type=\"button\"\n                    autoFocus\n                    [value]=\"i18n.msgStr('passkey-doAuthenticate')\"\n                    [kcClass]=\"['kcButtonClass', 'kcButtonPrimaryClass', 'kcButtonBlockClass', 'kcButtonLargeClass']\"\n                />\n            </div>\n        }\n    </div>\n</div>\n" }]
        }], ctorParameters: () => [] });

/**
 * Generated bundle index. Do not edit.
 */

export { LoginPasskeysConditionalAuthenticateComponent };
//# sourceMappingURL=keycloakify-angular-login-pages-login-passkeys-conditional-authenticate.mjs.map
