import * as i0 from '@angular/core';
import { inject, viewChild, signal, forwardRef, ChangeDetectionStrategy, Component } from '@angular/core';
import { KcSanitizePipe } from '@keycloakify/angular/lib/pipes/kc-sanitize';
import { USE_DEFAULT_CSS } from '@keycloakify/angular/lib/tokens/use-default-css';
import { ComponentReference } from '@keycloakify/angular/login/classes/component-reference';
import { PasswordWrapperComponent } from '@keycloakify/angular/login/components/password-wrapper';
import { KcClassDirective } from '@keycloakify/angular/login/directives/kc-class';
import { LOGIN_CLASSES } from '@keycloakify/angular/login/tokens/classes';
import { LOGIN_I18N } from '@keycloakify/angular/login/tokens/i18n';
import { KC_LOGIN_CONTEXT } from '@keycloakify/angular/login/tokens/kc-context';

class LoginPasswordComponent extends ComponentReference {
    constructor() {
        super(...arguments);
        this.kcContext = inject(KC_LOGIN_CONTEXT);
        this.i18n = inject(LOGIN_I18N);
        this.doUseDefaultCss = inject(USE_DEFAULT_CSS);
        this.classes = inject(LOGIN_CLASSES);
        this.displayRequiredFields = false;
        this.displayInfo = true;
        this.displayMessage = this.kcContext.messagesPerField.existsError('password');
        this.headerNode = viewChild('headerNode');
        this.infoNode = viewChild('infoNode');
        this.socialProvidersNode = viewChild('socialProvidersNode');
        this.authButtonId = 'authenticateWebAuthnButton';
        this.isLoginButtonDisabled = signal(false);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: LoginPasswordComponent, deps: null, target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "20.0.3", type: LoginPasswordComponent, isStandalone: true, selector: "kc-login-password", providers: [
            {
                provide: ComponentReference,
                useExisting: forwardRef(() => LoginPasswordComponent)
            }
        ], viewQueries: [{ propertyName: "headerNode", first: true, predicate: ["headerNode"], descendants: true, isSignal: true }, { propertyName: "infoNode", first: true, predicate: ["infoNode"], descendants: true, isSignal: true }, { propertyName: "socialProvidersNode", first: true, predicate: ["socialProvidersNode"], descendants: true, isSignal: true }], usesInheritance: true, ngImport: i0, template: "@let url = kcContext.url;\n@let messagesPerField = kcContext.messagesPerField;\n@let realm = kcContext.realm;\n\n<ng-template #headerNode>\n    {{ i18n.msgStr('doLogIn') }}\n</ng-template>\n\n<div id=\"kc-form\">\n    <div id=\"kc-form-wrapper\">\n        <form\n            id=\"kc-form-login\"\n            method=\"post\"\n            [action]=\"url?.loginAction\"\n            (onSubmit)=\"isLoginButtonDisabled.set(true)\"\n        >\n            <div\n                class=\"no-bottom-margin\"\n                [kcClass]=\"'kcFormGroupClass'\"\n            >\n                <hr />\n                <label\n                    for=\"password\"\n                    [kcClass]=\"'kcLabelClass'\"\n                >\n                    {{ i18n.msgStr('password') }}\n                </label>\n                <kc-password-wrapper passwordInputId=\"password\">\n                    <input\n                        type=\"password\"\n                        id=\"password\"\n                        name=\"password\"\n                        aria-describedby=\"input-error-password\"\n                        [kcClass]=\"'kcInputClass'\"\n                        [required]=\"true\"\n                        [autofocus]=\"true\"\n                        [tabindex]=\"1\"\n                    />\n                </kc-password-wrapper>\n\n                @if (messagesPerField.existsError('password')) {\n                    <span\n                        id=\"input-error-password\"\n                        aria-live=\"polite\"\n                        [kcClass]=\"'kcInputErrorMessageClass'\"\n                        [innerHTML]=\"messagesPerField.getFirstError('password') | kcSanitize: 'html'\"\n                    >\n                    </span>\n                }\n            </div>\n            <div [kcClass]=\"['kcFormGroupClass', 'kcFormSettingClass']\">\n                <div id=\"kc-form-options\"></div>\n                <div [kcClass]=\"'kcFormOptionsWrapperClass'\">\n                    @if (realm.resetPasswordAllowed) {\n                        <span>\n                            <a\n                                tabindex=\"5\"\n                                [href]=\"url.loginResetCredentialsUrl\"\n                            >\n                                {{ i18n.msgStr('doForgotPassword') }}\n                            </a>\n                        </span>\n                    }\n                </div>\n            </div>\n            <div\n                id=\"kc-form-buttons\"\n                [kcClass]=\"'kcFormGroupClass'\"\n            >\n                <input\n                    type=\"submit\"\n                    id=\"kc-login\"\n                    name=\"login\"\n                    [value]=\"i18n.msgStr('doLogIn')\"\n                    [disabled]=\"isLoginButtonDisabled()\"\n                    [kcClass]=\"['kcButtonClass', 'kcButtonPrimaryClass', 'kcButtonBlockClass', 'kcButtonLargeClass']\"\n                    [tabindex]=\"4\"\n                />\n            </div>\n        </form>\n    </div>\n</div>\n", dependencies: [{ kind: "directive", type: KcClassDirective, selector: "[kcClass]", inputs: ["class", "ngClass", "kcClass"] }, { kind: "component", type: PasswordWrapperComponent, selector: "kc-password-wrapper", inputs: ["passwordInputId"] }, { kind: "pipe", type: KcSanitizePipe, name: "kcSanitize" }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: LoginPasswordComponent, decorators: [{
            type: Component,
            args: [{ imports: [KcClassDirective, PasswordWrapperComponent, KcSanitizePipe], selector: 'kc-login-password', changeDetection: ChangeDetectionStrategy.OnPush, providers: [
                        {
                            provide: ComponentReference,
                            useExisting: forwardRef(() => LoginPasswordComponent)
                        }
                    ], template: "@let url = kcContext.url;\n@let messagesPerField = kcContext.messagesPerField;\n@let realm = kcContext.realm;\n\n<ng-template #headerNode>\n    {{ i18n.msgStr('doLogIn') }}\n</ng-template>\n\n<div id=\"kc-form\">\n    <div id=\"kc-form-wrapper\">\n        <form\n            id=\"kc-form-login\"\n            method=\"post\"\n            [action]=\"url?.loginAction\"\n            (onSubmit)=\"isLoginButtonDisabled.set(true)\"\n        >\n            <div\n                class=\"no-bottom-margin\"\n                [kcClass]=\"'kcFormGroupClass'\"\n            >\n                <hr />\n                <label\n                    for=\"password\"\n                    [kcClass]=\"'kcLabelClass'\"\n                >\n                    {{ i18n.msgStr('password') }}\n                </label>\n                <kc-password-wrapper passwordInputId=\"password\">\n                    <input\n                        type=\"password\"\n                        id=\"password\"\n                        name=\"password\"\n                        aria-describedby=\"input-error-password\"\n                        [kcClass]=\"'kcInputClass'\"\n                        [required]=\"true\"\n                        [autofocus]=\"true\"\n                        [tabindex]=\"1\"\n                    />\n                </kc-password-wrapper>\n\n                @if (messagesPerField.existsError('password')) {\n                    <span\n                        id=\"input-error-password\"\n                        aria-live=\"polite\"\n                        [kcClass]=\"'kcInputErrorMessageClass'\"\n                        [innerHTML]=\"messagesPerField.getFirstError('password') | kcSanitize: 'html'\"\n                    >\n                    </span>\n                }\n            </div>\n            <div [kcClass]=\"['kcFormGroupClass', 'kcFormSettingClass']\">\n                <div id=\"kc-form-options\"></div>\n                <div [kcClass]=\"'kcFormOptionsWrapperClass'\">\n                    @if (realm.resetPasswordAllowed) {\n                        <span>\n                            <a\n                                tabindex=\"5\"\n                                [href]=\"url.loginResetCredentialsUrl\"\n                            >\n                                {{ i18n.msgStr('doForgotPassword') }}\n                            </a>\n                        </span>\n                    }\n                </div>\n            </div>\n            <div\n                id=\"kc-form-buttons\"\n                [kcClass]=\"'kcFormGroupClass'\"\n            >\n                <input\n                    type=\"submit\"\n                    id=\"kc-login\"\n                    name=\"login\"\n                    [value]=\"i18n.msgStr('doLogIn')\"\n                    [disabled]=\"isLoginButtonDisabled()\"\n                    [kcClass]=\"['kcButtonClass', 'kcButtonPrimaryClass', 'kcButtonBlockClass', 'kcButtonLargeClass']\"\n                    [tabindex]=\"4\"\n                />\n            </div>\n        </form>\n    </div>\n</div>\n" }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { LoginPasswordComponent };
//# sourceMappingURL=keycloakify-angular-login-pages-login-password.mjs.map
