import * as i0 from '@angular/core';
import { inject, viewChild, signal, forwardRef, ChangeDetectionStrategy, Component } from '@angular/core';
import { USE_DEFAULT_CSS } from '@keycloakify/angular/lib/tokens/use-default-css';
import { ComponentReference } from '@keycloakify/angular/login/classes/component-reference';
import { LogoutOtherSessionsComponent } from '@keycloakify/angular/login/components/logout-other-sessions';
import { KcClassDirective } from '@keycloakify/angular/login/directives/kc-class';
import { LoginResourceInjectorService } from '@keycloakify/angular/login/services/login-resource-injector';
import { LOGIN_CLASSES } from '@keycloakify/angular/login/tokens/classes';
import { LOGIN_I18N } from '@keycloakify/angular/login/tokens/i18n';
import { KC_LOGIN_CONTEXT } from '@keycloakify/angular/login/tokens/kc-context';

class LoginRecoveryAuthnCodeConfigComponent extends ComponentReference {
    constructor() {
        super();
        this.kcContext = inject(KC_LOGIN_CONTEXT);
        this.i18n = inject(LOGIN_I18N);
        this.loginResourceInjectorService = inject(LoginResourceInjectorService);
        this.doUseDefaultCss = inject(USE_DEFAULT_CSS);
        this.classes = inject(LOGIN_CLASSES);
        this.displayRequiredFields = false;
        this.displayInfo = true;
        this.displayMessage = this.kcContext.messagesPerField.existsError('password');
        this.headerNode = viewChild('headerNode');
        this.infoNode = viewChild('infoNode');
        this.socialProvidersNode = viewChild('socialProvidersNode');
        this.toggleRecoveryCodesConfirmation = signal(false);
        this.olRecoveryCodesListId = 'kc-recovery-codes-list';
    }
    ngAfterViewInit() {
        this.loginResourceInjectorService.insertAdditionalScripts([
            {
                type: 'text/javascript',
                id: `${this.olRecoveryCodesListId}-script`,
                textContent: `
                    /* copy recovery codes  */
                    function copyRecoveryCodes() {
                        var tmpTextarea = document.createElement("textarea");
                        var codes = document.querySelectorAll("#${this.olRecoveryCodesListId} li");
                        for (i = 0; i < codes.length; i++) {
                            tmpTextarea.value = tmpTextarea.value + codes[i].innerText + "\\n";
                        }
                        document.body.appendChild(tmpTextarea);
                        tmpTextarea.select();
                        document.execCommand("copy");
                        document.body.removeChild(tmpTextarea);
                    }

                    var copyButton = document.getElementById("copyRecoveryCodes");
                    copyButton && copyButton.addEventListener("click", function () {
                        copyRecoveryCodes();
                    });

                    /* download recovery codes  */
                    function formatCurrentDateTime() {
                        var dt = new Date();
                        var options = {
                            month: 'long',
                            day: 'numeric',
                            year: 'numeric',
                            hour: 'numeric',
                            minute: 'numeric',
                            timeZoneName: 'short'
                        };

                        return dt.toLocaleString('en-US', options);
                    }

                    function parseRecoveryCodeList() {
                        var recoveryCodes = document.querySelectorAll("#${this.olRecoveryCodesListId} li");
                        var recoveryCodeList = "";

                        for (var i = 0; i < recoveryCodes.length; i++) {
                            var recoveryCodeLiElement = recoveryCodes[i].innerText;
                            recoveryCodeList += recoveryCodeLiElement + "\\r\\n";
                        }

                        return recoveryCodeList;
                    }

                    function buildDownloadContent() {
                        var recoveryCodeList = parseRecoveryCodeList();
                        var dt = new Date();
                        var options = {
                            month: 'long',
                            day: 'numeric',
                            year: 'numeric',
                            hour: 'numeric',
                            minute: 'numeric',
                            timeZoneName: 'short'
                        };

                        return fileBodyContent =
                            ${JSON.stringify(this.i18n.msgStr('recovery-codes-download-file-header'))} + "\\n\\n" +
                            recoveryCodeList + "\\n" +
                            ${JSON.stringify(this.i18n.msgStr('recovery-codes-download-file-description'))} + "\\n\\n" +
                            ${JSON.stringify(this.i18n.msgStr('recovery-codes-download-file-date'))} + " " + formatCurrentDateTime();
                    }

                    function setUpDownloadLinkAndDownload(filename, text) {
                        var el = document.createElement('a');
                        el.setAttribute('href', 'data:text/plain;charset=utf-8,' + encodeURIComponent(text));
                        el.setAttribute('download', filename);
                        el.style.display = 'none';
                        document.body.appendChild(el);
                        el.click();
                        document.body.removeChild(el);
                    }

                    function downloadRecoveryCodes() {
                        setUpDownloadLinkAndDownload('kc-download-recovery-codes.txt', buildDownloadContent());
                    }

                    var downloadButton = document.getElementById("downloadRecoveryCodes");
                    downloadButton && downloadButton.addEventListener("click", downloadRecoveryCodes);

                    /* print recovery codes */
                    function buildPrintContent() {
                        var recoveryCodeListHTML = document.getElementById('${this.olRecoveryCodesListId}').innerHTML;
                        var styles =
                            \`@page { size: auto;  margin-top: 0; }
                            body { width: 480px; }
                            div { list-style-type: none; font-family: monospace }
                            p:first-of-type { margin-top: 48px }\`;

                        return printFileContent =
                            "<html><style>" + styles + "</style><body>" +
                            "<title>kc-download-recovery-codes</title>" +
                            "<p>" + ${JSON.stringify(this.i18n.msgStr('recovery-codes-download-file-header'))} + "</p>" +
                            "<div>" + recoveryCodeListHTML + "</div>" +
                            "<p>" + ${JSON.stringify(this.i18n.msgStr('recovery-codes-download-file-description'))} + "</p>" +
                            "<p>" + ${JSON.stringify(this.i18n.msgStr('recovery-codes-download-file-date'))} + " " + formatCurrentDateTime() + "</p>" +
                            "</body></html>";
                    }

                    function printRecoveryCodes() {
                        var w = window.open();
                        w.document.write(buildPrintContent());
                        w.print();
                        w.close();
                    }

                    var printButton = document.getElementById("printRecoveryCodes");
                    printButton && printButton.addEventListener("click", printRecoveryCodes);
                `
            }
        ]);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: LoginRecoveryAuthnCodeConfigComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "20.0.3", type: LoginRecoveryAuthnCodeConfigComponent, isStandalone: true, selector: "kc-login-recovery-authn-code-config", providers: [
            {
                provide: ComponentReference,
                useExisting: forwardRef(() => LoginRecoveryAuthnCodeConfigComponent)
            }
        ], viewQueries: [{ propertyName: "headerNode", first: true, predicate: ["headerNode"], descendants: true, isSignal: true }, { propertyName: "infoNode", first: true, predicate: ["infoNode"], descendants: true, isSignal: true }, { propertyName: "socialProvidersNode", first: true, predicate: ["socialProvidersNode"], descendants: true, isSignal: true }], usesInheritance: true, ngImport: i0, template: "@let recoveryAuthnCodesConfigBean = kcContext.recoveryAuthnCodesConfigBean;\n@let isAppInitiatedAction = kcContext.isAppInitiatedAction;\n\n<ng-template #headerNode>\n    {{ i18n.msgStr('recovery-code-config-header') }}\n</ng-template>\n\n<div\n    class=\"pf-c-alert pf-m-warning pf-m-inline\"\n    aria-label=\"Warning alert\"\n    [kcClass]=\"'kcRecoveryCodesWarning'\"\n>\n    <div class=\"pf-c-alert__icon\">\n        <i\n            class=\"pficon-warning-triangle-o\"\n            aria-hidden=\"true\"\n        ></i>\n    </div>\n    <h4 class=\"pf-c-alert__title\">\n        <span class=\"pf-screen-reader\">Warning alert:</span>\n        {{ i18n.msgStr('recovery-code-config-warning-title') }}\n    </h4>\n    <div class=\"pf-c-alert__description\">\n        <p>{{ i18n.msgStr('recovery-code-config-warning-message') }}</p>\n    </div>\n</div>\n\n<ol\n    [id]=\"olRecoveryCodesListId\"\n    [kcClass]=\"'kcRecoveryCodesList'\"\n>\n    @for (code of recoveryAuthnCodesConfigBean.generatedRecoveryAuthnCodesList; track code; let i = $index) {\n        <li>\n            <span>{{ i + 1 }}:</span> {{ code.slice(0, 4) }}-{{ code.slice(4, 8) }}-{{ code.slice(8) }}\n        </li>\n    }\n</ol>\n\n<!-- actions -->\n<div [kcClass]=\"'kcRecoveryCodesActions'\">\n    <button\n        id=\"printRecoveryCodes\"\n        class=\"pf-c-button pf-m-link\"\n        type=\"button\"\n    >\n        <i\n            class=\"pficon-print\"\n            aria-hidden=\"true\"\n        ></i>\n        {{ i18n.msgStr('recovery-codes-print') }}\n    </button>\n    <button\n        id=\"downloadRecoveryCodes\"\n        class=\"pf-c-button pf-m-link\"\n        type=\"button\"\n    >\n        <i\n            class=\"pficon-save\"\n            aria-hidden=\"true\"\n        ></i>\n        {{ i18n.msgStr('recovery-codes-download') }}\n    </button>\n    <button\n        id=\"copyRecoveryCodes\"\n        class=\"pf-c-button pf-m-link\"\n        type=\"button\"\n    >\n        <i\n            class=\"pficon-blueprint\"\n            aria-hidden=\"true\"\n        ></i>\n        {{ i18n.msgStr('recovery-codes-copy') }}\n    </button>\n</div>\n\n<!-- confirmation checkbox -->\n\n<div\n    class=\"checkbox\"\n    [kcClass]=\"'kcFormOptionsClass'\"\n>\n    <label for=\"kcRecoveryCodesConfirmationCheck\">\n        <input\n            type=\"checkbox\"\n            id=\"kcRecoveryCodesConfirmationCheck\"\n            name=\"kcRecoveryCodesConfirmationCheck\"\n            [kcClass]=\"'kcCheckInputClass'\"\n            [checked]=\"toggleRecoveryCodesConfirmation()\"\n            (change)=\"toggleRecoveryCodesConfirmation.set($any($event.target).checked)\"\n        />\n        {{ i18n.msgStr('recovery-codes-confirmation-message') }}\n    </label>\n</div>\n\n<form\n    id=\"kc-recovery-codes-settings-form\"\n    method=\"post\"\n    [action]=\"kcContext.url.loginAction\"\n    [kcClass]=\"'kcFormGroupClass'\"\n>\n    <input\n        type=\"hidden\"\n        name=\"generatedRecoveryAuthnCodes\"\n        [value]=\"recoveryAuthnCodesConfigBean.generatedRecoveryAuthnCodesAsString\"\n    />\n    <input\n        type=\"hidden\"\n        name=\"generatedAt\"\n        [value]=\"recoveryAuthnCodesConfigBean.generatedAt\"\n    />\n    <input\n        type=\"hidden\"\n        id=\"userLabel\"\n        name=\"userLabel\"\n        [value]=\"i18n.msgStr('recovery-codes-label-default')\"\n    />\n\n    <kc-logout-other-sessions />\n\n    @if (isAppInitiatedAction) {\n        <input\n            type=\"submit\"\n            id=\"saveRecoveryAuthnCodesBtn\"\n            [kcClass]=\"['kcButtonClass', 'kcButtonPrimaryClass', 'kcButtonLargeClass']\"\n            [value]=\"i18n.msgStr('recovery-codes-action-complete')\"\n            [disabled]=\"!toggleRecoveryCodesConfirmation()\"\n        />\n        <button\n            type=\"submit\"\n            id=\"cancelRecoveryAuthnCodesBtn\"\n            name=\"cancel-aia\"\n            value=\"true\"\n            [kcClass]=\"['kcButtonClass', 'kcButtonDefaultClass', 'kcButtonLargeClass']\"\n        >\n            {{ i18n.msgStr('recovery-codes-action-cancel') }}\n        </button>\n    } @else {\n        <input\n            type=\"submit\"\n            id=\"saveRecoveryAuthnCodesBtn\"\n            [kcClass]=\"['kcButtonClass', 'kcButtonPrimaryClass', 'kcButtonBlockClass', 'kcButtonLargeClass']\"\n            [value]=\"i18n.msgStr('recovery-codes-action-complete')\"\n            [disabled]=\"!toggleRecoveryCodesConfirmation()\"\n        />\n    }\n</form>\n", dependencies: [{ kind: "directive", type: KcClassDirective, selector: "[kcClass]", inputs: ["class", "ngClass", "kcClass"] }, { kind: "component", type: LogoutOtherSessionsComponent, selector: "kc-logout-other-sessions" }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: LoginRecoveryAuthnCodeConfigComponent, decorators: [{
            type: Component,
            args: [{ imports: [KcClassDirective, LogoutOtherSessionsComponent], selector: 'kc-login-recovery-authn-code-config', changeDetection: ChangeDetectionStrategy.OnPush, providers: [
                        {
                            provide: ComponentReference,
                            useExisting: forwardRef(() => LoginRecoveryAuthnCodeConfigComponent)
                        }
                    ], template: "@let recoveryAuthnCodesConfigBean = kcContext.recoveryAuthnCodesConfigBean;\n@let isAppInitiatedAction = kcContext.isAppInitiatedAction;\n\n<ng-template #headerNode>\n    {{ i18n.msgStr('recovery-code-config-header') }}\n</ng-template>\n\n<div\n    class=\"pf-c-alert pf-m-warning pf-m-inline\"\n    aria-label=\"Warning alert\"\n    [kcClass]=\"'kcRecoveryCodesWarning'\"\n>\n    <div class=\"pf-c-alert__icon\">\n        <i\n            class=\"pficon-warning-triangle-o\"\n            aria-hidden=\"true\"\n        ></i>\n    </div>\n    <h4 class=\"pf-c-alert__title\">\n        <span class=\"pf-screen-reader\">Warning alert:</span>\n        {{ i18n.msgStr('recovery-code-config-warning-title') }}\n    </h4>\n    <div class=\"pf-c-alert__description\">\n        <p>{{ i18n.msgStr('recovery-code-config-warning-message') }}</p>\n    </div>\n</div>\n\n<ol\n    [id]=\"olRecoveryCodesListId\"\n    [kcClass]=\"'kcRecoveryCodesList'\"\n>\n    @for (code of recoveryAuthnCodesConfigBean.generatedRecoveryAuthnCodesList; track code; let i = $index) {\n        <li>\n            <span>{{ i + 1 }}:</span> {{ code.slice(0, 4) }}-{{ code.slice(4, 8) }}-{{ code.slice(8) }}\n        </li>\n    }\n</ol>\n\n<!-- actions -->\n<div [kcClass]=\"'kcRecoveryCodesActions'\">\n    <button\n        id=\"printRecoveryCodes\"\n        class=\"pf-c-button pf-m-link\"\n        type=\"button\"\n    >\n        <i\n            class=\"pficon-print\"\n            aria-hidden=\"true\"\n        ></i>\n        {{ i18n.msgStr('recovery-codes-print') }}\n    </button>\n    <button\n        id=\"downloadRecoveryCodes\"\n        class=\"pf-c-button pf-m-link\"\n        type=\"button\"\n    >\n        <i\n            class=\"pficon-save\"\n            aria-hidden=\"true\"\n        ></i>\n        {{ i18n.msgStr('recovery-codes-download') }}\n    </button>\n    <button\n        id=\"copyRecoveryCodes\"\n        class=\"pf-c-button pf-m-link\"\n        type=\"button\"\n    >\n        <i\n            class=\"pficon-blueprint\"\n            aria-hidden=\"true\"\n        ></i>\n        {{ i18n.msgStr('recovery-codes-copy') }}\n    </button>\n</div>\n\n<!-- confirmation checkbox -->\n\n<div\n    class=\"checkbox\"\n    [kcClass]=\"'kcFormOptionsClass'\"\n>\n    <label for=\"kcRecoveryCodesConfirmationCheck\">\n        <input\n            type=\"checkbox\"\n            id=\"kcRecoveryCodesConfirmationCheck\"\n            name=\"kcRecoveryCodesConfirmationCheck\"\n            [kcClass]=\"'kcCheckInputClass'\"\n            [checked]=\"toggleRecoveryCodesConfirmation()\"\n            (change)=\"toggleRecoveryCodesConfirmation.set($any($event.target).checked)\"\n        />\n        {{ i18n.msgStr('recovery-codes-confirmation-message') }}\n    </label>\n</div>\n\n<form\n    id=\"kc-recovery-codes-settings-form\"\n    method=\"post\"\n    [action]=\"kcContext.url.loginAction\"\n    [kcClass]=\"'kcFormGroupClass'\"\n>\n    <input\n        type=\"hidden\"\n        name=\"generatedRecoveryAuthnCodes\"\n        [value]=\"recoveryAuthnCodesConfigBean.generatedRecoveryAuthnCodesAsString\"\n    />\n    <input\n        type=\"hidden\"\n        name=\"generatedAt\"\n        [value]=\"recoveryAuthnCodesConfigBean.generatedAt\"\n    />\n    <input\n        type=\"hidden\"\n        id=\"userLabel\"\n        name=\"userLabel\"\n        [value]=\"i18n.msgStr('recovery-codes-label-default')\"\n    />\n\n    <kc-logout-other-sessions />\n\n    @if (isAppInitiatedAction) {\n        <input\n            type=\"submit\"\n            id=\"saveRecoveryAuthnCodesBtn\"\n            [kcClass]=\"['kcButtonClass', 'kcButtonPrimaryClass', 'kcButtonLargeClass']\"\n            [value]=\"i18n.msgStr('recovery-codes-action-complete')\"\n            [disabled]=\"!toggleRecoveryCodesConfirmation()\"\n        />\n        <button\n            type=\"submit\"\n            id=\"cancelRecoveryAuthnCodesBtn\"\n            name=\"cancel-aia\"\n            value=\"true\"\n            [kcClass]=\"['kcButtonClass', 'kcButtonDefaultClass', 'kcButtonLargeClass']\"\n        >\n            {{ i18n.msgStr('recovery-codes-action-cancel') }}\n        </button>\n    } @else {\n        <input\n            type=\"submit\"\n            id=\"saveRecoveryAuthnCodesBtn\"\n            [kcClass]=\"['kcButtonClass', 'kcButtonPrimaryClass', 'kcButtonBlockClass', 'kcButtonLargeClass']\"\n            [value]=\"i18n.msgStr('recovery-codes-action-complete')\"\n            [disabled]=\"!toggleRecoveryCodesConfirmation()\"\n        />\n    }\n</form>\n" }]
        }], ctorParameters: () => [] });

/**
 * Generated bundle index. Do not edit.
 */

export { LoginRecoveryAuthnCodeConfigComponent };
//# sourceMappingURL=keycloakify-angular-login-pages-login-recovery-authn-code-config.mjs.map
