import * as i0 from '@angular/core';
import { inject, viewChild, forwardRef, ChangeDetectionStrategy, Component } from '@angular/core';
import { KcSanitizePipe } from '@keycloakify/angular/lib/pipes/kc-sanitize';
import { USE_DEFAULT_CSS } from '@keycloakify/angular/lib/tokens/use-default-css';
import { ComponentReference } from '@keycloakify/angular/login/classes/component-reference';
import { LogoutOtherSessionsComponent } from '@keycloakify/angular/login/components/logout-other-sessions';
import { PasswordWrapperComponent } from '@keycloakify/angular/login/components/password-wrapper';
import { KcClassDirective } from '@keycloakify/angular/login/directives/kc-class';
import { LOGIN_CLASSES } from '@keycloakify/angular/login/tokens/classes';
import { LOGIN_I18N } from '@keycloakify/angular/login/tokens/i18n';
import { KC_LOGIN_CONTEXT } from '@keycloakify/angular/login/tokens/kc-context';

class LoginUpdatePasswordComponent extends ComponentReference {
    constructor() {
        super(...arguments);
        this.kcContext = inject(KC_LOGIN_CONTEXT);
        this.i18n = inject(LOGIN_I18N);
        this.doUseDefaultCss = inject(USE_DEFAULT_CSS);
        this.classes = inject(LOGIN_CLASSES);
        this.displayRequiredFields = false;
        this.displayInfo = false;
        this.displayMessage = this.kcContext.messagesPerField.existsError('password', 'password-confirm');
        this.headerNode = viewChild('headerNode');
        this.infoNode = viewChild('infoNode');
        this.socialProvidersNode = viewChild('socialProvidersNode');
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: LoginUpdatePasswordComponent, deps: null, target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "20.0.3", type: LoginUpdatePasswordComponent, isStandalone: true, selector: "kc-login-update-password", providers: [
            {
                provide: ComponentReference,
                useExisting: forwardRef(() => LoginUpdatePasswordComponent)
            }
        ], viewQueries: [{ propertyName: "headerNode", first: true, predicate: ["headerNode"], descendants: true, isSignal: true }, { propertyName: "infoNode", first: true, predicate: ["infoNode"], descendants: true, isSignal: true }, { propertyName: "socialProvidersNode", first: true, predicate: ["socialProvidersNode"], descendants: true, isSignal: true }], usesInheritance: true, ngImport: i0, template: "@let url = kcContext.url;\n@let messagesPerField = kcContext.messagesPerField;\n@let isAppInitiatedAction = kcContext.isAppInitiatedAction;\n\n<ng-template #headerNode>\n    {{ i18n.msgStr('updatePasswordTitle') }}\n</ng-template>\n<form\n    id=\"kc-passwd-update-form\"\n    method=\"post\"\n    [kcClass]=\"'kcFormClass'\"\n    [action]=\"url.loginAction\"\n>\n    <div [kcClass]=\"'kcFormGroupClass'\">\n        <div [kcClass]=\"'kcLabelWrapperClass'\">\n            <label\n                for=\"password-new\"\n                [kcClass]=\"'kcLabelClass'\"\n            >\n                {{ i18n.msgStr('passwordNew') }}\n            </label>\n        </div>\n        <div [kcClass]=\"'kcInputWrapperClass'\">\n            <kc-password-wrapper passwordInputId=\"password-new\">\n                <input\n                    type=\"password\"\n                    id=\"password-new\"\n                    name=\"password-new\"\n                    autoFocus\n                    autoComplete=\"new-password\"\n                    [kcClass]=\"'kcInputClass'\"\n                    [attr.aria-invalid]=\"messagesPerField.existsError('password', 'password-confirm')\"\n                />\n            </kc-password-wrapper>\n\n            @if (messagesPerField.existsError('password')) {\n                <span\n                    id=\"input-error-password\"\n                    aria-live=\"polite\"\n                    [kcClass]=\"'kcInputErrorMessageClass'\"\n                    [innerHtml]=\"messagesPerField.get('password') | kcSanitize: 'html'\"\n                ></span>\n            }\n        </div>\n    </div>\n\n    <div [kcClass]=\"'kcFormGroupClass'\">\n        <div [kcClass]=\"'kcLabelWrapperClass'\">\n            <label\n                for=\"password-confirm\"\n                [kcClass]=\"'kcLabelClass'\"\n            >\n                {{ i18n.msgStr('passwordConfirm') }}\n            </label>\n        </div>\n        <div [kcClass]=\"'kcInputWrapperClass'\">\n            <kc-password-wrapper passwordInputId=\"password-confirm\">\n                <input\n                    type=\"password\"\n                    id=\"password-confirm\"\n                    name=\"password-confirm\"\n                    autoFocus\n                    autoComplete=\"new-password\"\n                    [kcClass]=\"'kcInputClass'\"\n                    [attr.aria-invalid]=\"messagesPerField.existsError('password', 'password-confirm')\"\n                />\n            </kc-password-wrapper>\n            @if (messagesPerField.existsError('password-confirm')) {\n                <span\n                    id=\"input-error-password-confirm\"\n                    aria-live=\"polite\"\n                    [kcClass]=\"'kcInputErrorMessageClass'\"\n                    [innerHtml]=\"messagesPerField.get('password-confirm') | kcSanitize: 'html'\"\n                ></span>\n            }\n        </div>\n    </div>\n    <div [kcClass]=\"'kcFormGroupClass'\">\n        <kc-logout-other-sessions />\n        <div\n            id=\"kc-form-buttons\"\n            [kcClass]=\"'kcFormButtonsClass'\"\n        >\n            <input\n                type=\"submit\"\n                [kcClass]=\"{\n                    kcButtonClass: true,\n                    kcButtonPrimaryClass: true,\n                    kcButtonBlockClass: !isAppInitiatedAction,\n                    kcButtonLargeClass: true\n                }\"\n                [value]=\"i18n.msgStr('doSubmit')\"\n            />\n            @if (isAppInitiatedAction) {\n                <button\n                    type=\"submit\"\n                    name=\"cancel-aia\"\n                    value=\"true\"\n                    [kcClass]=\"['kcButtonClass', 'kcButtonDefaultClass', 'kcButtonLargeClass']\"\n                >\n                    {{ i18n.msgStr('doCancel') }}\n                </button>\n            }\n        </div>\n    </div>\n</form>\n", dependencies: [{ kind: "directive", type: KcClassDirective, selector: "[kcClass]", inputs: ["class", "ngClass", "kcClass"] }, { kind: "component", type: PasswordWrapperComponent, selector: "kc-password-wrapper", inputs: ["passwordInputId"] }, { kind: "pipe", type: KcSanitizePipe, name: "kcSanitize" }, { kind: "component", type: LogoutOtherSessionsComponent, selector: "kc-logout-other-sessions" }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: LoginUpdatePasswordComponent, decorators: [{
            type: Component,
            args: [{ imports: [KcClassDirective, PasswordWrapperComponent, KcSanitizePipe, LogoutOtherSessionsComponent], selector: 'kc-login-update-password', changeDetection: ChangeDetectionStrategy.OnPush, providers: [
                        {
                            provide: ComponentReference,
                            useExisting: forwardRef(() => LoginUpdatePasswordComponent)
                        }
                    ], template: "@let url = kcContext.url;\n@let messagesPerField = kcContext.messagesPerField;\n@let isAppInitiatedAction = kcContext.isAppInitiatedAction;\n\n<ng-template #headerNode>\n    {{ i18n.msgStr('updatePasswordTitle') }}\n</ng-template>\n<form\n    id=\"kc-passwd-update-form\"\n    method=\"post\"\n    [kcClass]=\"'kcFormClass'\"\n    [action]=\"url.loginAction\"\n>\n    <div [kcClass]=\"'kcFormGroupClass'\">\n        <div [kcClass]=\"'kcLabelWrapperClass'\">\n            <label\n                for=\"password-new\"\n                [kcClass]=\"'kcLabelClass'\"\n            >\n                {{ i18n.msgStr('passwordNew') }}\n            </label>\n        </div>\n        <div [kcClass]=\"'kcInputWrapperClass'\">\n            <kc-password-wrapper passwordInputId=\"password-new\">\n                <input\n                    type=\"password\"\n                    id=\"password-new\"\n                    name=\"password-new\"\n                    autoFocus\n                    autoComplete=\"new-password\"\n                    [kcClass]=\"'kcInputClass'\"\n                    [attr.aria-invalid]=\"messagesPerField.existsError('password', 'password-confirm')\"\n                />\n            </kc-password-wrapper>\n\n            @if (messagesPerField.existsError('password')) {\n                <span\n                    id=\"input-error-password\"\n                    aria-live=\"polite\"\n                    [kcClass]=\"'kcInputErrorMessageClass'\"\n                    [innerHtml]=\"messagesPerField.get('password') | kcSanitize: 'html'\"\n                ></span>\n            }\n        </div>\n    </div>\n\n    <div [kcClass]=\"'kcFormGroupClass'\">\n        <div [kcClass]=\"'kcLabelWrapperClass'\">\n            <label\n                for=\"password-confirm\"\n                [kcClass]=\"'kcLabelClass'\"\n            >\n                {{ i18n.msgStr('passwordConfirm') }}\n            </label>\n        </div>\n        <div [kcClass]=\"'kcInputWrapperClass'\">\n            <kc-password-wrapper passwordInputId=\"password-confirm\">\n                <input\n                    type=\"password\"\n                    id=\"password-confirm\"\n                    name=\"password-confirm\"\n                    autoFocus\n                    autoComplete=\"new-password\"\n                    [kcClass]=\"'kcInputClass'\"\n                    [attr.aria-invalid]=\"messagesPerField.existsError('password', 'password-confirm')\"\n                />\n            </kc-password-wrapper>\n            @if (messagesPerField.existsError('password-confirm')) {\n                <span\n                    id=\"input-error-password-confirm\"\n                    aria-live=\"polite\"\n                    [kcClass]=\"'kcInputErrorMessageClass'\"\n                    [innerHtml]=\"messagesPerField.get('password-confirm') | kcSanitize: 'html'\"\n                ></span>\n            }\n        </div>\n    </div>\n    <div [kcClass]=\"'kcFormGroupClass'\">\n        <kc-logout-other-sessions />\n        <div\n            id=\"kc-form-buttons\"\n            [kcClass]=\"'kcFormButtonsClass'\"\n        >\n            <input\n                type=\"submit\"\n                [kcClass]=\"{\n                    kcButtonClass: true,\n                    kcButtonPrimaryClass: true,\n                    kcButtonBlockClass: !isAppInitiatedAction,\n                    kcButtonLargeClass: true\n                }\"\n                [value]=\"i18n.msgStr('doSubmit')\"\n            />\n            @if (isAppInitiatedAction) {\n                <button\n                    type=\"submit\"\n                    name=\"cancel-aia\"\n                    value=\"true\"\n                    [kcClass]=\"['kcButtonClass', 'kcButtonDefaultClass', 'kcButtonLargeClass']\"\n                >\n                    {{ i18n.msgStr('doCancel') }}\n                </button>\n            }\n        </div>\n    </div>\n</form>\n" }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { LoginUpdatePasswordComponent };
//# sourceMappingURL=keycloakify-angular-login-pages-login-update-password.mjs.map
