import { NgComponentOutlet } from '@angular/common';
import * as i0 from '@angular/core';
import { inject, viewChild, input, forwardRef, ChangeDetectionStrategy, Component } from '@angular/core';
import { toSignal } from '@angular/core/rxjs-interop';
import { USE_DEFAULT_CSS } from '@keycloakify/angular/lib/tokens/use-default-css';
import { ComponentReference } from '@keycloakify/angular/login/classes/component-reference';
import { KcClassDirective } from '@keycloakify/angular/login/directives/kc-class';
import { UserProfileFormService } from '@keycloakify/angular/login/services/user-profile-form';
import { LOGIN_CLASSES } from '@keycloakify/angular/login/tokens/classes';
import { LOGIN_I18N } from '@keycloakify/angular/login/tokens/i18n';
import { KC_LOGIN_CONTEXT } from '@keycloakify/angular/login/tokens/kc-context';
import { map } from 'rxjs';

class LoginUpdateProfileComponent extends ComponentReference {
    constructor() {
        super(...arguments);
        this.#userProfileFormService = inject(UserProfileFormService);
        this.kcContext = inject(KC_LOGIN_CONTEXT);
        this.i18n = inject(LOGIN_I18N);
        this.doUseDefaultCss = inject(USE_DEFAULT_CSS);
        this.classes = inject(LOGIN_CLASSES);
        this.displayRequiredFields = true;
        this.displayInfo = false;
        this.displayMessage = this.kcContext.messagesPerField.exists('global');
        this.headerNode = viewChild('headerNode');
        this.infoNode = viewChild('infoNode');
        this.socialProvidersNode = viewChild('socialProvidersNode');
        this.isFormSubmittable = toSignal(this.#userProfileFormService.formState$.pipe(map(s => s.isFormSubmittable)), { initialValue: false });
        this.userProfileFormFields = input();
    }
    #userProfileFormService;
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: LoginUpdateProfileComponent, deps: null, target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "20.0.3", type: LoginUpdateProfileComponent, isStandalone: true, selector: "kc-login-update-profile", inputs: { userProfileFormFields: { classPropertyName: "userProfileFormFields", publicName: "userProfileFormFields", isSignal: true, isRequired: false, transformFunction: null } }, providers: [
            {
                provide: ComponentReference,
                useExisting: forwardRef(() => LoginUpdateProfileComponent)
            }
        ], viewQueries: [{ propertyName: "headerNode", first: true, predicate: ["headerNode"], descendants: true, isSignal: true }, { propertyName: "infoNode", first: true, predicate: ["infoNode"], descendants: true, isSignal: true }, { propertyName: "socialProvidersNode", first: true, predicate: ["socialProvidersNode"], descendants: true, isSignal: true }], usesInheritance: true, ngImport: i0, template: "@let url = kcContext.url;\n@let isAppInitiatedAction = kcContext.isAppInitiatedAction;\n\n<ng-template #headerNode>\n    {{ i18n.msgStr('loginProfileTitle') }}\n</ng-template>\n<form\n    id=\"kc-update-profile-form\"\n    method=\"post\"\n    [kcClass]=\"'kcFormClass'\"\n    [action]=\"url.loginAction\"\n>\n    <ng-container [ngComponentOutlet]=\"userProfileFormFields() ?? null\" />\n    <div [kcClass]=\"'kcFormGroupClass'\">\n        <div\n            id=\"kc-form-options\"\n            [kcClass]=\"'kcFormOptionsClass'\"\n        >\n            <div [kcClass]=\"'kcFormOptionsWrapperClass'\"></div>\n        </div>\n        <div\n            id=\"kc-form-buttons\"\n            [kcClass]=\"'kcFormButtonsClass'\"\n        >\n            <input\n                type=\"submit\"\n                [disabled]=\"!isFormSubmittable()\"\n                [kcClass]=\"{\n                    kcButtonClass: true,\n                    kcButtonPrimaryClass: true,\n                    kcButtonBlockClass: !isAppInitiatedAction,\n                    kcButtonLargeClass: true\n                }\"\n                [value]=\"i18n.msgStr('doSubmit')\"\n            />\n            @if (isAppInitiatedAction) {\n                <button\n                    type=\"submit\"\n                    name=\"cancel-aia\"\n                    value=\"true\"\n                    formNoValidate\n                    [kcClass]=\"['kcButtonClass', 'kcButtonDefaultClass', 'kcButtonLargeClass']\"\n                >\n                    {{ i18n.msgStr('doCancel') }}\n                </button>\n            }\n        </div>\n    </div>\n</form>\n", dependencies: [{ kind: "directive", type: KcClassDirective, selector: "[kcClass]", inputs: ["class", "ngClass", "kcClass"] }, { kind: "directive", type: NgComponentOutlet, selector: "[ngComponentOutlet]", inputs: ["ngComponentOutlet", "ngComponentOutletInputs", "ngComponentOutletInjector", "ngComponentOutletContent", "ngComponentOutletNgModule", "ngComponentOutletNgModuleFactory"], exportAs: ["ngComponentOutlet"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: LoginUpdateProfileComponent, decorators: [{
            type: Component,
            args: [{ imports: [KcClassDirective, NgComponentOutlet], selector: 'kc-login-update-profile', changeDetection: ChangeDetectionStrategy.OnPush, providers: [
                        {
                            provide: ComponentReference,
                            useExisting: forwardRef(() => LoginUpdateProfileComponent)
                        }
                    ], template: "@let url = kcContext.url;\n@let isAppInitiatedAction = kcContext.isAppInitiatedAction;\n\n<ng-template #headerNode>\n    {{ i18n.msgStr('loginProfileTitle') }}\n</ng-template>\n<form\n    id=\"kc-update-profile-form\"\n    method=\"post\"\n    [kcClass]=\"'kcFormClass'\"\n    [action]=\"url.loginAction\"\n>\n    <ng-container [ngComponentOutlet]=\"userProfileFormFields() ?? null\" />\n    <div [kcClass]=\"'kcFormGroupClass'\">\n        <div\n            id=\"kc-form-options\"\n            [kcClass]=\"'kcFormOptionsClass'\"\n        >\n            <div [kcClass]=\"'kcFormOptionsWrapperClass'\"></div>\n        </div>\n        <div\n            id=\"kc-form-buttons\"\n            [kcClass]=\"'kcFormButtonsClass'\"\n        >\n            <input\n                type=\"submit\"\n                [disabled]=\"!isFormSubmittable()\"\n                [kcClass]=\"{\n                    kcButtonClass: true,\n                    kcButtonPrimaryClass: true,\n                    kcButtonBlockClass: !isAppInitiatedAction,\n                    kcButtonLargeClass: true\n                }\"\n                [value]=\"i18n.msgStr('doSubmit')\"\n            />\n            @if (isAppInitiatedAction) {\n                <button\n                    type=\"submit\"\n                    name=\"cancel-aia\"\n                    value=\"true\"\n                    formNoValidate\n                    [kcClass]=\"['kcButtonClass', 'kcButtonDefaultClass', 'kcButtonLargeClass']\"\n                >\n                    {{ i18n.msgStr('doCancel') }}\n                </button>\n            }\n        </div>\n    </div>\n</form>\n" }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { LoginUpdateProfileComponent };
//# sourceMappingURL=keycloakify-angular-login-pages-login-update-profile.mjs.map
