import { NgComponentOutlet, AsyncPipe, NgClass } from '@angular/common';
import * as i0 from '@angular/core';
import { inject, viewChild, signal, input, forwardRef, ChangeDetectionStrategy, Component } from '@angular/core';
import { toSignal } from '@angular/core/rxjs-interop';
import { KcSanitizePipe } from '@keycloakify/angular/lib/pipes/kc-sanitize';
import { USE_DEFAULT_CSS } from '@keycloakify/angular/lib/tokens/use-default-css';
import { ComponentReference } from '@keycloakify/angular/login/classes/component-reference';
import { KcClassDirective } from '@keycloakify/angular/login/directives/kc-class';
import { UserProfileFormService } from '@keycloakify/angular/login/services/user-profile-form';
import { LOGIN_CLASSES } from '@keycloakify/angular/login/tokens/classes';
import { LOGIN_I18N } from '@keycloakify/angular/login/tokens/i18n';
import { KC_LOGIN_CONTEXT } from '@keycloakify/angular/login/tokens/kc-context';
import { map } from 'rxjs';

class RegisterComponent extends ComponentReference {
    constructor() {
        super(...arguments);
        this.#userProfileFormService = inject(UserProfileFormService);
        this.kcContext = inject(KC_LOGIN_CONTEXT);
        this.i18n = inject(LOGIN_I18N);
        this.doUseDefaultCss = inject(USE_DEFAULT_CSS);
        this.classes = inject(LOGIN_CLASSES);
        this.displayRequiredFields = false;
        this.displayInfo = false;
        this.displayMessage = this.kcContext?.messagesPerField?.existsError('global');
        this.headerNode = viewChild('headerNode');
        this.infoNode = viewChild('infoNode');
        this.socialProvidersNode = viewChild('socialProvidersNode');
        this.isFormSubmittable = toSignal(this.#userProfileFormService.formState$.pipe(map(s => s.isFormSubmittable)), { initialValue: false });
        this.areTermsAccepted = signal(false);
        this.userProfileFormFields = input();
    }
    #userProfileFormService;
    onCallback() {
        document.getElementById('kc-register-form').submit();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: RegisterComponent, deps: null, target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "20.0.3", type: RegisterComponent, isStandalone: true, selector: "kc-register", inputs: { userProfileFormFields: { classPropertyName: "userProfileFormFields", publicName: "userProfileFormFields", isSignal: true, isRequired: false, transformFunction: null } }, providers: [
            {
                provide: ComponentReference,
                useExisting: forwardRef(() => RegisterComponent)
            }
        ], viewQueries: [{ propertyName: "headerNode", first: true, predicate: ["headerNode"], descendants: true, isSignal: true }, { propertyName: "infoNode", first: true, predicate: ["infoNode"], descendants: true, isSignal: true }, { propertyName: "socialProvidersNode", first: true, predicate: ["socialProvidersNode"], descendants: true, isSignal: true }], usesInheritance: true, ngImport: i0, template: "@let url = kcContext.url;\n@let messagesPerField = kcContext.messagesPerField;\n@let recaptchaRequired = kcContext.recaptchaRequired;\n@let recaptchaVisible = kcContext.recaptchaVisible;\n@let recaptchaSiteKey = kcContext.recaptchaSiteKey;\n@let recaptchaAction = kcContext.recaptchaAction;\n@let termsAcceptanceRequired = kcContext.termsAcceptanceRequired;\n\n<ng-template #headerNode>\n    @let messageHeader = kcContext.messageHeader;\n    {{ messageHeader ?? i18n.advancedMsgStr('registerTitle') }}\n</ng-template>\n<form\n    id=\"kc-register-form\"\n    method=\"post\"\n    [kcClass]=\"'kcFormClass'\"\n    [action]=\"url.registrationAction\"\n>\n    <ng-container [ngComponentOutlet]=\"userProfileFormFields() ?? null\" />\n    @if (termsAcceptanceRequired) {\n        <div class=\"form-group\">\n            <div [kcClass]=\"'kcInputWrapperClass'\">\n                {{ i18n.msgStr('termsTitle') }}\n                <div id=\"kc-registration-terms-text\">\n                    {{ i18n.msgStr('termsText') }}\n                </div>\n            </div>\n        </div>\n        <div class=\"form-group\">\n            <div [kcClass]=\"'kcLabelWrapperClass'\">\n                <input\n                    type=\"checkbox\"\n                    id=\"termsAccepted\"\n                    name=\"termsAccepted\"\n                    [kcClass]=\"'kcCheckboxInputClass'\"\n                    [checked]=\"areTermsAccepted()\"\n                    [attr.aria-invalid]=\"messagesPerField.existsError('termsAccepted')\"\n                    (change)=\"areTermsAccepted.set($any($event.target).checked)\"\n                />\n                <label\n                    for=\"termsAccepted\"\n                    [kcClass]=\"'kcLabelClass'\"\n                >\n                    {{ i18n.msgStr('acceptTerms') }}\n                </label>\n            </div>\n            @if (messagesPerField.existsError('termsAccepted')) {\n                <div [kcClass]=\"'kcLabelWrapperClass'\">\n                    <span\n                        id=\"input-error-terms-accepted\"\n                        aria-live=\"polite\"\n                        [kcClass]=\"'kcInputErrorMessageClass'\"\n                        [innerHtml]=\"messagesPerField.get('termsAccepted') | kcSanitize: 'html'\"\n                    ></span>\n                </div>\n            }\n        </div>\n    }\n    @if (recaptchaRequired && (recaptchaVisible || recaptchaAction === undefined)) {\n        <div class=\"form-group\">\n            <div [kcClass]=\"'kcInputWrapperClass'\">\n                <div\n                    class=\"g-recaptcha\"\n                    data-size=\"compact\"\n                    [attr.data-sitekey]=\"recaptchaSiteKey\"\n                    [attr.data-action]=\"recaptchaAction\"\n                ></div>\n            </div>\n        </div>\n    }\n\n    <div [kcClass]=\"'kcFormGroupClass'\">\n        <div\n            id=\"kc-form-options\"\n            [kcClass]=\"'kcFormOptionsClass'\"\n        >\n            <div [kcClass]=\"'kcFormOptionsWrapperClass'\">\n                <span>\n                    <a\n                        [href]=\"url.loginUrl\"\n                        [innerHTML]=\"i18n.msgStr('backToLogin') | kcSanitize: 'html'\"\n                    ></a>\n                </span>\n            </div>\n        </div>\n        @if (recaptchaRequired && !recaptchaVisible && recaptchaAction !== undefined) {\n            <div\n                id=\"kc-form-buttons\"\n                [kcClass]=\"'kcFormButtonsClass'\"\n            >\n                <button\n                    class=\"g-recaptcha\"\n                    type=\"submit\"\n                    [kcClass]=\"['kcButtonClass', 'kcButtonPrimaryClass', 'kcButtonBlockClass', 'kcButtonLargeClass']\"\n                    [attr.data-sitekey]=\"recaptchaSiteKey\"\n                    [attr.data-callback]=\"onCallback\"\n                    [attr.data-action]=\"recaptchaAction\"\n                >\n                    {{ i18n.msgStr('doRegister') }}\n                </button>\n            </div>\n        } @else {\n            <div\n                id=\"kc-form-buttons\"\n                [kcClass]=\"'kcFormButtonsClass'\"\n            >\n                <input\n                    type=\"submit\"\n                    [disabled]=\"!isFormSubmittable() || (termsAcceptanceRequired && !areTermsAccepted())\"\n                    [kcClass]=\"['kcButtonClass', 'kcButtonPrimaryClass', 'kcButtonBlockClass', 'kcButtonLargeClass']\"\n                    [value]=\"i18n.msgStr('doRegister')\"\n                />\n            </div>\n        }\n    </div>\n</form>\n", dependencies: [{ kind: "directive", type: KcClassDirective, selector: "[kcClass]", inputs: ["class", "ngClass", "kcClass"] }, { kind: "pipe", type: KcSanitizePipe, name: "kcSanitize" }, { kind: "directive", type: NgComponentOutlet, selector: "[ngComponentOutlet]", inputs: ["ngComponentOutlet", "ngComponentOutletInputs", "ngComponentOutletInjector", "ngComponentOutletContent", "ngComponentOutletNgModule", "ngComponentOutletNgModuleFactory"], exportAs: ["ngComponentOutlet"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: RegisterComponent, decorators: [{
            type: Component,
            args: [{ selector: 'kc-register', changeDetection: ChangeDetectionStrategy.OnPush, imports: [KcClassDirective, AsyncPipe, KcSanitizePipe, NgClass, NgComponentOutlet], providers: [
                        {
                            provide: ComponentReference,
                            useExisting: forwardRef(() => RegisterComponent)
                        }
                    ], template: "@let url = kcContext.url;\n@let messagesPerField = kcContext.messagesPerField;\n@let recaptchaRequired = kcContext.recaptchaRequired;\n@let recaptchaVisible = kcContext.recaptchaVisible;\n@let recaptchaSiteKey = kcContext.recaptchaSiteKey;\n@let recaptchaAction = kcContext.recaptchaAction;\n@let termsAcceptanceRequired = kcContext.termsAcceptanceRequired;\n\n<ng-template #headerNode>\n    @let messageHeader = kcContext.messageHeader;\n    {{ messageHeader ?? i18n.advancedMsgStr('registerTitle') }}\n</ng-template>\n<form\n    id=\"kc-register-form\"\n    method=\"post\"\n    [kcClass]=\"'kcFormClass'\"\n    [action]=\"url.registrationAction\"\n>\n    <ng-container [ngComponentOutlet]=\"userProfileFormFields() ?? null\" />\n    @if (termsAcceptanceRequired) {\n        <div class=\"form-group\">\n            <div [kcClass]=\"'kcInputWrapperClass'\">\n                {{ i18n.msgStr('termsTitle') }}\n                <div id=\"kc-registration-terms-text\">\n                    {{ i18n.msgStr('termsText') }}\n                </div>\n            </div>\n        </div>\n        <div class=\"form-group\">\n            <div [kcClass]=\"'kcLabelWrapperClass'\">\n                <input\n                    type=\"checkbox\"\n                    id=\"termsAccepted\"\n                    name=\"termsAccepted\"\n                    [kcClass]=\"'kcCheckboxInputClass'\"\n                    [checked]=\"areTermsAccepted()\"\n                    [attr.aria-invalid]=\"messagesPerField.existsError('termsAccepted')\"\n                    (change)=\"areTermsAccepted.set($any($event.target).checked)\"\n                />\n                <label\n                    for=\"termsAccepted\"\n                    [kcClass]=\"'kcLabelClass'\"\n                >\n                    {{ i18n.msgStr('acceptTerms') }}\n                </label>\n            </div>\n            @if (messagesPerField.existsError('termsAccepted')) {\n                <div [kcClass]=\"'kcLabelWrapperClass'\">\n                    <span\n                        id=\"input-error-terms-accepted\"\n                        aria-live=\"polite\"\n                        [kcClass]=\"'kcInputErrorMessageClass'\"\n                        [innerHtml]=\"messagesPerField.get('termsAccepted') | kcSanitize: 'html'\"\n                    ></span>\n                </div>\n            }\n        </div>\n    }\n    @if (recaptchaRequired && (recaptchaVisible || recaptchaAction === undefined)) {\n        <div class=\"form-group\">\n            <div [kcClass]=\"'kcInputWrapperClass'\">\n                <div\n                    class=\"g-recaptcha\"\n                    data-size=\"compact\"\n                    [attr.data-sitekey]=\"recaptchaSiteKey\"\n                    [attr.data-action]=\"recaptchaAction\"\n                ></div>\n            </div>\n        </div>\n    }\n\n    <div [kcClass]=\"'kcFormGroupClass'\">\n        <div\n            id=\"kc-form-options\"\n            [kcClass]=\"'kcFormOptionsClass'\"\n        >\n            <div [kcClass]=\"'kcFormOptionsWrapperClass'\">\n                <span>\n                    <a\n                        [href]=\"url.loginUrl\"\n                        [innerHTML]=\"i18n.msgStr('backToLogin') | kcSanitize: 'html'\"\n                    ></a>\n                </span>\n            </div>\n        </div>\n        @if (recaptchaRequired && !recaptchaVisible && recaptchaAction !== undefined) {\n            <div\n                id=\"kc-form-buttons\"\n                [kcClass]=\"'kcFormButtonsClass'\"\n            >\n                <button\n                    class=\"g-recaptcha\"\n                    type=\"submit\"\n                    [kcClass]=\"['kcButtonClass', 'kcButtonPrimaryClass', 'kcButtonBlockClass', 'kcButtonLargeClass']\"\n                    [attr.data-sitekey]=\"recaptchaSiteKey\"\n                    [attr.data-callback]=\"onCallback\"\n                    [attr.data-action]=\"recaptchaAction\"\n                >\n                    {{ i18n.msgStr('doRegister') }}\n                </button>\n            </div>\n        } @else {\n            <div\n                id=\"kc-form-buttons\"\n                [kcClass]=\"'kcFormButtonsClass'\"\n            >\n                <input\n                    type=\"submit\"\n                    [disabled]=\"!isFormSubmittable() || (termsAcceptanceRequired && !areTermsAccepted())\"\n                    [kcClass]=\"['kcButtonClass', 'kcButtonPrimaryClass', 'kcButtonBlockClass', 'kcButtonLargeClass']\"\n                    [value]=\"i18n.msgStr('doRegister')\"\n                />\n            </div>\n        }\n    </div>\n</form>\n" }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { RegisterComponent };
//# sourceMappingURL=keycloakify-angular-login-pages-register.mjs.map
