import * as i0 from '@angular/core';
import { inject, viewChild, forwardRef, ChangeDetectionStrategy, Component } from '@angular/core';
import { USE_DEFAULT_CSS } from '@keycloakify/angular/lib/tokens/use-default-css';
import { ComponentReference } from '@keycloakify/angular/login/classes/component-reference';
import { LogoutOtherSessionsComponent } from '@keycloakify/angular/login/components/logout-other-sessions';
import { KcClassDirective } from '@keycloakify/angular/login/directives/kc-class';
import { LoginResourceInjectorService } from '@keycloakify/angular/login/services/login-resource-injector';
import { LOGIN_CLASSES } from '@keycloakify/angular/login/tokens/classes';
import { LOGIN_I18N } from '@keycloakify/angular/login/tokens/i18n';
import { KC_LOGIN_CONTEXT } from '@keycloakify/angular/login/tokens/kc-context';
import { getKcClsx } from 'keycloakify/login/lib/kcClsx';

class WebauthnAuthenticateComponent extends ComponentReference {
    constructor() {
        super();
        this.kcContext = inject(KC_LOGIN_CONTEXT);
        this.loginResourceInjectorService = inject(LoginResourceInjectorService);
        this.i18n = inject(LOGIN_I18N);
        this.doUseDefaultCss = inject(USE_DEFAULT_CSS);
        this.classes = inject(LOGIN_CLASSES);
        this.displayRequiredFields = false;
        this.displayInfo = false;
        this.displayMessage = true;
        this.headerNode = viewChild('headerNode');
        this.infoNode = viewChild('infoNode');
        this.socialProvidersNode = viewChild('socialProvidersNode');
        this.authButtonId = 'authenticateWebAuthnButton';
        const { url, isUserIdentified, challenge, userVerification, rpId, createTimeout } = this.kcContext;
        const scripts = [
            {
                type: 'module',
                id: 'WebAuthnAuthenticateScript',
                textContent: `
              import { authenticateByWebAuthn } from "${url.resourcesPath}/js/webauthnAuthenticate.js";
              const authButton = document.getElementById('${this.authButtonId}');
              authButton.addEventListener("click", function() {
                  const input = {
                      isUserIdentified : ${isUserIdentified},
                      challenge : '${challenge}',
                      userVerification : '${userVerification}',
                      rpId : '${rpId}',
                      createTimeout : ${createTimeout},
                      errmsg : ${JSON.stringify(this.i18n.msgStr('webauthn-unsupported-browser-text'))}
                  };
                  authenticateByWebAuthn(input);
              });
          `
            }
        ];
        this.loginResourceInjectorService.insertAdditionalScripts(scripts);
    }
    selectAuthListItemIconClass(iconClass) {
        const kcClsx = getKcClsx({
            doUseDefaultCss: this.doUseDefaultCss ?? true,
            classes: this.classes
        }).kcClsx;
        // eslint-disable-next-line @typescript-eslint/no-explicit-any
        const className = kcClsx(iconClass);
        if (className === iconClass) {
            return kcClsx('kcWebAuthnDefaultIcon');
        }
        return className;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: WebauthnAuthenticateComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "20.0.3", type: WebauthnAuthenticateComponent, isStandalone: true, selector: "kc-webauthn-authenticate", providers: [
            {
                provide: ComponentReference,
                useExisting: forwardRef(() => WebauthnAuthenticateComponent)
            }
        ], viewQueries: [{ propertyName: "headerNode", first: true, predicate: ["headerNode"], descendants: true, isSignal: true }, { propertyName: "infoNode", first: true, predicate: ["infoNode"], descendants: true, isSignal: true }, { propertyName: "socialProvidersNode", first: true, predicate: ["socialProvidersNode"], descendants: true, isSignal: true }], usesInheritance: true, ngImport: i0, template: "@let url = kcContext.url;\n@let authenticators = kcContext.authenticators;\n@let shouldDisplayAuthenticators = kcContext.shouldDisplayAuthenticators;\n\n<ng-template #headerNode>\n    {{ i18n.msgStr('webauthn-login-title') }}\n</ng-template>\n<ng-template #infoNode>\n    @let url = kcContext.url;\n    <div id=\"kc-registration\">\n        <span>\n            {{ i18n.msgStr('noAccount') }}\n            <a\n                tabIndex=\"6\"\n                [href]=\"url.registrationUrl\"\n            >\n                {{ i18n.msgStr('doRegister') }}\n            </a>\n        </span>\n    </div>\n</ng-template>\n<div\n    id=\"kc-form-webauthn\"\n    [kcClass]=\"'kcFormClass'\"\n>\n    <form\n        id=\"webauth\"\n        method=\"post\"\n        [action]=\"url.loginAction\"\n    >\n        <input\n            type=\"hidden\"\n            id=\"clientDataJSON\"\n            name=\"clientDataJSON\"\n        />\n        <input\n            type=\"hidden\"\n            id=\"authenticatorData\"\n            name=\"authenticatorData\"\n        />\n        <input\n            type=\"hidden\"\n            id=\"signature\"\n            name=\"signature\"\n        />\n        <input\n            type=\"hidden\"\n            id=\"credentialId\"\n            name=\"credentialId\"\n        />\n        <input\n            type=\"hidden\"\n            id=\"userHandle\"\n            name=\"userHandle\"\n        />\n        <input\n            type=\"hidden\"\n            id=\"error\"\n            name=\"error\"\n        />\n    </form>\n\n    <div\n        class=\"no-bottom-margin\"\n        [kcClass]=\"'kcFormGroupClass'\"\n    >\n        @if (authenticators) {\n            <form\n                id=\"authn_select\"\n                [kcClass]=\"'kcFormClass'\"\n            >\n                @for (authenticator of authenticators.authenticators; track authenticator.credentialId) {\n                    <input\n                        type=\"hidden\"\n                        name=\"authn_use_chk\"\n                        [value]=\"authenticator.credentialId\"\n                    />\n                }\n                @if (shouldDisplayAuthenticators) {\n                    @if (authenticators.authenticators.length > 1) {\n                        <p [kcClass]=\"'kcSelectAuthListItemTitle'\">\n                            {{ i18n.msgStr('webauthn-available-authenticators') }}\n                        </p>\n                    }\n                    <div [kcClass]=\"'kcFormOptionsClass'\">\n                        @for (authenticator of authenticators.authenticators; track authenticator.credentialId; let i = $index) {\n                            <div\n                                [id]=\"'kc-webauthn-authenticator-item-' + i\"\n                                [kcClass]=\"'kcSelectAuthListItemClass'\"\n                            >\n                                <div [kcClass]=\"'kcSelectAuthListItemIconClass'\">\n                                    <i\n                                        [ngClass]=\"selectAuthListItemIconClass(authenticator.transports.iconClass)\"\n                                        [kcClass]=\"'kcSelectAuthListItemIconPropertyClass'\"\n                                    ></i>\n                                    <div [kcClass]=\"'kcSelectAuthListItemArrowIconClass'\">\n                                        <div\n                                            [id]=\"'kc-webauthn-authenticator-label-' + i\"\n                                            [kcClass]=\"'kcSelectAuthListItemHeadingClass'\"\n                                        >\n                                            {{ i18n.advancedMsgStr(authenticator.label) }}\n                                        </div>\n                                        @if (authenticator.transports.displayNameProperties?.length) {\n                                            <div\n                                                [id]=\"'kc-webauthn-authenticator-transport-' + i\"\n                                                [kcClass]=\"'kcSelectAuthListItemDescriptionClass'\"\n                                            >\n                                                @for (\n                                                    displayNameProperty of authenticator.transports.displayNameProperties;\n                                                    track displayNameProperty;\n                                                    let last = $last\n                                                ) {\n                                                    {{ i18n.advancedMsgStr(displayNameProperty) }}\n                                                    @if (!last) {\n                                                        <span>, </span>\n                                                    }\n                                                }\n                                            </div>\n                                            <div [kcClass]=\"'kcSelectAuthListItemDescriptionClass'\">\n                                                <span [id]=\"'kc-webauthn-authenticator-createdlabel-' + i\">\n                                                    {{ i18n.msgStr('webauthn-createdAt-label') }}\n                                                </span>\n                                                <span [id]=\"'kc-webauthn-authenticator-created-' + i\">{{ authenticator.createdAt }}</span>\n                                            </div>\n                                            <div [kcClass]=\"'kcSelectAuthListItemFillClass'\"></div>\n                                        }\n                                    </div>\n                                </div>\n                            </div>\n                        }\n                    </div>\n                }\n            </form>\n        }\n\n        <div\n            id=\"kc-form-buttons\"\n            [kcClass]=\"'kcFormButtonsClass'\"\n        >\n            <input\n                type=\"button\"\n                autofocus\n                name=\"cancel-aia\"\n                [id]=\"authButtonId\"\n                [kcClass]=\"['kcButtonClass', 'kcButtonDefaultClass', 'kcButtonBlockClass', 'kcButtonLargeClass']\"\n                [value]=\"i18n.msgStr('webauthn-doAuthenticate')\"\n            />\n        </div>\n    </div>\n</div>\n", dependencies: [{ kind: "directive", type: KcClassDirective, selector: "[kcClass]", inputs: ["class", "ngClass", "kcClass"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: WebauthnAuthenticateComponent, decorators: [{
            type: Component,
            args: [{ imports: [KcClassDirective, LogoutOtherSessionsComponent], selector: 'kc-webauthn-authenticate', changeDetection: ChangeDetectionStrategy.OnPush, providers: [
                        {
                            provide: ComponentReference,
                            useExisting: forwardRef(() => WebauthnAuthenticateComponent)
                        }
                    ], template: "@let url = kcContext.url;\n@let authenticators = kcContext.authenticators;\n@let shouldDisplayAuthenticators = kcContext.shouldDisplayAuthenticators;\n\n<ng-template #headerNode>\n    {{ i18n.msgStr('webauthn-login-title') }}\n</ng-template>\n<ng-template #infoNode>\n    @let url = kcContext.url;\n    <div id=\"kc-registration\">\n        <span>\n            {{ i18n.msgStr('noAccount') }}\n            <a\n                tabIndex=\"6\"\n                [href]=\"url.registrationUrl\"\n            >\n                {{ i18n.msgStr('doRegister') }}\n            </a>\n        </span>\n    </div>\n</ng-template>\n<div\n    id=\"kc-form-webauthn\"\n    [kcClass]=\"'kcFormClass'\"\n>\n    <form\n        id=\"webauth\"\n        method=\"post\"\n        [action]=\"url.loginAction\"\n    >\n        <input\n            type=\"hidden\"\n            id=\"clientDataJSON\"\n            name=\"clientDataJSON\"\n        />\n        <input\n            type=\"hidden\"\n            id=\"authenticatorData\"\n            name=\"authenticatorData\"\n        />\n        <input\n            type=\"hidden\"\n            id=\"signature\"\n            name=\"signature\"\n        />\n        <input\n            type=\"hidden\"\n            id=\"credentialId\"\n            name=\"credentialId\"\n        />\n        <input\n            type=\"hidden\"\n            id=\"userHandle\"\n            name=\"userHandle\"\n        />\n        <input\n            type=\"hidden\"\n            id=\"error\"\n            name=\"error\"\n        />\n    </form>\n\n    <div\n        class=\"no-bottom-margin\"\n        [kcClass]=\"'kcFormGroupClass'\"\n    >\n        @if (authenticators) {\n            <form\n                id=\"authn_select\"\n                [kcClass]=\"'kcFormClass'\"\n            >\n                @for (authenticator of authenticators.authenticators; track authenticator.credentialId) {\n                    <input\n                        type=\"hidden\"\n                        name=\"authn_use_chk\"\n                        [value]=\"authenticator.credentialId\"\n                    />\n                }\n                @if (shouldDisplayAuthenticators) {\n                    @if (authenticators.authenticators.length > 1) {\n                        <p [kcClass]=\"'kcSelectAuthListItemTitle'\">\n                            {{ i18n.msgStr('webauthn-available-authenticators') }}\n                        </p>\n                    }\n                    <div [kcClass]=\"'kcFormOptionsClass'\">\n                        @for (authenticator of authenticators.authenticators; track authenticator.credentialId; let i = $index) {\n                            <div\n                                [id]=\"'kc-webauthn-authenticator-item-' + i\"\n                                [kcClass]=\"'kcSelectAuthListItemClass'\"\n                            >\n                                <div [kcClass]=\"'kcSelectAuthListItemIconClass'\">\n                                    <i\n                                        [ngClass]=\"selectAuthListItemIconClass(authenticator.transports.iconClass)\"\n                                        [kcClass]=\"'kcSelectAuthListItemIconPropertyClass'\"\n                                    ></i>\n                                    <div [kcClass]=\"'kcSelectAuthListItemArrowIconClass'\">\n                                        <div\n                                            [id]=\"'kc-webauthn-authenticator-label-' + i\"\n                                            [kcClass]=\"'kcSelectAuthListItemHeadingClass'\"\n                                        >\n                                            {{ i18n.advancedMsgStr(authenticator.label) }}\n                                        </div>\n                                        @if (authenticator.transports.displayNameProperties?.length) {\n                                            <div\n                                                [id]=\"'kc-webauthn-authenticator-transport-' + i\"\n                                                [kcClass]=\"'kcSelectAuthListItemDescriptionClass'\"\n                                            >\n                                                @for (\n                                                    displayNameProperty of authenticator.transports.displayNameProperties;\n                                                    track displayNameProperty;\n                                                    let last = $last\n                                                ) {\n                                                    {{ i18n.advancedMsgStr(displayNameProperty) }}\n                                                    @if (!last) {\n                                                        <span>, </span>\n                                                    }\n                                                }\n                                            </div>\n                                            <div [kcClass]=\"'kcSelectAuthListItemDescriptionClass'\">\n                                                <span [id]=\"'kc-webauthn-authenticator-createdlabel-' + i\">\n                                                    {{ i18n.msgStr('webauthn-createdAt-label') }}\n                                                </span>\n                                                <span [id]=\"'kc-webauthn-authenticator-created-' + i\">{{ authenticator.createdAt }}</span>\n                                            </div>\n                                            <div [kcClass]=\"'kcSelectAuthListItemFillClass'\"></div>\n                                        }\n                                    </div>\n                                </div>\n                            </div>\n                        }\n                    </div>\n                }\n            </form>\n        }\n\n        <div\n            id=\"kc-form-buttons\"\n            [kcClass]=\"'kcFormButtonsClass'\"\n        >\n            <input\n                type=\"button\"\n                autofocus\n                name=\"cancel-aia\"\n                [id]=\"authButtonId\"\n                [kcClass]=\"['kcButtonClass', 'kcButtonDefaultClass', 'kcButtonBlockClass', 'kcButtonLargeClass']\"\n                [value]=\"i18n.msgStr('webauthn-doAuthenticate')\"\n            />\n        </div>\n    </div>\n</div>\n" }]
        }], ctorParameters: () => [] });

/**
 * Generated bundle index. Do not edit.
 */

export { WebauthnAuthenticateComponent };
//# sourceMappingURL=keycloakify-angular-login-pages-webauthn-authenticate.mjs.map
