import * as i0 from '@angular/core';
import { inject, viewChild, forwardRef, ChangeDetectionStrategy, Component } from '@angular/core';
import { USE_DEFAULT_CSS } from '@keycloakify/angular/lib/tokens/use-default-css';
import { ComponentReference } from '@keycloakify/angular/login/classes/component-reference';
import { LogoutOtherSessionsComponent } from '@keycloakify/angular/login/components/logout-other-sessions';
import { KcClassDirective } from '@keycloakify/angular/login/directives/kc-class';
import { LoginResourceInjectorService } from '@keycloakify/angular/login/services/login-resource-injector';
import { LOGIN_CLASSES } from '@keycloakify/angular/login/tokens/classes';
import { LOGIN_I18N } from '@keycloakify/angular/login/tokens/i18n';
import { KC_LOGIN_CONTEXT } from '@keycloakify/angular/login/tokens/kc-context';

class WebauthnRegisterComponent extends ComponentReference {
    constructor() {
        super();
        this.kcContext = inject(KC_LOGIN_CONTEXT);
        this.loginResourceInjectorService = inject(LoginResourceInjectorService);
        this.i18n = inject(LOGIN_I18N);
        this.doUseDefaultCss = inject(USE_DEFAULT_CSS);
        this.classes = inject(LOGIN_CLASSES);
        this.displayRequiredFields = false;
        this.displayInfo = false;
        this.displayMessage = true;
        this.headerNode = viewChild('headerNode');
        this.infoNode = viewChild('infoNode');
        this.socialProvidersNode = viewChild('socialProvidersNode');
        this.authButtonId = 'authenticateWebAuthnButton';
        const { url, challenge, userid, username, signatureAlgorithms, rpEntityName, rpId, attestationConveyancePreference, authenticatorAttachment, requireResidentKey, userVerificationRequirement, createTimeout, excludeCredentialIds } = this.kcContext;
        const scripts = [
            {
                type: 'module',
                id: 'WebAuthnRegisterScript',
                textContent: `
              import { registerByWebAuthn } from "${url.resourcesPath}/js/webauthnRegister.js";
              const registerButton = document.getElementById('${this.authButtonId}');
              registerButton.addEventListener("click", function() {
                  const input = {
                      challenge : '${challenge}',
                      userid : '${userid}',
                      username : '${username}',
                      signatureAlgorithms : ${JSON.stringify(signatureAlgorithms)},
                      rpEntityName : ${JSON.stringify(rpEntityName)},
                      rpId : ${JSON.stringify(rpId)},
                      attestationConveyancePreference : ${JSON.stringify(attestationConveyancePreference)},
                      authenticatorAttachment : ${JSON.stringify(authenticatorAttachment)},
                      requireResidentKey : ${JSON.stringify(requireResidentKey)},
                      userVerificationRequirement : ${JSON.stringify(userVerificationRequirement)},
                      createTimeout : ${createTimeout},
                      excludeCredentialIds : ${JSON.stringify(excludeCredentialIds)},
                      initLabel : ${JSON.stringify(this.i18n.msgStr('webauthn-registration-init-label'))},
                      initLabelPrompt : ${JSON.stringify(this.i18n.msgStr('webauthn-registration-init-label-prompt'))},
                      errmsg : ${JSON.stringify(this.i18n.msgStr('webauthn-unsupported-browser-text'))}
                  };
                  registerByWebAuthn(input);
              });
          `
            }
        ];
        this.loginResourceInjectorService.insertAdditionalScripts(scripts);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: WebauthnRegisterComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "20.0.3", type: WebauthnRegisterComponent, isStandalone: true, selector: "kc-webauthn-register", providers: [
            {
                provide: ComponentReference,
                useExisting: forwardRef(() => WebauthnRegisterComponent)
            }
        ], viewQueries: [{ propertyName: "headerNode", first: true, predicate: ["headerNode"], descendants: true, isSignal: true }, { propertyName: "infoNode", first: true, predicate: ["infoNode"], descendants: true, isSignal: true }, { propertyName: "socialProvidersNode", first: true, predicate: ["socialProvidersNode"], descendants: true, isSignal: true }], usesInheritance: true, ngImport: i0, template: "@let url = kcContext.url;\n@let isSetRetry = kcContext.isSetRetry;\n@let isAppInitiatedAction = kcContext.isAppInitiatedAction;\n\n<ng-template #headerNode>\n    <span [kcClass]=\"'kcWebAuthnKeyIcon'\"></span>\n    {{ i18n.msgStr('webauthn-registration-title') }}\n</ng-template>\n<form\n    id=\"register\"\n    method=\"post\"\n    [kcClass]=\"'kcFormClass'\"\n    [action]=\"url.loginAction\"\n>\n    <div [kcClass]=\"'kcFormGroupClass'\">\n        <input\n            type=\"hidden\"\n            id=\"clientDataJSON\"\n            name=\"clientDataJSON\"\n        />\n        <input\n            type=\"hidden\"\n            id=\"attestationObject\"\n            name=\"attestationObject\"\n        />\n        <input\n            type=\"hidden\"\n            id=\"publicKeyCredentialId\"\n            name=\"publicKeyCredentialId\"\n        />\n        <input\n            type=\"hidden\"\n            id=\"authenticatorLabel\"\n            name=\"authenticatorLabel\"\n        />\n        <input\n            type=\"hidden\"\n            id=\"transports\"\n            name=\"transports\"\n        />\n        <input\n            type=\"hidden\"\n            id=\"error\"\n            name=\"error\"\n        />\n        <kc-logout-other-sessions />\n    </div>\n</form>\n<input\n    type=\"submit\"\n    [kcClass]=\"['kcButtonClass', 'kcButtonPrimaryClass', 'kcButtonBlockClass', 'kcButtonLargeClass']\"\n    [id]=\"authButtonId\"\n    [value]=\"i18n.msgStr('doRegisterSecurityKey')\"\n/>\n@if (!isSetRetry && isAppInitiatedAction) {\n    <form\n        id=\"kc-webauthn-settings-form\"\n        method=\"post\"\n        [action]=\"url.loginAction\"\n        [kcClass]=\"'kcFormClass'\"\n    >\n        <button\n            type=\"submit\"\n            id=\"cancelWebAuthnAIA\"\n            name=\"cancel-aia\"\n            value=\"true\"\n            [kcClass]=\"['kcButtonClass', 'kcButtonDefaultClass', 'kcButtonBlockClass', 'kcButtonLargeClass']\"\n        >\n            {{ i18n.msgStr('doCancel') }}\n        </button>\n    </form>\n}\n", dependencies: [{ kind: "directive", type: KcClassDirective, selector: "[kcClass]", inputs: ["class", "ngClass", "kcClass"] }, { kind: "component", type: LogoutOtherSessionsComponent, selector: "kc-logout-other-sessions" }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: WebauthnRegisterComponent, decorators: [{
            type: Component,
            args: [{ imports: [KcClassDirective, LogoutOtherSessionsComponent], selector: 'kc-webauthn-register', changeDetection: ChangeDetectionStrategy.OnPush, providers: [
                        {
                            provide: ComponentReference,
                            useExisting: forwardRef(() => WebauthnRegisterComponent)
                        }
                    ], template: "@let url = kcContext.url;\n@let isSetRetry = kcContext.isSetRetry;\n@let isAppInitiatedAction = kcContext.isAppInitiatedAction;\n\n<ng-template #headerNode>\n    <span [kcClass]=\"'kcWebAuthnKeyIcon'\"></span>\n    {{ i18n.msgStr('webauthn-registration-title') }}\n</ng-template>\n<form\n    id=\"register\"\n    method=\"post\"\n    [kcClass]=\"'kcFormClass'\"\n    [action]=\"url.loginAction\"\n>\n    <div [kcClass]=\"'kcFormGroupClass'\">\n        <input\n            type=\"hidden\"\n            id=\"clientDataJSON\"\n            name=\"clientDataJSON\"\n        />\n        <input\n            type=\"hidden\"\n            id=\"attestationObject\"\n            name=\"attestationObject\"\n        />\n        <input\n            type=\"hidden\"\n            id=\"publicKeyCredentialId\"\n            name=\"publicKeyCredentialId\"\n        />\n        <input\n            type=\"hidden\"\n            id=\"authenticatorLabel\"\n            name=\"authenticatorLabel\"\n        />\n        <input\n            type=\"hidden\"\n            id=\"transports\"\n            name=\"transports\"\n        />\n        <input\n            type=\"hidden\"\n            id=\"error\"\n            name=\"error\"\n        />\n        <kc-logout-other-sessions />\n    </div>\n</form>\n<input\n    type=\"submit\"\n    [kcClass]=\"['kcButtonClass', 'kcButtonPrimaryClass', 'kcButtonBlockClass', 'kcButtonLargeClass']\"\n    [id]=\"authButtonId\"\n    [value]=\"i18n.msgStr('doRegisterSecurityKey')\"\n/>\n@if (!isSetRetry && isAppInitiatedAction) {\n    <form\n        id=\"kc-webauthn-settings-form\"\n        method=\"post\"\n        [action]=\"url.loginAction\"\n        [kcClass]=\"'kcFormClass'\"\n    >\n        <button\n            type=\"submit\"\n            id=\"cancelWebAuthnAIA\"\n            name=\"cancel-aia\"\n            value=\"true\"\n            [kcClass]=\"['kcButtonClass', 'kcButtonDefaultClass', 'kcButtonBlockClass', 'kcButtonLargeClass']\"\n        >\n            {{ i18n.msgStr('doCancel') }}\n        </button>\n    </form>\n}\n" }]
        }], ctorParameters: () => [] });

/**
 * Generated bundle index. Do not edit.
 */

export { WebauthnRegisterComponent };
//# sourceMappingURL=keycloakify-angular-login-pages-webauthn-register.mjs.map
