import * as i0 from '@angular/core';
import { inject, Injectable } from '@angular/core';
import { KC_LOGIN_CONTEXT } from '@keycloakify/angular/login/tokens/kc-context';
import { ResourceInjectorService } from '@keycloakify/angular/lib/services/resource-injector';
import { of, forkJoin, switchMap, catchError } from 'rxjs';

class LoginResourceInjectorService {
    constructor() {
        this.kcContext = inject(KC_LOGIN_CONTEXT);
        this.resourceInjectorService = inject(ResourceInjectorService);
    }
    injectResource(doUseDefaultCss = true) {
        if (!doUseDefaultCss) {
            this.injectScripts();
            return of(true);
        }
        //reversed order of stylesheets to accomodate prepending to head
        const stylesheets = [
            `${this.kcContext.url.resourcesPath}/css/login.css`,
            `${this.kcContext.url.resourcesCommonPath}/lib/pficon/pficon.css`,
            `${this.kcContext.url.resourcesCommonPath}/node_modules/patternfly/dist/css/patternfly-additions.min.css`,
            `${this.kcContext.url.resourcesCommonPath}/node_modules/patternfly/dist/css/patternfly.min.css`,
            `${this.kcContext.url.resourcesCommonPath}/node_modules/@patternfly/patternfly/patternfly.min.css`
        ];
        return forkJoin(stylesheets.map(url => this.resourceInjectorService.createLink(url))).pipe(switchMap(() => {
            this.injectScripts();
            return of(true);
        }), catchError(error => {
            console.error('Error loading styles:', error);
            return of(false);
        }));
    }
    insertAdditionalScripts(scripts) {
        scripts.map(script => this.resourceInjectorService.createScript(script));
    }
    injectScripts() {
        const scripts = [
            {
                type: 'module',
                id: `${this.kcContext.url.resourcesPath}/js/menu-button-links.js`,
                src: `${this.kcContext.url.resourcesPath}/js/menu-button-links.js`
            },
            ...(this.kcContext.scripts ?? []).map(script => ({
                type: 'text/javascript',
                src: script,
                id: script
            })),
            {
                type: 'module',
                id: 'authenticationSession',
                textContent: `
        import { checkCookiesAndSetTimer } from "${this.kcContext.url.resourcesPath}/js/authChecker.js";
          
        checkCookiesAndSetTimer(
            "${this.kcContext.url.ssoLoginInOtherTabsUrl}"
        );`
            }
        ];
        this.insertAdditionalScripts(scripts);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: LoginResourceInjectorService, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: LoginResourceInjectorService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: LoginResourceInjectorService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { LoginResourceInjectorService };
//# sourceMappingURL=keycloakify-angular-login-services-login-resource-injector.mjs.map
