import { AsyncPipe, NgTemplateOutlet } from '@angular/common';
import * as i0 from '@angular/core';
import { inject, Renderer2, ChangeDetectorRef, input, viewChild, ViewContainerRef, effect, computed, forwardRef, ChangeDetectionStrategy, Component } from '@angular/core';
import { Meta, Title } from '@angular/platform-browser';
import { KcSanitizePipe } from '@keycloakify/angular/lib/pipes/kc-sanitize';
import { USE_DEFAULT_CSS } from '@keycloakify/angular/lib/tokens/use-default-css';
import { ComponentReference } from '@keycloakify/angular/login/classes/component-reference';
import { KcClassDirective } from '@keycloakify/angular/login/directives/kc-class';
import { LoginResourceInjectorService } from '@keycloakify/angular/login/services/login-resource-injector';
import { LOGIN_CLASSES } from '@keycloakify/angular/login/tokens/classes';
import { LOGIN_I18N } from '@keycloakify/angular/login/tokens/i18n';
import { KC_LOGIN_CONTEXT } from '@keycloakify/angular/login/tokens/kc-context';
import { getKcClsx } from 'keycloakify/login/lib/kcClsx';

class TemplateComponent extends ComponentReference {
    #cdr;
    #effectRef;
    constructor() {
        super();
        this.i18n = inject(LOGIN_I18N);
        this.renderer = inject(Renderer2);
        this.#cdr = inject(ChangeDetectorRef);
        this.meta = inject(Meta);
        this.title = inject(Title);
        this.kcContext = inject(KC_LOGIN_CONTEXT);
        this.doUseDefaultCss = inject(USE_DEFAULT_CSS);
        this.classes = inject(LOGIN_CLASSES);
        this.loginResourceInjectorService = inject(LoginResourceInjectorService);
        this.displayInfo = false;
        this.displayMessage = true;
        this.displayRequiredFields = false;
        this.page = input();
        this.pageRef = viewChild('pageRef', { read: ViewContainerRef });
        this.userProfileFormFields = input();
        this.isReadyToRender$ = this.loginResourceInjectorService.injectResource(this.doUseDefaultCss);
        this.#effectRef = effect(() => {
            const page = this.page();
            const pageRef = this.pageRef();
            if (!page || !pageRef)
                return;
            const userProfileFormFields = this.userProfileFormFields();
            const compRef = pageRef.createComponent(page);
            if ('userProfileFormFields' in compRef.instance && userProfileFormFields) {
                compRef.setInput('userProfileFormFields', userProfileFormFields);
            }
            this.onComponentCreated(compRef.instance);
        }, { manualCleanup: true });
    }
    applyKcIndexClasses() {
        const kcClsx = getKcClsx({
            doUseDefaultCss: this.doUseDefaultCss,
            classes: this.classes
        }).kcClsx;
        const kcBodyClass = this.bodyClassName ?? kcClsx('kcBodyClass');
        const kcHtmlClass = kcClsx('kcHtmlClass');
        const kcBodyClasses = kcBodyClass.split(/\s+/);
        const kcHtmlClasses = kcHtmlClass.split(/\s+/);
        kcBodyClasses.forEach(klass => {
            this.renderer.addClass(document.body, klass);
        });
        kcHtmlClasses.forEach(klass => {
            this.renderer.addClass(document.documentElement, klass);
        });
    }
    tryAnotherWay() {
        document.forms['kc-select-try-another-way-form'].submit();
    }
    onComponentCreated(compRef) {
        if ('displayInfo' in compRef) {
            this.displayInfo = !!compRef.displayInfo;
        }
        if ('displayMessage' in compRef) {
            this.displayMessage = !!compRef.displayMessage;
        }
        if ('displayRequiredFields' in compRef) {
            this.displayRequiredFields = !!compRef.displayRequiredFields;
        }
        if ('documentTitle' in compRef && compRef.documentTitle) {
            this.documentTitle = compRef.documentTitle;
        }
        if ('bodyClassName' in compRef && compRef.bodyClassName) {
            this.bodyClassName = compRef.bodyClassName;
        }
        if ('headerNode' in compRef && compRef.headerNode) {
            this.headerNode = computed(() => {
                const headerNode = compRef.headerNode();
                return headerNode;
            });
        }
        if ('infoNode' in compRef && compRef.infoNode) {
            this.infoNode = computed(() => {
                const infoNode = compRef.infoNode();
                return infoNode;
            });
        }
        if ('socialProvidersNode' in compRef && compRef.socialProvidersNode) {
            this.socialProvidersNode = computed(() => {
                const socialProvidersNode = compRef.socialProvidersNode();
                return socialProvidersNode;
            });
        }
        this.title.setTitle(this.documentTitle ?? this.i18n.msgStr('loginTitle', this.kcContext.realm.displayName));
        this.applyKcIndexClasses();
        this.#cdr.markForCheck();
        this.#effectRef.destroy();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: TemplateComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "20.0.3", type: TemplateComponent, isStandalone: true, selector: "kc-root", inputs: { page: { classPropertyName: "page", publicName: "page", isSignal: true, isRequired: false, transformFunction: null }, userProfileFormFields: { classPropertyName: "userProfileFormFields", publicName: "userProfileFormFields", isSignal: true, isRequired: false, transformFunction: null } }, providers: [
            {
                provide: ComponentReference,
                useExisting: forwardRef(() => TemplateComponent)
            }
        ], viewQueries: [{ propertyName: "pageRef", first: true, predicate: ["pageRef"], descendants: true, read: ViewContainerRef, isSignal: true }], usesInheritance: true, ngImport: i0, template: "@let realm = kcContext.realm;\n@let message = kcContext.message;\n@let auth = kcContext.auth;\n@let isAppInitiatedAction = kcContext.isAppInitiatedAction;\n@let url = kcContext.url;\n@let isReadyToRender = isReadyToRender$ | async;\n\n@if (isReadyToRender) {\n    <div [kcClass]=\"'kcLoginClass'\">\n        <div\n            id=\"kc-header\"\n            [kcClass]=\"'kcHeaderClass'\"\n        >\n            <div\n                id=\"kc-header-wrapper\"\n                [kcClass]=\"'kcHeaderWrapperClass'\"\n            >\n                <div [innerHTML]=\"realm?.displayNameHtml ?? '' | kcSanitize: 'html'\"></div>\n            </div>\n        </div>\n\n        <div [kcClass]=\"'kcFormCardClass'\">\n            <header [kcClass]=\"'kcFormHeaderClass'\">\n                <!-- Locale switcher -->\n                @if (i18n.enabledLanguages.length > 1) {\n                    <div\n                        id=\"kc-locale\"\n                        [kcClass]=\"'kcLocaleMainClass'\"\n                    >\n                        <div\n                            id=\"kc-locale-wrapper\"\n                            [kcClass]=\"'kcLocaleWrapperClass'\"\n                        >\n                            <div\n                                id=\"kc-locale-dropdown\"\n                                class=\"menu-button-links\"\n                                [kcClass]=\"'kcLocaleDropDownClass'\"\n                            >\n                                <button\n                                    tabindex=\"1\"\n                                    id=\"kc-current-locale-link\"\n                                    aria-haspopup=\"true\"\n                                    aria-expanded=\"false\"\n                                    aria-controls=\"language-switch1\"\n                                    [attr.aria-label]=\"i18n.msgStr('languages')\"\n                                >\n                                    {{ i18n.currentLanguage.label }}\n                                </button>\n                                <ul\n                                    role=\"menu\"\n                                    tabindex=\"-1\"\n                                    aria-labelledby=\"kc-current-locale-link\"\n                                    aria-activedescendant=\"\"\n                                    id=\"language-switch1\"\n                                    [kcClass]=\"'kcLocaleListClass'\"\n                                >\n                                    @for (entry of i18n.enabledLanguages; track entry; let idx = $index) {\n                                        <li\n                                            role=\"none\"\n                                            [kcClass]=\"'kcLocaleListItemClass'\"\n                                        >\n                                            <a\n                                                role=\"menuitem\"\n                                                tabindex=\"-1\"\n                                                [href]=\"entry.href\"\n                                                [kcClass]=\"'kcLocaleItemClass'\"\n                                                [id]=\"'language-' + idx\"\n                                            >\n                                                {{ entry.label }}\n                                            </a>\n                                        </li>\n                                    }\n                                </ul>\n                            </div>\n                        </div>\n                    </div>\n                }\n\n                <!-- Header content -->\n                <ng-template #node>\n                    @if (auth && !auth.showUsername && !auth.showResetCredentials) {\n                        <h1 id=\"kc-page-title\">\n                            @let header = headerNode && headerNode();\n                            @if (header) {\n                                <ng-container [ngTemplateOutlet]=\"header\" />\n                            }\n                        </h1>\n                    } @else {\n                        <div\n                            id=\"kc-username\"\n                            [kcClass]=\"'kcFormGroupClass'\"\n                        >\n                            <label id=\"kc-attempted-username\">{{ auth?.attemptedUsername }}</label>\n                            <a\n                                id=\"reset-login\"\n                                [href]=\"url?.loginRestartFlowUrl\"\n                                [attr.aria-label]=\"i18n.msgStr('restartLoginTooltip')\"\n                            >\n                                <div class=\"kc-login-tooltip\">\n                                    <i [kcClass]=\"'kcResetFlowIcon'\"></i>\n                                    <span class=\"kc-tooltip-text\">\n                                        {{ i18n.msgStr('restartLoginTooltip') }}\n                                    </span>\n                                </div>\n                            </a>\n                        </div>\n                    }\n                </ng-template>\n\n                @if (displayRequiredFields) {\n                    <div [kcClass]=\"'kcContentWrapperClass'\">\n                        <div\n                            class=\"subtitle\"\n                            [kcClass]=\"'kcLabelWrapperClass'\"\n                        >\n                            <span class=\"subtitle\">\n                                <span class=\"required\">*</span>\n                                {{ i18n.msgStr('requiredFields') }}\n                            </span>\n                        </div>\n                        <div class=\"col-md-10\">\n                            <ng-container [ngTemplateOutlet]=\"node\" />\n                        </div>\n                    </div>\n                } @else {\n                    <ng-container [ngTemplateOutlet]=\"node\" />\n                }\n            </header>\n\n            <div id=\"kc-content\">\n                <div id=\"kc-content-wrapper\">\n                    <!-- Message display -->\n                    @if (displayMessage && message && (message.type !== 'warning' || !isAppInitiatedAction)) {\n                        <div\n                            [kcClass]=\"'kcAlertClass'\"\n                            [ngClass]=\"message.type === 'error' ? 'pf-m-danger' : 'pf-m-' + message.type\"\n                            [class]=\"'alert-' + message.type\"\n                        >\n                            <div class=\"pf-c-alert__icon\">\n                                @switch (message.type) {\n                                    @case ('success') {\n                                        <span [kcClass]=\"'kcFeedbackSuccessIcon'\"></span>\n                                    }\n                                    @case ('warning') {\n                                        <span [kcClass]=\"'kcFeedbackWarningIcon'\"></span>\n                                    }\n                                    @case ('info') {\n                                        <span [kcClass]=\"'kcFeedbackInfoIcon'\"></span>\n                                    }\n                                    @case ('error') {\n                                        <span [kcClass]=\"'kcFeedbackErrorIcon'\"></span>\n                                    }\n                                }\n                            </div>\n                            <span\n                                [kcClass]=\"'kcAlertTitleClass'\"\n                                [innerHTML]=\"message.summary | kcSanitize: 'html'\"\n                            ></span>\n                        </div>\n                    }\n                    <!-- Content -->\n                    <ng-template #pageRef></ng-template>\n\n                    @if (!!auth && auth?.showTryAnotherWayLink) {\n                        <form\n                            id=\"kc-select-try-another-way-form\"\n                            method=\"post\"\n                            [action]=\"url?.loginAction\"\n                        >\n                            <div [kcClass]=\"'kcFormGroupClass'\">\n                                <div [kcClass]=\"'kcFormGroupClass'\">\n                                    <input\n                                        type=\"hidden\"\n                                        name=\"tryAnotherWay\"\n                                        value=\"on\"\n                                    />\n                                    <a\n                                        id=\"try-another-way\"\n                                        (click)=\"tryAnotherWay()\"\n                                    >\n                                        {{ i18n.msgStr('doTryAnotherWay') }}\n                                    </a>\n                                </div>\n                            </div>\n                        </form>\n                    }\n                    @let socialProviders = socialProvidersNode && socialProvidersNode();\n                    @if (socialProviders) {\n                        <ng-container [ngTemplateOutlet]=\"socialProviders\" />\n                    }\n                    <!-- Info display -->\n                    @if (displayInfo) {\n                        <div\n                            id=\"kc-info\"\n                            [kcClass]=\"'kcSignUpClass'\"\n                        >\n                            <div\n                                id=\"kc-info-wrapper\"\n                                [kcClass]=\"'kcInfoAreaWrapperClass'\"\n                            >\n                                @let info = infoNode && infoNode();\n                                @if (info) {\n                                    <ng-container [ngTemplateOutlet]=\"info\" />\n                                }\n                            </div>\n                        </div>\n                    }\n                </div>\n            </div>\n        </div>\n    </div>\n}\n", dependencies: [{ kind: "pipe", type: AsyncPipe, name: "async" }, { kind: "pipe", type: KcSanitizePipe, name: "kcSanitize" }, { kind: "directive", type: NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }, { kind: "directive", type: KcClassDirective, selector: "[kcClass]", inputs: ["class", "ngClass", "kcClass"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: TemplateComponent, decorators: [{
            type: Component,
            args: [{ selector: 'kc-root', imports: [AsyncPipe, KcSanitizePipe, NgTemplateOutlet, KcClassDirective], changeDetection: ChangeDetectionStrategy.OnPush, providers: [
                        {
                            provide: ComponentReference,
                            useExisting: forwardRef(() => TemplateComponent)
                        }
                    ], template: "@let realm = kcContext.realm;\n@let message = kcContext.message;\n@let auth = kcContext.auth;\n@let isAppInitiatedAction = kcContext.isAppInitiatedAction;\n@let url = kcContext.url;\n@let isReadyToRender = isReadyToRender$ | async;\n\n@if (isReadyToRender) {\n    <div [kcClass]=\"'kcLoginClass'\">\n        <div\n            id=\"kc-header\"\n            [kcClass]=\"'kcHeaderClass'\"\n        >\n            <div\n                id=\"kc-header-wrapper\"\n                [kcClass]=\"'kcHeaderWrapperClass'\"\n            >\n                <div [innerHTML]=\"realm?.displayNameHtml ?? '' | kcSanitize: 'html'\"></div>\n            </div>\n        </div>\n\n        <div [kcClass]=\"'kcFormCardClass'\">\n            <header [kcClass]=\"'kcFormHeaderClass'\">\n                <!-- Locale switcher -->\n                @if (i18n.enabledLanguages.length > 1) {\n                    <div\n                        id=\"kc-locale\"\n                        [kcClass]=\"'kcLocaleMainClass'\"\n                    >\n                        <div\n                            id=\"kc-locale-wrapper\"\n                            [kcClass]=\"'kcLocaleWrapperClass'\"\n                        >\n                            <div\n                                id=\"kc-locale-dropdown\"\n                                class=\"menu-button-links\"\n                                [kcClass]=\"'kcLocaleDropDownClass'\"\n                            >\n                                <button\n                                    tabindex=\"1\"\n                                    id=\"kc-current-locale-link\"\n                                    aria-haspopup=\"true\"\n                                    aria-expanded=\"false\"\n                                    aria-controls=\"language-switch1\"\n                                    [attr.aria-label]=\"i18n.msgStr('languages')\"\n                                >\n                                    {{ i18n.currentLanguage.label }}\n                                </button>\n                                <ul\n                                    role=\"menu\"\n                                    tabindex=\"-1\"\n                                    aria-labelledby=\"kc-current-locale-link\"\n                                    aria-activedescendant=\"\"\n                                    id=\"language-switch1\"\n                                    [kcClass]=\"'kcLocaleListClass'\"\n                                >\n                                    @for (entry of i18n.enabledLanguages; track entry; let idx = $index) {\n                                        <li\n                                            role=\"none\"\n                                            [kcClass]=\"'kcLocaleListItemClass'\"\n                                        >\n                                            <a\n                                                role=\"menuitem\"\n                                                tabindex=\"-1\"\n                                                [href]=\"entry.href\"\n                                                [kcClass]=\"'kcLocaleItemClass'\"\n                                                [id]=\"'language-' + idx\"\n                                            >\n                                                {{ entry.label }}\n                                            </a>\n                                        </li>\n                                    }\n                                </ul>\n                            </div>\n                        </div>\n                    </div>\n                }\n\n                <!-- Header content -->\n                <ng-template #node>\n                    @if (auth && !auth.showUsername && !auth.showResetCredentials) {\n                        <h1 id=\"kc-page-title\">\n                            @let header = headerNode && headerNode();\n                            @if (header) {\n                                <ng-container [ngTemplateOutlet]=\"header\" />\n                            }\n                        </h1>\n                    } @else {\n                        <div\n                            id=\"kc-username\"\n                            [kcClass]=\"'kcFormGroupClass'\"\n                        >\n                            <label id=\"kc-attempted-username\">{{ auth?.attemptedUsername }}</label>\n                            <a\n                                id=\"reset-login\"\n                                [href]=\"url?.loginRestartFlowUrl\"\n                                [attr.aria-label]=\"i18n.msgStr('restartLoginTooltip')\"\n                            >\n                                <div class=\"kc-login-tooltip\">\n                                    <i [kcClass]=\"'kcResetFlowIcon'\"></i>\n                                    <span class=\"kc-tooltip-text\">\n                                        {{ i18n.msgStr('restartLoginTooltip') }}\n                                    </span>\n                                </div>\n                            </a>\n                        </div>\n                    }\n                </ng-template>\n\n                @if (displayRequiredFields) {\n                    <div [kcClass]=\"'kcContentWrapperClass'\">\n                        <div\n                            class=\"subtitle\"\n                            [kcClass]=\"'kcLabelWrapperClass'\"\n                        >\n                            <span class=\"subtitle\">\n                                <span class=\"required\">*</span>\n                                {{ i18n.msgStr('requiredFields') }}\n                            </span>\n                        </div>\n                        <div class=\"col-md-10\">\n                            <ng-container [ngTemplateOutlet]=\"node\" />\n                        </div>\n                    </div>\n                } @else {\n                    <ng-container [ngTemplateOutlet]=\"node\" />\n                }\n            </header>\n\n            <div id=\"kc-content\">\n                <div id=\"kc-content-wrapper\">\n                    <!-- Message display -->\n                    @if (displayMessage && message && (message.type !== 'warning' || !isAppInitiatedAction)) {\n                        <div\n                            [kcClass]=\"'kcAlertClass'\"\n                            [ngClass]=\"message.type === 'error' ? 'pf-m-danger' : 'pf-m-' + message.type\"\n                            [class]=\"'alert-' + message.type\"\n                        >\n                            <div class=\"pf-c-alert__icon\">\n                                @switch (message.type) {\n                                    @case ('success') {\n                                        <span [kcClass]=\"'kcFeedbackSuccessIcon'\"></span>\n                                    }\n                                    @case ('warning') {\n                                        <span [kcClass]=\"'kcFeedbackWarningIcon'\"></span>\n                                    }\n                                    @case ('info') {\n                                        <span [kcClass]=\"'kcFeedbackInfoIcon'\"></span>\n                                    }\n                                    @case ('error') {\n                                        <span [kcClass]=\"'kcFeedbackErrorIcon'\"></span>\n                                    }\n                                }\n                            </div>\n                            <span\n                                [kcClass]=\"'kcAlertTitleClass'\"\n                                [innerHTML]=\"message.summary | kcSanitize: 'html'\"\n                            ></span>\n                        </div>\n                    }\n                    <!-- Content -->\n                    <ng-template #pageRef></ng-template>\n\n                    @if (!!auth && auth?.showTryAnotherWayLink) {\n                        <form\n                            id=\"kc-select-try-another-way-form\"\n                            method=\"post\"\n                            [action]=\"url?.loginAction\"\n                        >\n                            <div [kcClass]=\"'kcFormGroupClass'\">\n                                <div [kcClass]=\"'kcFormGroupClass'\">\n                                    <input\n                                        type=\"hidden\"\n                                        name=\"tryAnotherWay\"\n                                        value=\"on\"\n                                    />\n                                    <a\n                                        id=\"try-another-way\"\n                                        (click)=\"tryAnotherWay()\"\n                                    >\n                                        {{ i18n.msgStr('doTryAnotherWay') }}\n                                    </a>\n                                </div>\n                            </div>\n                        </form>\n                    }\n                    @let socialProviders = socialProvidersNode && socialProvidersNode();\n                    @if (socialProviders) {\n                        <ng-container [ngTemplateOutlet]=\"socialProviders\" />\n                    }\n                    <!-- Info display -->\n                    @if (displayInfo) {\n                        <div\n                            id=\"kc-info\"\n                            [kcClass]=\"'kcSignUpClass'\"\n                        >\n                            <div\n                                id=\"kc-info-wrapper\"\n                                [kcClass]=\"'kcInfoAreaWrapperClass'\"\n                            >\n                                @let info = infoNode && infoNode();\n                                @if (info) {\n                                    <ng-container [ngTemplateOutlet]=\"info\" />\n                                }\n                            </div>\n                        </div>\n                    }\n                </div>\n            </div>\n        </div>\n    </div>\n}\n" }]
        }], ctorParameters: () => [] });

/**
 * Generated bundle index. Do not edit.
 */

export { TemplateComponent };
//# sourceMappingURL=keycloakify-angular-login-template.mjs.map
