import { KeyValuePipe, NgClass } from '@angular/common';
import * as i0 from '@angular/core';
import { inject, forwardRef, Component } from '@angular/core';
import { ComponentReference } from '@keycloakify/angular/account/classes/component-reference';
import { KcClassDirective } from '@keycloakify/angular/account/directives/kc-class';
import { ACCOUNT_CLASSES } from '@keycloakify/angular/account/tokens/classes';
import { ACCOUNT_I18N } from '@keycloakify/angular/account/tokens/i18n';
import { KC_ACCOUNT_CONTEXT } from '@keycloakify/angular/account/tokens/kc-context';
import { IsArrayWithEmptyObjectPipe } from '@keycloakify/angular/lib/pipes/is-array-with-empty-object';
import { USE_DEFAULT_CSS } from '@keycloakify/angular/lib/tokens/use-default-css';

class ApplicationsComponent extends ComponentReference {
    constructor() {
        super(...arguments);
        this.i18n = inject(ACCOUNT_I18N);
        this.kcContext = inject(KC_ACCOUNT_CONTEXT);
        this.doUseDefaultCss = inject(USE_DEFAULT_CSS);
        this.classes = inject(ACCOUNT_CLASSES);
        this.active = 'applications';
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: ApplicationsComponent, deps: null, target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "20.0.3", type: ApplicationsComponent, isStandalone: true, selector: "kc-applications", providers: [
            {
                provide: ComponentReference,
                useExisting: forwardRef(() => ApplicationsComponent)
            }
        ], usesInheritance: true, ngImport: i0, template: "@let url = kcContext.url;\n@let stateChecker = kcContext.stateChecker;\n@let applications = kcContext.applications?.applications;\n\n<div class=\"row\">\n    <div class=\"col-md-10\">\n        <h2>{{ i18n.msgStr('applicationsHtmlTitle') }}</h2>\n    </div>\n\n    <form\n        method=\"post\"\n        [action]=\"url.applicationsUrl\"\n    >\n        <input\n            type=\"hidden\"\n            id=\"stateChecker\"\n            name=\"stateChecker\"\n            [value]=\"stateChecker\"\n        />\n        <input\n            type=\"hidden\"\n            id=\"referrer\"\n            name=\"referrer\"\n            [value]=\"stateChecker\"\n        />\n\n        <table class=\"table table-striped table-bordered\">\n            <thead>\n                <tr>\n                    <td>{{ i18n.msgStr('application') }}</td>\n                    <td>{{ i18n.msgStr('availableRoles') }}</td>\n                    <td>{{ i18n.msgStr('grantedPermissions') }}</td>\n                    <td>{{ i18n.msgStr('additionalGrants') }}</td>\n                    <td>{{ i18n.msgStr('action') }}</td>\n                </tr>\n            </thead>\n\n            <tbody>\n                @for (application of applications ?? []; track application) {\n                    <tr>\n                        <td>\n                            @if (application.effectiveUrl) {\n                                <a [href]=\"application.effectiveUrl\">\n                                    @if (application.client.name) {\n                                        {{ i18n.advancedMsgStr(application.client.name) }}\n                                    } @else {\n                                        {{ application.client.clientId }}\n                                    }\n                                </a>\n                            } @else {\n                                @if (application.client.name) {\n                                    {{ i18n.advancedMsgStr(application.client.name) }}\n                                } @else {\n                                    {{ application.client.clientId }}\n                                }\n                            }\n                        </td>\n\n                        <td>\n                            @if (!(application.realmRolesAvailable | isArrayWithEmptyObject)) {\n                                @for (role of application.realmRolesAvailable; track role; let last = $last) {\n                                    <span>\n                                        @if (role.description) {\n                                            {{ i18n.advancedMsgStr(role.description) }}\n                                        } @else {\n                                            {{ i18n.advancedMsgStr(role.name) }}\n                                        }\n                                        @if (!last) {\n                                            ,&nbsp;\n                                        }\n                                    </span>\n                                }\n                            }\n                            @if (application.resourceRolesAvailable) {\n                                @for (resource of application.resourceRolesAvailable | keyvalue; track resource.key) {\n                                    <span>\n                                        @if (!(application.realmRolesAvailable | isArrayWithEmptyObject)) {\n                                            ,&nbsp;\n                                        }\n                                        @for (\n                                            clientRole of application.resourceRolesAvailable[resource.key];\n                                            track clientRole;\n                                            let roleLast = $last\n                                        ) {\n                                            <span>\n                                                {{\n                                                    i18n.advancedMsgStr(clientRole.roleDescription ? clientRole.roleDescription : clientRole.roleName)\n                                                }}\n                                                {{ i18n.msgStr('inResource') }}\n                                                <strong>\n                                                    {{\n                                                        clientRole.clientName ? i18n.advancedMsgStr(clientRole.clientName) : clientRole.clientId\n                                                    }}</strong\n                                                >\n                                                @if (!roleLast) {\n                                                    ,&nbsp;\n                                                }\n                                            </span>\n                                        }\n                                    </span>\n                                }\n                            }\n                        </td>\n\n                        <td>\n                            @if (application.client.consentRequired) {\n                                @for (claim of application.clientScopesGranted; track claim; let last = $last) {\n                                    {{ i18n.advancedMsgStr(claim) }}\n                                    @if (!last) {\n                                        ,&nbsp;\n                                    }\n                                }\n                            } @else {\n                                <strong>{{ i18n.msgStr('fullAccess') }}</strong>\n                            }\n                        </td>\n\n                        <td>\n                            @for (grant of application.additionalGrants; track grant; let last = $last) {\n                                {{ i18n.advancedMsgStr(grant) }}\n                                @if (!last) {\n                                    ,&nbsp;\n                                }\n                            }\n                        </td>\n\n                        <td>\n                            @if (\n                                (application.client.consentRequired && application.clientScopesGranted.length > 0) ||\n                                application.additionalGrants.length > 0\n                            ) {\n                                <button\n                                    type=\"submit\"\n                                    name=\"clientId\"\n                                    [kcClass]=\"['kcButtonPrimaryClass', 'kcButtonClass']\"\n                                    [id]=\"'revoke-' + application.client.clientId\"\n                                    [value]=\"application.client.id\"\n                                >\n                                    {{ i18n.msgStr('revoke') }}\n                                </button>\n                            }\n                        </td>\n                    </tr>\n                }\n            </tbody>\n        </table>\n    </form>\n</div>\n", dependencies: [{ kind: "directive", type: KcClassDirective, selector: "[kcClass]", inputs: ["class", "ngClass", "kcClass"] }, { kind: "pipe", type: KeyValuePipe, name: "keyvalue" }, { kind: "pipe", type: IsArrayWithEmptyObjectPipe, name: "isArrayWithEmptyObject" }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: ApplicationsComponent, decorators: [{
            type: Component,
            args: [{ imports: [KcClassDirective, NgClass, KeyValuePipe, IsArrayWithEmptyObjectPipe], selector: 'kc-applications', providers: [
                        {
                            provide: ComponentReference,
                            useExisting: forwardRef(() => ApplicationsComponent)
                        }
                    ], template: "@let url = kcContext.url;\n@let stateChecker = kcContext.stateChecker;\n@let applications = kcContext.applications?.applications;\n\n<div class=\"row\">\n    <div class=\"col-md-10\">\n        <h2>{{ i18n.msgStr('applicationsHtmlTitle') }}</h2>\n    </div>\n\n    <form\n        method=\"post\"\n        [action]=\"url.applicationsUrl\"\n    >\n        <input\n            type=\"hidden\"\n            id=\"stateChecker\"\n            name=\"stateChecker\"\n            [value]=\"stateChecker\"\n        />\n        <input\n            type=\"hidden\"\n            id=\"referrer\"\n            name=\"referrer\"\n            [value]=\"stateChecker\"\n        />\n\n        <table class=\"table table-striped table-bordered\">\n            <thead>\n                <tr>\n                    <td>{{ i18n.msgStr('application') }}</td>\n                    <td>{{ i18n.msgStr('availableRoles') }}</td>\n                    <td>{{ i18n.msgStr('grantedPermissions') }}</td>\n                    <td>{{ i18n.msgStr('additionalGrants') }}</td>\n                    <td>{{ i18n.msgStr('action') }}</td>\n                </tr>\n            </thead>\n\n            <tbody>\n                @for (application of applications ?? []; track application) {\n                    <tr>\n                        <td>\n                            @if (application.effectiveUrl) {\n                                <a [href]=\"application.effectiveUrl\">\n                                    @if (application.client.name) {\n                                        {{ i18n.advancedMsgStr(application.client.name) }}\n                                    } @else {\n                                        {{ application.client.clientId }}\n                                    }\n                                </a>\n                            } @else {\n                                @if (application.client.name) {\n                                    {{ i18n.advancedMsgStr(application.client.name) }}\n                                } @else {\n                                    {{ application.client.clientId }}\n                                }\n                            }\n                        </td>\n\n                        <td>\n                            @if (!(application.realmRolesAvailable | isArrayWithEmptyObject)) {\n                                @for (role of application.realmRolesAvailable; track role; let last = $last) {\n                                    <span>\n                                        @if (role.description) {\n                                            {{ i18n.advancedMsgStr(role.description) }}\n                                        } @else {\n                                            {{ i18n.advancedMsgStr(role.name) }}\n                                        }\n                                        @if (!last) {\n                                            ,&nbsp;\n                                        }\n                                    </span>\n                                }\n                            }\n                            @if (application.resourceRolesAvailable) {\n                                @for (resource of application.resourceRolesAvailable | keyvalue; track resource.key) {\n                                    <span>\n                                        @if (!(application.realmRolesAvailable | isArrayWithEmptyObject)) {\n                                            ,&nbsp;\n                                        }\n                                        @for (\n                                            clientRole of application.resourceRolesAvailable[resource.key];\n                                            track clientRole;\n                                            let roleLast = $last\n                                        ) {\n                                            <span>\n                                                {{\n                                                    i18n.advancedMsgStr(clientRole.roleDescription ? clientRole.roleDescription : clientRole.roleName)\n                                                }}\n                                                {{ i18n.msgStr('inResource') }}\n                                                <strong>\n                                                    {{\n                                                        clientRole.clientName ? i18n.advancedMsgStr(clientRole.clientName) : clientRole.clientId\n                                                    }}</strong\n                                                >\n                                                @if (!roleLast) {\n                                                    ,&nbsp;\n                                                }\n                                            </span>\n                                        }\n                                    </span>\n                                }\n                            }\n                        </td>\n\n                        <td>\n                            @if (application.client.consentRequired) {\n                                @for (claim of application.clientScopesGranted; track claim; let last = $last) {\n                                    {{ i18n.advancedMsgStr(claim) }}\n                                    @if (!last) {\n                                        ,&nbsp;\n                                    }\n                                }\n                            } @else {\n                                <strong>{{ i18n.msgStr('fullAccess') }}</strong>\n                            }\n                        </td>\n\n                        <td>\n                            @for (grant of application.additionalGrants; track grant; let last = $last) {\n                                {{ i18n.advancedMsgStr(grant) }}\n                                @if (!last) {\n                                    ,&nbsp;\n                                }\n                            }\n                        </td>\n\n                        <td>\n                            @if (\n                                (application.client.consentRequired && application.clientScopesGranted.length > 0) ||\n                                application.additionalGrants.length > 0\n                            ) {\n                                <button\n                                    type=\"submit\"\n                                    name=\"clientId\"\n                                    [kcClass]=\"['kcButtonPrimaryClass', 'kcButtonClass']\"\n                                    [id]=\"'revoke-' + application.client.clientId\"\n                                    [value]=\"application.client.id\"\n                                >\n                                    {{ i18n.msgStr('revoke') }}\n                                </button>\n                            }\n                        </td>\n                    </tr>\n                }\n            </tbody>\n        </table>\n    </form>\n</div>\n" }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { ApplicationsComponent };
//# sourceMappingURL=keycloakify-angular-account-pages-applications.mjs.map
