import { NgClass } from '@angular/common';
import * as i0 from '@angular/core';
import { inject, forwardRef, Component } from '@angular/core';
import { ComponentReference } from '@keycloakify/angular/account/classes/component-reference';
import { KcClassDirective } from '@keycloakify/angular/account/directives/kc-class';
import { ACCOUNT_CLASSES } from '@keycloakify/angular/account/tokens/classes';
import { ACCOUNT_I18N } from '@keycloakify/angular/account/tokens/i18n';
import { KC_ACCOUNT_CONTEXT } from '@keycloakify/angular/account/tokens/kc-context';
import { KcSanitizePipe } from '@keycloakify/angular/lib/pipes/kc-sanitize';
import { USE_DEFAULT_CSS } from '@keycloakify/angular/lib/tokens/use-default-css';

class TotpComponent extends ComponentReference {
    constructor() {
        super(...arguments);
        this.i18n = inject(ACCOUNT_I18N);
        this.kcContext = inject(KC_ACCOUNT_CONTEXT);
        this.doUseDefaultCss = inject(USE_DEFAULT_CSS);
        this.classes = inject(ACCOUNT_CLASSES);
        this.active = 'totp';
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: TotpComponent, deps: null, target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "20.0.3", type: TotpComponent, isStandalone: true, selector: "kc-totp", providers: [
            {
                provide: ComponentReference,
                useExisting: forwardRef(() => TotpComponent)
            }
        ], usesInheritance: true, ngImport: i0, template: "@let url = kcContext.url;\n@let mode = kcContext.mode;\n@let messagesPerField = kcContext.messagesPerField;\n@let stateChecker = kcContext.stateChecker;\n@let totp = kcContext.totp;\n\n<div class=\"row\">\n    <div class=\"col-md-10\">\n        <h2>{{ i18n.msgStr('authenticatorTitle') }}</h2>\n    </div>\n    @if (totp.otpCredentials.length) {\n        <div class=\"subtitle col-md-2\">\n            <span class=\"required\">*</span>\n            {{ i18n.msgStr('requiredFields') }}\n        </div>\n    }\n</div>\n@if (totp.enabled) {\n    <table class=\"table table-bordered table-striped\">\n        <thead>\n            @if (totp.otpCredentials.length > 1) {\n                <tr>\n                    <th [colSpan]=\"4\">{{ i18n.msgStr('configureAuthenticators') }}</th>\n                </tr>\n            } @else {\n                <tr>\n                    <th [colSpan]=\"3\">{{ i18n.msgStr('configureAuthenticators') }}</th>\n                </tr>\n            }\n        </thead>\n        <tbody>\n            @for (credential of totp.otpCredentials; track credential; let index = $index) {\n                <tr>\n                    <td class=\"provider\">{{ i18n.msgStr('mobile') }}</td>\n                    @if (totp.otpCredentials.length > 1) {\n                        <td class=\"provider\">{{ credential.id }}</td>\n                    }\n                    <td class=\"provider\">{{ credential.userLabel || '' }}</td>\n                    <td class=\"action\">\n                        <form\n                            method=\"post\"\n                            class=\"form-inline\"\n                            [action]=\"url.totpUrl\"\n                        >\n                            <input\n                                type=\"hidden\"\n                                id=\"stateChecker\"\n                                name=\"stateChecker\"\n                                [value]=\"stateChecker\"\n                            />\n                            <input\n                                type=\"hidden\"\n                                id=\"submitAction\"\n                                name=\"submitAction\"\n                                value=\"Delete\"\n                            />\n                            <input\n                                type=\"hidden\"\n                                id=\"credentialId\"\n                                name=\"credentialId\"\n                                [value]=\"credential.id\"\n                            />\n                            <button\n                                class=\"btn btn-default\"\n                                [id]=\"'remove-mobile-' + index\"\n                            >\n                                <i class=\"pficon pficon-delete\"></i>\n                            </button>\n                        </form>\n                    </td>\n                </tr>\n            }\n        </tbody>\n    </table>\n} @else {\n    <div>\n        <hr />\n        <ol id=\"kc-totp-settings\">\n            <li>\n                <p>{{ i18n.msgStr('totpStep1') }}</p>\n\n                <ul id=\"kc-totp-supported-apps\">\n                    @for (app of totp.supportedApplications; track app) {\n                        <li>{{ i18n.advancedMsgStr(app) }}</li>\n                    }\n                </ul>\n            </li>\n            @if (mode && mode === 'manual') {\n                <li>\n                    <p>{{ i18n.msgStr('totpManualStep2') }}</p>\n                    <p>\n                        <span id=\"kc-totp-secret-key\">{{ totp.totpSecretEncoded }}</span>\n                    </p>\n                    <p>\n                        <a\n                            id=\"mode-barcode\"\n                            [href]=\"totp.qrUrl\"\n                        >\n                            {{ i18n.msgStr('totpScanBarcode') }}\n                        </a>\n                    </p>\n                </li>\n                <li>\n                    <p>{{ i18n.msgStr('totpManualStep3') }}</p>\n                    <ul>\n                        <li id=\"kc-totp-type\">{{ i18n.msgStr('totpType') }}: {{ i18n.msgStr($any('totp.' + totp.policy.type)) }}</li>\n                        <li id=\"kc-totp-algorithm\">{{ i18n.msgStr('totpAlgorithm') }}: {{ totp.policy.getAlgorithmKey() }}</li>\n                        <li id=\"kc-totp-digits\">{{ i18n.msgStr('totpDigits') }}: {{ totp.policy.digits }}</li>\n                        @if (totp.policy.type === 'totp') {\n                            <li id=\"kc-totp-period\">{{ i18n.msgStr('totpInterval') }}: {{ totp.policy.period }}</li>\n                        } @else {\n                            <li id=\"kc-totp-counter\">{{ i18n.msgStr('totpCounter') }}: {{ totp.policy.initialCounter }}</li>\n                        }\n                    </ul>\n                </li>\n            } @else {\n                <li>\n                    <p>{{ i18n.msgStr('totpStep2') }}</p>\n                    <p>\n                        <img\n                            id=\"kc-totp-secret-qr-code\"\n                            alt=\"Figure: Barcode\"\n                            [src]=\"'data:image/png;base64, ' + totp.totpSecretQrCode\"\n                        />\n                    </p>\n                    <p>\n                        <a\n                            id=\"mode-manual\"\n                            [href]=\"totp.manualUrl\"\n                        >\n                            {{ i18n.msgStr('totpUnableToScan') }}\n                        </a>\n                    </p>\n                </li>\n            }\n            <li>\n                <p>{{ i18n.msgStr('totpStep3') }}</p>\n                <p>{{ i18n.msgStr('totpStep3DeviceName') }}</p>\n            </li>\n        </ol>\n        <hr />\n        <form\n            id=\"kc-totp-settings-form\"\n            method=\"post\"\n            [action]=\"url.totpUrl\"\n            [kcClass]=\"'kcFormClass'\"\n        >\n            <input\n                type=\"hidden\"\n                id=\"stateChecker\"\n                name=\"stateChecker\"\n                [value]=\"stateChecker\"\n            />\n            <div [kcClass]=\"'kcFormGroupClass'\">\n                <div class=\"col-sm-2 col-md-2\">\n                    <label\n                        for=\"totp\"\n                        class=\"control-label\"\n                    >\n                        {{ i18n.msgStr('authenticatorCode') }}\n                    </label>\n                    <span class=\"required\">*</span>\n                </div>\n                <div class=\"col-sm-10 col-md-10\">\n                    <input\n                        type=\"text\"\n                        id=\"totp\"\n                        name=\"totp\"\n                        autoComplete=\"off\"\n                        [kcClass]=\"'kcInputClass'\"\n                        [attr.aria-invalid]=\"messagesPerField.existsError('totp')\"\n                    />\n                    @if (messagesPerField.existsError('totp')) {\n                        <span\n                            id=\"input-error-otp-code\"\n                            aria-live=\"polite\"\n                            [kcClass]=\"'kcInputErrorMessageClass'\"\n                            [innerHTML]=\"messagesPerField.get('totp') | kcSanitize: 'html'\"\n                        ></span>\n                    }\n                </div>\n                <input\n                    type=\"hidden\"\n                    id=\"totpSecret\"\n                    name=\"totpSecret\"\n                    [value]=\"totp.totpSecret\"\n                />\n                @if (mode) {\n                    <input\n                        type=\"hidden\"\n                        id=\"mode\"\n                        [value]=\"mode\"\n                    />\n                }\n            </div>\n\n            <div [kcClass]=\"'kcFormGroupClass'\">\n                <div class=\"col-sm-2 col-md-2\">\n                    <label\n                        for=\"userLabel\"\n                        [kcClass]=\"'kcLabelClass'\"\n                    >\n                        {{ i18n.msgStr('totpDeviceName') }}\n                    </label>\n                    @if (totp.otpCredentials.length >= 1) {\n                        <span class=\"required\">*</span>\n                    }\n                </div>\n                <div class=\"col-sm-10 col-md-10\">\n                    <input\n                        type=\"text\"\n                        id=\"userLabel\"\n                        name=\"userLabel\"\n                        autoComplete=\"off\"\n                        [kcClass]=\"'kcInputClass'\"\n                        [attr.aria-invalid]=\"messagesPerField.existsError('userLabel')\"\n                    />\n                    @if (messagesPerField.existsError('userLabel')) {\n                        <span\n                            id=\"input-error-otp-label\"\n                            aria-live=\"polite\"\n                            [kcClass]=\"'kcInputErrorMessageClass'\"\n                            [innerHTML]=\"messagesPerField.get('userLabel') | kcSanitize: 'html'\"\n                        ></span>\n                    }\n                </div>\n            </div>\n\n            <div\n                id=\"kc-form-buttons\"\n                class=\"text-right\"\n                [kcClass]=\"'kcFormGroupClass'\"\n            >\n                <div [kcClass]=\"'kcInputWrapperClass'\">\n                    <input\n                        type=\"submit\"\n                        id=\"saveTOTPBtn\"\n                        [kcClass]=\"['kcButtonClass', 'kcButtonPrimaryClass', 'kcButtonLargeClass']\"\n                        [value]=\"i18n.msgStr('doSave')\"\n                    />\n                    <button\n                        type=\"submit\"\n                        id=\"cancelTOTPBtn\"\n                        name=\"submitAction\"\n                        value=\"Cancel\"\n                        [kcClass]=\"['kcButtonClass', 'kcButtonDefaultClass', 'kcButtonLargeClass']\"\n                    >\n                        {{ i18n.msgStr('doCancel') }}\n                    </button>\n                </div>\n            </div>\n        </form>\n    </div>\n}\n", dependencies: [{ kind: "directive", type: KcClassDirective, selector: "[kcClass]", inputs: ["class", "ngClass", "kcClass"] }, { kind: "pipe", type: KcSanitizePipe, name: "kcSanitize" }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: TotpComponent, decorators: [{
            type: Component,
            args: [{ imports: [KcClassDirective, KcSanitizePipe, NgClass], selector: 'kc-totp', providers: [
                        {
                            provide: ComponentReference,
                            useExisting: forwardRef(() => TotpComponent)
                        }
                    ], template: "@let url = kcContext.url;\n@let mode = kcContext.mode;\n@let messagesPerField = kcContext.messagesPerField;\n@let stateChecker = kcContext.stateChecker;\n@let totp = kcContext.totp;\n\n<div class=\"row\">\n    <div class=\"col-md-10\">\n        <h2>{{ i18n.msgStr('authenticatorTitle') }}</h2>\n    </div>\n    @if (totp.otpCredentials.length) {\n        <div class=\"subtitle col-md-2\">\n            <span class=\"required\">*</span>\n            {{ i18n.msgStr('requiredFields') }}\n        </div>\n    }\n</div>\n@if (totp.enabled) {\n    <table class=\"table table-bordered table-striped\">\n        <thead>\n            @if (totp.otpCredentials.length > 1) {\n                <tr>\n                    <th [colSpan]=\"4\">{{ i18n.msgStr('configureAuthenticators') }}</th>\n                </tr>\n            } @else {\n                <tr>\n                    <th [colSpan]=\"3\">{{ i18n.msgStr('configureAuthenticators') }}</th>\n                </tr>\n            }\n        </thead>\n        <tbody>\n            @for (credential of totp.otpCredentials; track credential; let index = $index) {\n                <tr>\n                    <td class=\"provider\">{{ i18n.msgStr('mobile') }}</td>\n                    @if (totp.otpCredentials.length > 1) {\n                        <td class=\"provider\">{{ credential.id }}</td>\n                    }\n                    <td class=\"provider\">{{ credential.userLabel || '' }}</td>\n                    <td class=\"action\">\n                        <form\n                            method=\"post\"\n                            class=\"form-inline\"\n                            [action]=\"url.totpUrl\"\n                        >\n                            <input\n                                type=\"hidden\"\n                                id=\"stateChecker\"\n                                name=\"stateChecker\"\n                                [value]=\"stateChecker\"\n                            />\n                            <input\n                                type=\"hidden\"\n                                id=\"submitAction\"\n                                name=\"submitAction\"\n                                value=\"Delete\"\n                            />\n                            <input\n                                type=\"hidden\"\n                                id=\"credentialId\"\n                                name=\"credentialId\"\n                                [value]=\"credential.id\"\n                            />\n                            <button\n                                class=\"btn btn-default\"\n                                [id]=\"'remove-mobile-' + index\"\n                            >\n                                <i class=\"pficon pficon-delete\"></i>\n                            </button>\n                        </form>\n                    </td>\n                </tr>\n            }\n        </tbody>\n    </table>\n} @else {\n    <div>\n        <hr />\n        <ol id=\"kc-totp-settings\">\n            <li>\n                <p>{{ i18n.msgStr('totpStep1') }}</p>\n\n                <ul id=\"kc-totp-supported-apps\">\n                    @for (app of totp.supportedApplications; track app) {\n                        <li>{{ i18n.advancedMsgStr(app) }}</li>\n                    }\n                </ul>\n            </li>\n            @if (mode && mode === 'manual') {\n                <li>\n                    <p>{{ i18n.msgStr('totpManualStep2') }}</p>\n                    <p>\n                        <span id=\"kc-totp-secret-key\">{{ totp.totpSecretEncoded }}</span>\n                    </p>\n                    <p>\n                        <a\n                            id=\"mode-barcode\"\n                            [href]=\"totp.qrUrl\"\n                        >\n                            {{ i18n.msgStr('totpScanBarcode') }}\n                        </a>\n                    </p>\n                </li>\n                <li>\n                    <p>{{ i18n.msgStr('totpManualStep3') }}</p>\n                    <ul>\n                        <li id=\"kc-totp-type\">{{ i18n.msgStr('totpType') }}: {{ i18n.msgStr($any('totp.' + totp.policy.type)) }}</li>\n                        <li id=\"kc-totp-algorithm\">{{ i18n.msgStr('totpAlgorithm') }}: {{ totp.policy.getAlgorithmKey() }}</li>\n                        <li id=\"kc-totp-digits\">{{ i18n.msgStr('totpDigits') }}: {{ totp.policy.digits }}</li>\n                        @if (totp.policy.type === 'totp') {\n                            <li id=\"kc-totp-period\">{{ i18n.msgStr('totpInterval') }}: {{ totp.policy.period }}</li>\n                        } @else {\n                            <li id=\"kc-totp-counter\">{{ i18n.msgStr('totpCounter') }}: {{ totp.policy.initialCounter }}</li>\n                        }\n                    </ul>\n                </li>\n            } @else {\n                <li>\n                    <p>{{ i18n.msgStr('totpStep2') }}</p>\n                    <p>\n                        <img\n                            id=\"kc-totp-secret-qr-code\"\n                            alt=\"Figure: Barcode\"\n                            [src]=\"'data:image/png;base64, ' + totp.totpSecretQrCode\"\n                        />\n                    </p>\n                    <p>\n                        <a\n                            id=\"mode-manual\"\n                            [href]=\"totp.manualUrl\"\n                        >\n                            {{ i18n.msgStr('totpUnableToScan') }}\n                        </a>\n                    </p>\n                </li>\n            }\n            <li>\n                <p>{{ i18n.msgStr('totpStep3') }}</p>\n                <p>{{ i18n.msgStr('totpStep3DeviceName') }}</p>\n            </li>\n        </ol>\n        <hr />\n        <form\n            id=\"kc-totp-settings-form\"\n            method=\"post\"\n            [action]=\"url.totpUrl\"\n            [kcClass]=\"'kcFormClass'\"\n        >\n            <input\n                type=\"hidden\"\n                id=\"stateChecker\"\n                name=\"stateChecker\"\n                [value]=\"stateChecker\"\n            />\n            <div [kcClass]=\"'kcFormGroupClass'\">\n                <div class=\"col-sm-2 col-md-2\">\n                    <label\n                        for=\"totp\"\n                        class=\"control-label\"\n                    >\n                        {{ i18n.msgStr('authenticatorCode') }}\n                    </label>\n                    <span class=\"required\">*</span>\n                </div>\n                <div class=\"col-sm-10 col-md-10\">\n                    <input\n                        type=\"text\"\n                        id=\"totp\"\n                        name=\"totp\"\n                        autoComplete=\"off\"\n                        [kcClass]=\"'kcInputClass'\"\n                        [attr.aria-invalid]=\"messagesPerField.existsError('totp')\"\n                    />\n                    @if (messagesPerField.existsError('totp')) {\n                        <span\n                            id=\"input-error-otp-code\"\n                            aria-live=\"polite\"\n                            [kcClass]=\"'kcInputErrorMessageClass'\"\n                            [innerHTML]=\"messagesPerField.get('totp') | kcSanitize: 'html'\"\n                        ></span>\n                    }\n                </div>\n                <input\n                    type=\"hidden\"\n                    id=\"totpSecret\"\n                    name=\"totpSecret\"\n                    [value]=\"totp.totpSecret\"\n                />\n                @if (mode) {\n                    <input\n                        type=\"hidden\"\n                        id=\"mode\"\n                        [value]=\"mode\"\n                    />\n                }\n            </div>\n\n            <div [kcClass]=\"'kcFormGroupClass'\">\n                <div class=\"col-sm-2 col-md-2\">\n                    <label\n                        for=\"userLabel\"\n                        [kcClass]=\"'kcLabelClass'\"\n                    >\n                        {{ i18n.msgStr('totpDeviceName') }}\n                    </label>\n                    @if (totp.otpCredentials.length >= 1) {\n                        <span class=\"required\">*</span>\n                    }\n                </div>\n                <div class=\"col-sm-10 col-md-10\">\n                    <input\n                        type=\"text\"\n                        id=\"userLabel\"\n                        name=\"userLabel\"\n                        autoComplete=\"off\"\n                        [kcClass]=\"'kcInputClass'\"\n                        [attr.aria-invalid]=\"messagesPerField.existsError('userLabel')\"\n                    />\n                    @if (messagesPerField.existsError('userLabel')) {\n                        <span\n                            id=\"input-error-otp-label\"\n                            aria-live=\"polite\"\n                            [kcClass]=\"'kcInputErrorMessageClass'\"\n                            [innerHTML]=\"messagesPerField.get('userLabel') | kcSanitize: 'html'\"\n                        ></span>\n                    }\n                </div>\n            </div>\n\n            <div\n                id=\"kc-form-buttons\"\n                class=\"text-right\"\n                [kcClass]=\"'kcFormGroupClass'\"\n            >\n                <div [kcClass]=\"'kcInputWrapperClass'\">\n                    <input\n                        type=\"submit\"\n                        id=\"saveTOTPBtn\"\n                        [kcClass]=\"['kcButtonClass', 'kcButtonPrimaryClass', 'kcButtonLargeClass']\"\n                        [value]=\"i18n.msgStr('doSave')\"\n                    />\n                    <button\n                        type=\"submit\"\n                        id=\"cancelTOTPBtn\"\n                        name=\"submitAction\"\n                        value=\"Cancel\"\n                        [kcClass]=\"['kcButtonClass', 'kcButtonDefaultClass', 'kcButtonLargeClass']\"\n                    >\n                        {{ i18n.msgStr('doCancel') }}\n                    </button>\n                </div>\n            </div>\n        </form>\n    </div>\n}\n" }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { TotpComponent };
//# sourceMappingURL=keycloakify-angular-account-pages-totp.mjs.map
