import * as i0 from '@angular/core';
import { inject, viewChild, forwardRef, ChangeDetectionStrategy, Component } from '@angular/core';
import { KcSanitizePipe } from '@keycloakify/angular/lib/pipes/kc-sanitize';
import { USE_DEFAULT_CSS } from '@keycloakify/angular/lib/tokens/use-default-css';
import { ComponentReference } from '@keycloakify/angular/login/classes/component-reference';
import { LogoutOtherSessionsComponent } from '@keycloakify/angular/login/components/logout-other-sessions';
import { KcClassDirective } from '@keycloakify/angular/login/directives/kc-class';
import { LOGIN_CLASSES } from '@keycloakify/angular/login/tokens/classes';
import { LOGIN_I18N } from '@keycloakify/angular/login/tokens/i18n';
import { KC_LOGIN_CONTEXT } from '@keycloakify/angular/login/tokens/kc-context';

class LoginConfigTotpComponent extends ComponentReference {
    constructor() {
        super(...arguments);
        this.kcContext = inject(KC_LOGIN_CONTEXT);
        this.i18n = inject(LOGIN_I18N);
        this.doUseDefaultCss = inject(USE_DEFAULT_CSS);
        this.classes = inject(LOGIN_CLASSES);
        this.displayRequiredFields = false;
        this.displayInfo = false;
        this.displayMessage = this.kcContext.messagesPerField.existsError('totp', 'userLabel');
        this.headerNode = viewChild('headerNode');
        this.infoNode = viewChild('infoNode');
        this.socialProvidersNode = viewChild('socialProvidersNode');
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: LoginConfigTotpComponent, deps: null, target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "20.0.3", type: LoginConfigTotpComponent, isStandalone: true, selector: "kc-login-config-totp", providers: [
            {
                provide: ComponentReference,
                useExisting: forwardRef(() => LoginConfigTotpComponent)
            }
        ], viewQueries: [{ propertyName: "headerNode", first: true, predicate: ["headerNode"], descendants: true, isSignal: true }, { propertyName: "infoNode", first: true, predicate: ["infoNode"], descendants: true, isSignal: true }, { propertyName: "socialProvidersNode", first: true, predicate: ["socialProvidersNode"], descendants: true, isSignal: true }], usesInheritance: true, ngImport: i0, template: "@let totp = kcContext.totp;\n@let url = kcContext.url;\n@let messagesPerField = kcContext.messagesPerField;\n@let mode = kcContext.mode;\n@let isAppInitiatedAction = kcContext.isAppInitiatedAction;\n\n<ng-template #headerNode>\n    {{ i18n.msgStr('loginTotpStep1') }}\n</ng-template>\n<ol id=\"kc-totp-settings\">\n    <li>\n        <p>{{ i18n.msgStr('loginTotpStep1') }}</p>\n        <ul id=\"kc-totp-supported-apps\">\n            @for (app of totp.supportedApplications; track app) {\n                <li>{{ i18n.advancedMsgStr(app) }}</li>\n            }\n        </ul>\n    </li>\n    @if (kcContext.mode === 'manual') {\n        <li>\n            <p>{{ i18n.msgStr('loginTotpManualStep2') }}</p>\n            <p>\n                <span id=\"kc-totp-secret-key\">{{ totp.totpSecretEncoded }}</span>\n            </p>\n            <p>\n                <a\n                    id=\"mode-barcode\"\n                    [href]=\"totp.qrUrl\"\n                >\n                    {{ i18n.msgStr('loginTotpScanBarcode') }}\n                </a>\n            </p>\n        </li>\n        <li>\n            <p>{{ i18n.msgStr('loginTotpManualStep3') }}</p>\n            <p></p>\n            <ul>\n                <li id=\"kc-totp-type\">\n                    {{ i18n.msgStr('loginTotpType') }}:\n                    {{ i18n.advancedMsgStr('loginTotp.' + totp.policy.type) }}\n                </li>\n                <li id=\"kc-totp-algorithm\">\n                    {{ i18n.msgStr('loginTotpAlgorithm') }}:\n                    {{ totp.policy.getAlgorithmKey() }}\n                </li>\n                <li id=\"kc-totp-digits\">{{ i18n.msgStr('loginTotpDigits') }}: {{ totp.policy.digits }}</li>\n                @if (totp.policy.type === 'totp') {\n                    <li id=\"kc-totp-period\">\n                        {{ i18n.msgStr('loginTotpInterval') }}:\n                        {{ totp.policy.period }}\n                    </li>\n                } @else {\n                    <li id=\"kc-totp-counter\">\n                        {{ i18n.msgStr('loginTotpCounter') }}:\n                        {{ totp.policy.initialCounter }}\n                    </li>\n                }\n            </ul>\n        </li>\n    } @else {\n        <li>\n            <p>{{ i18n.msgStr('loginTotpStep2') }}</p>\n            <img\n                id=\"kc-totp-secret-qr-code\"\n                alt=\"Figure: Barcode\"\n                [src]=\"'data:image/png;base64, ' + totp.totpSecretQrCode\"\n            />\n            <br />\n            <p>\n                <a\n                    id=\"mode-manual\"\n                    [href]=\"totp.manualUrl\"\n                >\n                    {{ i18n.msgStr('loginTotpUnableToScan') }}\n                </a>\n            </p>\n        </li>\n    }\n    <li>\n        <p>{{ i18n.msgStr('loginTotpStep3') }}</p>\n        <p>{{ i18n.msgStr('loginTotpStep3DeviceName') }}</p>\n    </li>\n</ol>\n<form\n    id=\"kc-totp-settings-form\"\n    method=\"post\"\n    [action]=\"url.loginAction\"\n    [kcClass]=\"'kcFormClass'\"\n>\n    <div [kcClass]=\"'kcFormGroupClass'\">\n        <div [kcClass]=\"'kcInputWrapperClass'\">\n            <label\n                for=\"totp\"\n                [kcClass]=\"'kcLabelClass'\"\n            >\n                {{ i18n.msgStr('authenticatorCode') }}\n            </label>\n            <span class=\"required\">*</span>\n        </div>\n        <div [kcClass]=\"'kcInputWrapperClass'\">\n            <input\n                type=\"text\"\n                id=\"totp\"\n                name=\"totp\"\n                autoComplete=\"off\"\n                [kcClass]=\"'kcInputClass'\"\n                [attr.aria-invalid]=\"messagesPerField.existsError('totp')\"\n            />\n            @if (messagesPerField.existsError('totp')) {\n                <span\n                    id=\"input-error-otp-code\"\n                    aria-live=\"polite\"\n                    [kcClass]=\"'kcInputErrorMessageClass'\"\n                    [innerHTML]=\"messagesPerField.get('totp') | kcSanitize: 'html'\"\n                ></span>\n            }\n        </div>\n        <input\n            type=\"hidden\"\n            id=\"totpSecret\"\n            name=\"totpSecret\"\n            [value]=\"totp.totpSecret\"\n        />\n        @if (mode) {\n            <input\n                type=\"hidden\"\n                id=\"mode\"\n                [value]=\"mode\"\n            />\n        }\n    </div>\n    <div [kcClass]=\"'kcFormGroupClass'\">\n        <div [kcClass]=\"'kcInputWrapperClass'\">\n            <label\n                for=\"userLabel\"\n                [kcClass]=\"'kcLabelClass'\"\n            >\n                {{ i18n.msgStr('loginTotpDeviceName') }}\n            </label>\n            @if (totp.otpCredentials.length >= 1) {\n                <span class=\"required\">*</span>\n            }\n        </div>\n        <div [kcClass]=\"'kcInputWrapperClass'\">\n            <input\n                type=\"text\"\n                id=\"userLabel\"\n                name=\"userLabel\"\n                autoComplete=\"off\"\n                [kcClass]=\"'kcInputClass'\"\n                [attr.aria-invalid]=\"messagesPerField.existsError('userLabel')\"\n            />\n            @if (messagesPerField.existsError('userLabel')) {\n                <span\n                    id=\"input-error-otp-label\"\n                    aria-live=\"polite\"\n                    [kcClass]=\"'kcInputErrorMessageClass'\"\n                    [innerHTML]=\"messagesPerField.get('userLabel') | kcSanitize: 'html'\"\n                ></span>\n            }\n        </div>\n    </div>\n    <div [kcClass]=\"'kcFormGroupClass'\">\n        <kc-logout-other-sessions />\n    </div>\n\n    @if (isAppInitiatedAction) {\n        <input\n            type=\"submit\"\n            id=\"saveTOTPBtn\"\n            [kcClass]=\"['kcButtonClass', 'kcButtonPrimaryClass', 'kcButtonLargeClass']\"\n            [value]=\"i18n.msgStr('doSubmit')\"\n        />\n        <button\n            type=\"submit\"\n            id=\"cancelTOTPBtn\"\n            name=\"cancel-aia\"\n            [kcClass]=\"['kcButtonClass', 'kcButtonDefaultClass', 'kcButtonLargeClass', 'kcButtonLargeClass']\"\n            [value]=\"true\"\n        >\n            {{ i18n.msgStr('doCancel') }}\n        </button>\n    } @else {\n        <input\n            type=\"submit\"\n            id=\"saveTOTPBtn\"\n            [kcClass]=\"['kcButtonClass', 'kcButtonPrimaryClass', 'kcButtonLargeClass']\"\n            [value]=\"i18n.msgStr('doSubmit')\"\n        />\n    }\n</form>\n", dependencies: [{ kind: "directive", type: KcClassDirective, selector: "[kcClass]", inputs: ["class", "ngClass", "kcClass"] }, { kind: "pipe", type: KcSanitizePipe, name: "kcSanitize" }, { kind: "component", type: LogoutOtherSessionsComponent, selector: "kc-logout-other-sessions" }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: LoginConfigTotpComponent, decorators: [{
            type: Component,
            args: [{ imports: [KcClassDirective, KcSanitizePipe, LogoutOtherSessionsComponent], selector: 'kc-login-config-totp', changeDetection: ChangeDetectionStrategy.OnPush, providers: [
                        {
                            provide: ComponentReference,
                            useExisting: forwardRef(() => LoginConfigTotpComponent)
                        }
                    ], template: "@let totp = kcContext.totp;\n@let url = kcContext.url;\n@let messagesPerField = kcContext.messagesPerField;\n@let mode = kcContext.mode;\n@let isAppInitiatedAction = kcContext.isAppInitiatedAction;\n\n<ng-template #headerNode>\n    {{ i18n.msgStr('loginTotpStep1') }}\n</ng-template>\n<ol id=\"kc-totp-settings\">\n    <li>\n        <p>{{ i18n.msgStr('loginTotpStep1') }}</p>\n        <ul id=\"kc-totp-supported-apps\">\n            @for (app of totp.supportedApplications; track app) {\n                <li>{{ i18n.advancedMsgStr(app) }}</li>\n            }\n        </ul>\n    </li>\n    @if (kcContext.mode === 'manual') {\n        <li>\n            <p>{{ i18n.msgStr('loginTotpManualStep2') }}</p>\n            <p>\n                <span id=\"kc-totp-secret-key\">{{ totp.totpSecretEncoded }}</span>\n            </p>\n            <p>\n                <a\n                    id=\"mode-barcode\"\n                    [href]=\"totp.qrUrl\"\n                >\n                    {{ i18n.msgStr('loginTotpScanBarcode') }}\n                </a>\n            </p>\n        </li>\n        <li>\n            <p>{{ i18n.msgStr('loginTotpManualStep3') }}</p>\n            <p></p>\n            <ul>\n                <li id=\"kc-totp-type\">\n                    {{ i18n.msgStr('loginTotpType') }}:\n                    {{ i18n.advancedMsgStr('loginTotp.' + totp.policy.type) }}\n                </li>\n                <li id=\"kc-totp-algorithm\">\n                    {{ i18n.msgStr('loginTotpAlgorithm') }}:\n                    {{ totp.policy.getAlgorithmKey() }}\n                </li>\n                <li id=\"kc-totp-digits\">{{ i18n.msgStr('loginTotpDigits') }}: {{ totp.policy.digits }}</li>\n                @if (totp.policy.type === 'totp') {\n                    <li id=\"kc-totp-period\">\n                        {{ i18n.msgStr('loginTotpInterval') }}:\n                        {{ totp.policy.period }}\n                    </li>\n                } @else {\n                    <li id=\"kc-totp-counter\">\n                        {{ i18n.msgStr('loginTotpCounter') }}:\n                        {{ totp.policy.initialCounter }}\n                    </li>\n                }\n            </ul>\n        </li>\n    } @else {\n        <li>\n            <p>{{ i18n.msgStr('loginTotpStep2') }}</p>\n            <img\n                id=\"kc-totp-secret-qr-code\"\n                alt=\"Figure: Barcode\"\n                [src]=\"'data:image/png;base64, ' + totp.totpSecretQrCode\"\n            />\n            <br />\n            <p>\n                <a\n                    id=\"mode-manual\"\n                    [href]=\"totp.manualUrl\"\n                >\n                    {{ i18n.msgStr('loginTotpUnableToScan') }}\n                </a>\n            </p>\n        </li>\n    }\n    <li>\n        <p>{{ i18n.msgStr('loginTotpStep3') }}</p>\n        <p>{{ i18n.msgStr('loginTotpStep3DeviceName') }}</p>\n    </li>\n</ol>\n<form\n    id=\"kc-totp-settings-form\"\n    method=\"post\"\n    [action]=\"url.loginAction\"\n    [kcClass]=\"'kcFormClass'\"\n>\n    <div [kcClass]=\"'kcFormGroupClass'\">\n        <div [kcClass]=\"'kcInputWrapperClass'\">\n            <label\n                for=\"totp\"\n                [kcClass]=\"'kcLabelClass'\"\n            >\n                {{ i18n.msgStr('authenticatorCode') }}\n            </label>\n            <span class=\"required\">*</span>\n        </div>\n        <div [kcClass]=\"'kcInputWrapperClass'\">\n            <input\n                type=\"text\"\n                id=\"totp\"\n                name=\"totp\"\n                autoComplete=\"off\"\n                [kcClass]=\"'kcInputClass'\"\n                [attr.aria-invalid]=\"messagesPerField.existsError('totp')\"\n            />\n            @if (messagesPerField.existsError('totp')) {\n                <span\n                    id=\"input-error-otp-code\"\n                    aria-live=\"polite\"\n                    [kcClass]=\"'kcInputErrorMessageClass'\"\n                    [innerHTML]=\"messagesPerField.get('totp') | kcSanitize: 'html'\"\n                ></span>\n            }\n        </div>\n        <input\n            type=\"hidden\"\n            id=\"totpSecret\"\n            name=\"totpSecret\"\n            [value]=\"totp.totpSecret\"\n        />\n        @if (mode) {\n            <input\n                type=\"hidden\"\n                id=\"mode\"\n                [value]=\"mode\"\n            />\n        }\n    </div>\n    <div [kcClass]=\"'kcFormGroupClass'\">\n        <div [kcClass]=\"'kcInputWrapperClass'\">\n            <label\n                for=\"userLabel\"\n                [kcClass]=\"'kcLabelClass'\"\n            >\n                {{ i18n.msgStr('loginTotpDeviceName') }}\n            </label>\n            @if (totp.otpCredentials.length >= 1) {\n                <span class=\"required\">*</span>\n            }\n        </div>\n        <div [kcClass]=\"'kcInputWrapperClass'\">\n            <input\n                type=\"text\"\n                id=\"userLabel\"\n                name=\"userLabel\"\n                autoComplete=\"off\"\n                [kcClass]=\"'kcInputClass'\"\n                [attr.aria-invalid]=\"messagesPerField.existsError('userLabel')\"\n            />\n            @if (messagesPerField.existsError('userLabel')) {\n                <span\n                    id=\"input-error-otp-label\"\n                    aria-live=\"polite\"\n                    [kcClass]=\"'kcInputErrorMessageClass'\"\n                    [innerHTML]=\"messagesPerField.get('userLabel') | kcSanitize: 'html'\"\n                ></span>\n            }\n        </div>\n    </div>\n    <div [kcClass]=\"'kcFormGroupClass'\">\n        <kc-logout-other-sessions />\n    </div>\n\n    @if (isAppInitiatedAction) {\n        <input\n            type=\"submit\"\n            id=\"saveTOTPBtn\"\n            [kcClass]=\"['kcButtonClass', 'kcButtonPrimaryClass', 'kcButtonLargeClass']\"\n            [value]=\"i18n.msgStr('doSubmit')\"\n        />\n        <button\n            type=\"submit\"\n            id=\"cancelTOTPBtn\"\n            name=\"cancel-aia\"\n            [kcClass]=\"['kcButtonClass', 'kcButtonDefaultClass', 'kcButtonLargeClass', 'kcButtonLargeClass']\"\n            [value]=\"true\"\n        >\n            {{ i18n.msgStr('doCancel') }}\n        </button>\n    } @else {\n        <input\n            type=\"submit\"\n            id=\"saveTOTPBtn\"\n            [kcClass]=\"['kcButtonClass', 'kcButtonPrimaryClass', 'kcButtonLargeClass']\"\n            [value]=\"i18n.msgStr('doSubmit')\"\n        />\n    }\n</form>\n" }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { LoginConfigTotpComponent };
//# sourceMappingURL=keycloakify-angular-login-pages-login-config-totp.mjs.map
