import { NgClass, CommonModule, AsyncPipe } from '@angular/common';
import * as i0 from '@angular/core';
import { inject, viewChild, signal, forwardRef, ChangeDetectionStrategy, Component } from '@angular/core';
import { KcSanitizePipe } from '@keycloakify/angular/lib/pipes/kc-sanitize';
import { USE_DEFAULT_CSS } from '@keycloakify/angular/lib/tokens/use-default-css';
import { ComponentReference } from '@keycloakify/angular/login/classes/component-reference';
import { PasswordWrapperComponent } from '@keycloakify/angular/login/components/password-wrapper';
import { KcClassDirective } from '@keycloakify/angular/login/directives/kc-class';
import { LOGIN_CLASSES } from '@keycloakify/angular/login/tokens/classes';
import { LOGIN_I18N } from '@keycloakify/angular/login/tokens/i18n';
import { KC_LOGIN_CONTEXT } from '@keycloakify/angular/login/tokens/kc-context';

class LoginComponent extends ComponentReference {
    constructor() {
        super(...arguments);
        this.kcContext = inject(KC_LOGIN_CONTEXT);
        this.i18n = inject(LOGIN_I18N);
        this.doUseDefaultCss = inject(USE_DEFAULT_CSS);
        this.classes = inject(LOGIN_CLASSES);
        this.displayRequiredFields = false;
        this.displayInfo = !!this.kcContext?.realm?.password && !!this.kcContext?.realm?.registrationAllowed && !this.kcContext?.registrationDisabled;
        this.displayMessage = !this.kcContext?.messagesPerField?.existsError('username', 'password');
        this.headerNode = viewChild('headerNode');
        this.infoNode = viewChild('infoNode');
        this.socialProvidersNode = viewChild('socialProvidersNode');
        this.isLoginButtonDisabled = signal(false);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: LoginComponent, deps: null, target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "20.0.3", type: LoginComponent, isStandalone: true, selector: "kc-login", providers: [
            {
                provide: ComponentReference,
                useExisting: forwardRef(() => LoginComponent)
            }
        ], viewQueries: [{ propertyName: "headerNode", first: true, predicate: ["headerNode"], descendants: true, isSignal: true }, { propertyName: "infoNode", first: true, predicate: ["infoNode"], descendants: true, isSignal: true }, { propertyName: "socialProvidersNode", first: true, predicate: ["socialProvidersNode"], descendants: true, isSignal: true }], usesInheritance: true, ngImport: i0, template: "@let realm = kcContext.realm;\n@let usernameHidden = kcContext.usernameHidden;\n@let auth = kcContext.auth;\n@let messagesPerField = kcContext.messagesPerField;\n@let url = kcContext.url;\n@let login = kcContext.login;\n\n<ng-template #headerNode>\n    {{ i18n.msgStr('loginAccountTitle') }}\n</ng-template>\n<ng-template #infoNode>\n    @let url = kcContext.url;\n    <div id=\"kc-registration-container\">\n        <div id=\"kc-registration\">\n            <span>\n                {{ i18n.msgStr('noAccount') }}\n                <a\n                    tabindex=\"8\"\n                    [href]=\"url?.registrationUrl\"\n                >\n                    {{ i18n.msgStr('doRegister') }}\n                </a>\n            </span>\n        </div>\n    </div>\n</ng-template>\n<ng-template #socialProvidersNode>\n    @let realm = kcContext.realm;\n    @let social = kcContext.social;\n    @if (!!realm?.password && !!social?.providers?.length) {\n        <div\n            id=\"kc-social-providers\"\n            [kcClass]=\"'kcFormSocialAccountSectionClass'\"\n        >\n            <hr />\n            <h2>{{ i18n.msgStr('identity-provider-login-label') }}</h2>\n            <ul\n                [kcClass]=\"{\n                    kcFormSocialAccountListClass: true,\n                    kcFormSocialAccountListGridClass: (social?.providers?.length ?? 0) > 3\n                }\"\n            >\n                @for (provider of social?.providers; track provider.alias; let idx = $index) {\n                    <li>\n                        <a\n                            type=\"button\"\n                            [id]=\"provider.alias\"\n                            [kcClass]=\"{\n                                kcFormSocialAccountListButtonClass: true,\n                                kcFormSocialAccountGridItem: (social?.providers?.length ?? 0) > 3\n                            }\"\n                            [href]=\"provider.loginUrl\"\n                        >\n                            @if (provider.iconClasses) {\n                                <i\n                                    aria-hidden=\"true\"\n                                    [ngClass]=\"provider.iconClasses\"\n                                    [kcClass]=\"'kcCommonLogoIdP'\"\n                                ></i>\n                            }\n                            <span\n                                [ngClass]=\"{\n                                    'kc-social-icon-text': provider.iconClasses\n                                }\"\n                                [kcClass]=\"'kcFormSocialAccountNameClass'\"\n                                [innerHTML]=\"provider.displayName | kcSanitize: 'html'\"\n                            ></span>\n                        </a>\n                    </li>\n                }\n            </ul>\n        </div>\n    }\n</ng-template>\n<div id=\"kc-form\">\n    <div id=\"kc-form-wrapper\">\n        <!-- login.component.html -->\n        @if (realm?.password) {\n            <form\n                id=\"kc-form-login\"\n                method=\"post\"\n                [action]=\"url?.loginAction\"\n                (onSubmit)=\"isLoginButtonDisabled.set(true)\"\n            >\n                @if (!usernameHidden) {\n                    <div [kcClass]=\"'kcFormGroupClass'\">\n                        <label\n                            for=\"username\"\n                            [kcClass]=\"'kcLabelClass'\"\n                        >\n                            @if (!realm?.loginWithEmailAllowed) {\n                                {{ i18n.msgStr('username') }}\n                            } @else if (!realm?.registrationEmailAsUsername) {\n                                {{ i18n.msgStr('usernameOrEmail') }}\n                            } @else {\n                                {{ i18n.msgStr('email') }}\n                            }\n                        </label>\n                        <input\n                            tabindex=\"2\"\n                            id=\"username\"\n                            name=\"username\"\n                            type=\"text\"\n                            autofocus\n                            [kcClass]=\"'kcInputClass'\"\n                            [defaultValue]=\"login?.username || ''\"\n                            [attr.aria-invalid]=\"messagesPerField?.existsError('username', 'password')\"\n                        />\n                        @if (messagesPerField?.existsError('username', 'password')) {\n                            <span\n                                id=\"input-error\"\n                                aria-live=\"polite\"\n                                [kcClass]=\"'kcInputErrorMessageClass'\"\n                                [innerHTML]=\"messagesPerField.getFirstError('username', 'password') | kcSanitize: 'html'\"\n                            >\n                            </span>\n                        }\n                    </div>\n                }\n\n                <div [kcClass]=\"'kcFormGroupClass'\">\n                    <label\n                        for=\"password\"\n                        [kcClass]=\"'kcLabelClass'\"\n                    >\n                        {{ i18n.msgStr('password') }}\n                    </label>\n\n                    <kc-password-wrapper passwordInputId=\"password\">\n                        <input\n                            tabindex=\"3\"\n                            id=\"password\"\n                            name=\"password\"\n                            type=\"password\"\n                            autocomplete=\"off\"\n                            [kcClass]=\"'kcInputClass'\"\n                            [attr.aria-invalid]=\"messagesPerField.existsError('username', 'password')\"\n                        />\n                    </kc-password-wrapper>\n                    @if (usernameHidden && messagesPerField?.existsError('username', 'password')) {\n                        <span\n                            id=\"input-error\"\n                            aria-live=\"polite\"\n                            [kcClass]=\"'kcInputErrorMessageClass'\"\n                            [innerHTML]=\"messagesPerField.getFirstError('username', 'password') | kcSanitize: 'html'\"\n                        >\n                        </span>\n                    }\n                </div>\n\n                <div [kcClass]=\"['kcFormGroupClass', 'kcFormSettingClass']\">\n                    <div id=\"kc-form-options\">\n                        @if (realm?.rememberMe && !usernameHidden) {\n                            <div class=\"checkbox\">\n                                <label>\n                                    <input\n                                        tabindex=\"5\"\n                                        id=\"rememberMe\"\n                                        name=\"rememberMe\"\n                                        type=\"checkbox\"\n                                        [defaultChecked]=\"!!login?.rememberMe\"\n                                    />\n                                    {{ i18n.msgStr('rememberMe') }}\n                                </label>\n                            </div>\n                        }\n                    </div>\n\n                    <div [kcClass]=\"'kcFormOptionsWrapperClass'\">\n                        @if (realm?.resetPasswordAllowed) {\n                            <span>\n                                <a\n                                    tabindex=\"6\"\n                                    [href]=\"url?.loginResetCredentialsUrl\"\n                                    >{{ i18n.msgStr('doForgotPassword') }}</a\n                                >\n                            </span>\n                        }\n                    </div>\n                </div>\n                <div\n                    id=\"kc-form-buttons\"\n                    [kcClass]=\"'kcFormGroupClass'\"\n                >\n                    <input\n                        type=\"hidden\"\n                        id=\"id-hidden-input\"\n                        name=\"credentialId\"\n                        [value]=\"auth?.selectedCredential\"\n                    />\n                    <input\n                        tabindex=\"7\"\n                        name=\"login\"\n                        id=\"kc-login\"\n                        type=\"submit\"\n                        [kcClass]=\"['kcButtonClass', 'kcButtonPrimaryClass', 'kcButtonBlockClass', 'kcButtonLargeClass']\"\n                        [value]=\"i18n.msgStr('doLogIn')\"\n                        [disabled]=\"isLoginButtonDisabled()\"\n                    />\n                </div>\n            </form>\n        }\n    </div>\n</div>\n", dependencies: [{ kind: "directive", type: KcClassDirective, selector: "[kcClass]", inputs: ["class", "ngClass", "kcClass"] }, { kind: "pipe", type: KcSanitizePipe, name: "kcSanitize" }, { kind: "component", type: PasswordWrapperComponent, selector: "kc-password-wrapper", inputs: ["passwordInputId"] }, { kind: "directive", type: NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "ngmodule", type: CommonModule }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: LoginComponent, decorators: [{
            type: Component,
            args: [{ selector: 'kc-login', changeDetection: ChangeDetectionStrategy.OnPush, imports: [KcClassDirective, AsyncPipe, KcSanitizePipe, PasswordWrapperComponent, NgClass, CommonModule], providers: [
                        {
                            provide: ComponentReference,
                            useExisting: forwardRef(() => LoginComponent)
                        }
                    ], template: "@let realm = kcContext.realm;\n@let usernameHidden = kcContext.usernameHidden;\n@let auth = kcContext.auth;\n@let messagesPerField = kcContext.messagesPerField;\n@let url = kcContext.url;\n@let login = kcContext.login;\n\n<ng-template #headerNode>\n    {{ i18n.msgStr('loginAccountTitle') }}\n</ng-template>\n<ng-template #infoNode>\n    @let url = kcContext.url;\n    <div id=\"kc-registration-container\">\n        <div id=\"kc-registration\">\n            <span>\n                {{ i18n.msgStr('noAccount') }}\n                <a\n                    tabindex=\"8\"\n                    [href]=\"url?.registrationUrl\"\n                >\n                    {{ i18n.msgStr('doRegister') }}\n                </a>\n            </span>\n        </div>\n    </div>\n</ng-template>\n<ng-template #socialProvidersNode>\n    @let realm = kcContext.realm;\n    @let social = kcContext.social;\n    @if (!!realm?.password && !!social?.providers?.length) {\n        <div\n            id=\"kc-social-providers\"\n            [kcClass]=\"'kcFormSocialAccountSectionClass'\"\n        >\n            <hr />\n            <h2>{{ i18n.msgStr('identity-provider-login-label') }}</h2>\n            <ul\n                [kcClass]=\"{\n                    kcFormSocialAccountListClass: true,\n                    kcFormSocialAccountListGridClass: (social?.providers?.length ?? 0) > 3\n                }\"\n            >\n                @for (provider of social?.providers; track provider.alias; let idx = $index) {\n                    <li>\n                        <a\n                            type=\"button\"\n                            [id]=\"provider.alias\"\n                            [kcClass]=\"{\n                                kcFormSocialAccountListButtonClass: true,\n                                kcFormSocialAccountGridItem: (social?.providers?.length ?? 0) > 3\n                            }\"\n                            [href]=\"provider.loginUrl\"\n                        >\n                            @if (provider.iconClasses) {\n                                <i\n                                    aria-hidden=\"true\"\n                                    [ngClass]=\"provider.iconClasses\"\n                                    [kcClass]=\"'kcCommonLogoIdP'\"\n                                ></i>\n                            }\n                            <span\n                                [ngClass]=\"{\n                                    'kc-social-icon-text': provider.iconClasses\n                                }\"\n                                [kcClass]=\"'kcFormSocialAccountNameClass'\"\n                                [innerHTML]=\"provider.displayName | kcSanitize: 'html'\"\n                            ></span>\n                        </a>\n                    </li>\n                }\n            </ul>\n        </div>\n    }\n</ng-template>\n<div id=\"kc-form\">\n    <div id=\"kc-form-wrapper\">\n        <!-- login.component.html -->\n        @if (realm?.password) {\n            <form\n                id=\"kc-form-login\"\n                method=\"post\"\n                [action]=\"url?.loginAction\"\n                (onSubmit)=\"isLoginButtonDisabled.set(true)\"\n            >\n                @if (!usernameHidden) {\n                    <div [kcClass]=\"'kcFormGroupClass'\">\n                        <label\n                            for=\"username\"\n                            [kcClass]=\"'kcLabelClass'\"\n                        >\n                            @if (!realm?.loginWithEmailAllowed) {\n                                {{ i18n.msgStr('username') }}\n                            } @else if (!realm?.registrationEmailAsUsername) {\n                                {{ i18n.msgStr('usernameOrEmail') }}\n                            } @else {\n                                {{ i18n.msgStr('email') }}\n                            }\n                        </label>\n                        <input\n                            tabindex=\"2\"\n                            id=\"username\"\n                            name=\"username\"\n                            type=\"text\"\n                            autofocus\n                            [kcClass]=\"'kcInputClass'\"\n                            [defaultValue]=\"login?.username || ''\"\n                            [attr.aria-invalid]=\"messagesPerField?.existsError('username', 'password')\"\n                        />\n                        @if (messagesPerField?.existsError('username', 'password')) {\n                            <span\n                                id=\"input-error\"\n                                aria-live=\"polite\"\n                                [kcClass]=\"'kcInputErrorMessageClass'\"\n                                [innerHTML]=\"messagesPerField.getFirstError('username', 'password') | kcSanitize: 'html'\"\n                            >\n                            </span>\n                        }\n                    </div>\n                }\n\n                <div [kcClass]=\"'kcFormGroupClass'\">\n                    <label\n                        for=\"password\"\n                        [kcClass]=\"'kcLabelClass'\"\n                    >\n                        {{ i18n.msgStr('password') }}\n                    </label>\n\n                    <kc-password-wrapper passwordInputId=\"password\">\n                        <input\n                            tabindex=\"3\"\n                            id=\"password\"\n                            name=\"password\"\n                            type=\"password\"\n                            autocomplete=\"off\"\n                            [kcClass]=\"'kcInputClass'\"\n                            [attr.aria-invalid]=\"messagesPerField.existsError('username', 'password')\"\n                        />\n                    </kc-password-wrapper>\n                    @if (usernameHidden && messagesPerField?.existsError('username', 'password')) {\n                        <span\n                            id=\"input-error\"\n                            aria-live=\"polite\"\n                            [kcClass]=\"'kcInputErrorMessageClass'\"\n                            [innerHTML]=\"messagesPerField.getFirstError('username', 'password') | kcSanitize: 'html'\"\n                        >\n                        </span>\n                    }\n                </div>\n\n                <div [kcClass]=\"['kcFormGroupClass', 'kcFormSettingClass']\">\n                    <div id=\"kc-form-options\">\n                        @if (realm?.rememberMe && !usernameHidden) {\n                            <div class=\"checkbox\">\n                                <label>\n                                    <input\n                                        tabindex=\"5\"\n                                        id=\"rememberMe\"\n                                        name=\"rememberMe\"\n                                        type=\"checkbox\"\n                                        [defaultChecked]=\"!!login?.rememberMe\"\n                                    />\n                                    {{ i18n.msgStr('rememberMe') }}\n                                </label>\n                            </div>\n                        }\n                    </div>\n\n                    <div [kcClass]=\"'kcFormOptionsWrapperClass'\">\n                        @if (realm?.resetPasswordAllowed) {\n                            <span>\n                                <a\n                                    tabindex=\"6\"\n                                    [href]=\"url?.loginResetCredentialsUrl\"\n                                    >{{ i18n.msgStr('doForgotPassword') }}</a\n                                >\n                            </span>\n                        }\n                    </div>\n                </div>\n                <div\n                    id=\"kc-form-buttons\"\n                    [kcClass]=\"'kcFormGroupClass'\"\n                >\n                    <input\n                        type=\"hidden\"\n                        id=\"id-hidden-input\"\n                        name=\"credentialId\"\n                        [value]=\"auth?.selectedCredential\"\n                    />\n                    <input\n                        tabindex=\"7\"\n                        name=\"login\"\n                        id=\"kc-login\"\n                        type=\"submit\"\n                        [kcClass]=\"['kcButtonClass', 'kcButtonPrimaryClass', 'kcButtonBlockClass', 'kcButtonLargeClass']\"\n                        [value]=\"i18n.msgStr('doLogIn')\"\n                        [disabled]=\"isLoginButtonDisabled()\"\n                    />\n                </div>\n            </form>\n        }\n    </div>\n</div>\n" }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { LoginComponent };
//# sourceMappingURL=keycloakify-angular-login-pages-login.mjs.map
